@@ -21,28 +21,27 @@
 
 #include "duplicate.h"
 
+#include <utility>               // for as_const
+
 #include <QList>                 // for QList, QList<>::iterator, QList<>::const_iterator
 #include <QMultiHash>            // for QMultiHash
-#include <QtCore>                // for qAsConst
 
 #include "defs.h"
 
 
 #if FILTERS_ENABLED
 
-#define MYNAME "duplicate"
-
 void DuplicateFilter::init()
 {
   if (!lcopt && !snopt) {
-    fatal(MYNAME ": one or both of the shortname and location options are required.\n");
+    gbFatal("one or both of the shortname and location options are required.\n");
   }
 }
 
 void DuplicateFilter::process()
 {
   QMultiHash<QString, Waypoint*> wpthash;
-  for (Waypoint* waypointp : qAsConst(*global_waypoint_list)) {
+  for (Waypoint* waypointp : std::as_const(*global_waypoint_list)) {
 
     QString key;
     if (lcopt) {
@@ -72,8 +71,7 @@ void DuplicateFilter::process()
         wptfirst->latitude = wptlast->latitude;
         wptfirst->longitude = wptlast->longitude;
       }
-      for (auto it = values.cbegin(); it != values.cend(); ++it) {
-        Waypoint* wpt = *it;
+      for (Waypoint* wpt : values) {
         if (purge_duplicates || (wpt != wptfirst)) {
           wpt->wpt_flags.marked_for_deletion = 1;
         }
