@@ -22,11 +22,13 @@
 #ifndef DUPLICATE_H_INCLUDED_
 #define DUPLICATE_H_INCLUDED_
 
+#include <QList>     // for QList
 #include <QString>   // for QString
 #include <QVector>   // for QVector
 
 #include "defs.h"    // for ARGTYPE_BOOL, ARG_NOMINMAX, Waypoint (ptr only)
 #include "filter.h"  // for Filter
+#include "option.h"  // for OptionBool
 
 #if FILTERS_ENABLED
 
@@ -41,10 +43,10 @@ public:
   void process() override;
 
 private:
-  char* snopt = nullptr;
-  char* lcopt = nullptr;
-  char* purge_duplicates = nullptr;
-  char* correct_coords = nullptr;
+  OptionBool snopt;
+  OptionBool lcopt;
+  OptionBool purge_duplicates;
+  OptionBool correct_coords;
 
   QVector<arglist_t> args = {
     {
