@@ -21,10 +21,12 @@
 #ifndef FILTER_VECS_H_INCLUDED_
 #define FILTER_VECS_H_INCLUDED_
 
-#include <QString>          // for QString
+#include <QList>        // for QList
+#include <QString>      // for QString
+#include <QStringList>  // for QStringList
 
-#include "defs.h"           // for arglist_t
-#include "filter.h"         // for Filter
+#include "defs.h"       // for arglist_t
+#include "filter.h"     // for Filter
 
 
 class FilterVecs
@@ -68,7 +70,7 @@ public:
   static void prepare_filter(const fltinfo_t& fltdata);
   fltinfo_t find_filter_vec(const QString& fltargstring);
   static void free_filter_vec(Filter* flt);
-  static void init_filter_vec(Filter* flt);
+  static void init_filter_vec(Filter* flt, const QString& fltname);
   void init_filter_vecs();
   static void exit_filter_vec(Filter* flt);
   void exit_filter_vecs();
