@@ -58,42 +58,41 @@ struct gbfile {
 #if !ZLIB_INHIBITED
     gzFile gz;
 #endif
-  } handle;
-  char*   name;
-  char*   module;
-  char*   buff;	/* static growing buffer, primary used by gbprintf */
-  int    buffsz;
-  char   mode;
-  int    back;
-  gbsize_t mempos;	/* curr. position in memory */
-  gbsize_t memlen;	/* max. number of written bytes to memory */
-  gbsize_t memsz;		/* curr. size of allocated memory */
-  unsigned char big_endian:1;
-  unsigned char binary:1;
-  unsigned char gzapi:1;
-  unsigned char memapi:1;
-  unsigned char unicode:1;
-  unsigned char unicode_checked:1;
-  unsigned char is_pipe:1;
-  gbfclearerr_cb fileclearerr;
-  gbfclose_cb fileclose;
-  gbfeof_cb fileeof;
-  gbferror_cb fileerror;
-  gbfflush_cb fileflush;
-  gbfopen_cb fileopen;
-  gbfread_cb fileread;
-  gbfseek_cb fileseek;
-  gbftell_cb filetell;
-  gbfungetc_cb fileungetc;
-  gbfwrite_cb filewrite;
+  } handle{nullptr};
+  QString   name;
+  char*   buff{nullptr};	/* static growing buffer, primary used by gbprintf */
+  int    buffsz{0};
+  char   mode{0};
+  int    back{0};
+  gbsize_t mempos{0};	/* curr. position in memory */
+  gbsize_t memlen{0};	/* max. number of written bytes to memory */
+  gbsize_t memsz{0};	/* curr. size of allocated memory */
+  unsigned char big_endian:1{0};
+  unsigned char binary:1{0};
+  unsigned char gzapi:1{0};
+  unsigned char memapi:1{0};
+  unsigned char unicode:1{0};
+  unsigned char unicode_checked:1{0};
+  unsigned char is_pipe:1{0};
+  gbfclearerr_cb fileclearerr{nullptr};
+  gbfclose_cb fileclose{nullptr};
+  gbfeof_cb fileeof{nullptr};
+  gbferror_cb fileerror{nullptr};
+  gbfflush_cb fileflush{nullptr};
+  gbfopen_cb fileopen{nullptr};
+  gbfread_cb fileread{nullptr};
+  gbfseek_cb fileseek{nullptr};
+  gbftell_cb filetell{nullptr};
+  gbfungetc_cb fileungetc{nullptr};
+  gbfwrite_cb filewrite{nullptr};
 };
 
 
-gbfile* gbfopen(const QString& filename, const char* mode, const char* module);
-gbfile* gbfopen_be(const QString& filename, const char* mode, const char* module);
-inline gbfile* gbfopen_le(const QString& filename, const char* mode, const char* module)
+gbfile* gbfopen(const QString& filename, const char* mode);
+gbfile* gbfopen_be(const QString& filename, const char* mode);
+inline gbfile* gbfopen_le(const QString& filename, const char* mode)
 {
-  return gbfopen(filename, mode, module);
+  return gbfopen(filename, mode);
 }
 void gbfclose(gbfile* file);
 
