@@ -81,7 +81,7 @@ DWORD mkspeed(unsigned br)
     return 230400;
 #endif
   default:
-    fatal("Unsupported serial speed: %d\n", br);
+    gbFatal("Unsupported serial speed: %d\n", br);
     return 0;   /* keep compiler happy */
   }
 }
@@ -227,15 +227,15 @@ int gbser_set_port(void* handle, unsigned speed, unsigned bits, unsigned parity,
   DCB tio;
 
   if (bits < 5 || bits > 8) {
-    fatal("Unsupported bits setting: %d\n", bits);
+    gbFatal("Unsupported bits setting: %d\n", bits);
   }
 
   if (parity > 2) {
-    fatal("Unsupported parity setting: %d\n", parity);
+    gbFatal("Unsupported parity setting: %d\n", parity);
   }
 
   if (stop < 1 || stop > 2) {
-    fatal("Unsupported stop setting: %d\n", stop);
+    gbFatal("Unsupported stop setting: %d\n", stop);
   }
 
   tio.DCBlength = sizeof(DCB);
