@@ -35,14 +35,13 @@
 #include <QtGlobal>                 // for Q_UNUSED, qPrintable, foreach
 
 #include <cmath>                    // for fabs
-#include <cstdio>                   // for printf, SEEK_SET
-#include <cstdlib>                  // for strtol
+#include <cstdio>                   // for SEEK_SET
 #include <cstring>                  // for memset, strstr, strcmp
 #include <iterator>                 // for next
 
-#include "defs.h"                   // for Waypoint, warning, route_head, fatal, UrlLink, bounds, UrlList, unknown_alt, xfree, waypt_add_to_bounds, waypt_init_bounds, xstrtoi, route_add_wpt, route_disp_all, waypt_bounds_valid, xmalloc, gb_color, WaypointList, find_wa...
+#include "defs.h"                   // for Waypoint, gbWarning, route_head, gbFatal, UrlLink, bounds, UrlList, unknown_alt, xfree, waypt_add_to_bounds, waypt_init_bounds, route_add_wpt, route_disp_all, waypt_bounds_valid, xmalloc, gb_color, WaypointList, find_wa...
 #include "formspec.h"               // for FormatSpecificDataList
-#include "garmin_fs.h"              // for garmin_fs_t, garmin_ilink_t, garmin_fs_alloc
+#include "garmin_fs.h"              // for garmin_fs_t, garmin_ilink_t
 #include "garmin_tables.h"          // for gt_waypt_class_map_point, gt_color_index_by_rgb, gt_color_value, gt_waypt_classes_e, gt_find_desc_from_icon_number, gt_find_icon_number_from_desc, gt_gdb_display_mode_symbol, gt_get_icao_country, gt_waypt_class_user_waypoint, GDB, gt_display_mode_symbol
 #include "gbfile.h"                 // for gbfgetint32, gbfputint32, gbfgetc, gbfread, gbfwrite, gbfgetdbl, gbfputc, gbfgetcstr, gbfclose, gbfgetnativecstr, gbfopen_le, gbfputint16, gbfile, gbfcopyfrom, gbfputcstr, gbfrewind, gbfseek, gbftell, gbfgetcstr_old, gbfgetint16, gbfgetuint32, gbfputdbl
 #include "grtcirc.h"                // for RAD, gcdist, radtometers
@@ -51,32 +50,30 @@
 #include "src/core/datetime.h"      // for DateTime
 
 
-#define MYNAME "gdb"
-
 #define GDB_DEF_CLASS		gt_waypt_class_user_waypoint
 #define GDB_DEF_HIDDEN_CLASS	gt_waypt_class_map_point
 
-#define GDB_DBG_WPT		1
-#define GDB_DBG_RTE		2
-#define GDB_DBG_TRK		4
+constexpr unsigned int GDB_DBG_WPT = 1;
+constexpr unsigned int GDB_DBG_RTE = 2;
+constexpr unsigned int GDB_DBG_TRK = 4;
 
-#define GDB_DBG_WPTe		8
-#define GDB_DBG_RTEe		16
-#define GDB_DBG_TRKe		32
+constexpr unsigned int GDB_DBG_WPTe = 8;
+constexpr unsigned int GDB_DBG_RTEe = 16;
+//constexpr unsigned int GDB_DBG_TRKe = 32;
 
-#define GDB_DEBUG		(GDB_DBG_WPTe) /* | GDB_DBG_RTE) */
-#undef GDB_DEBUG
-// #define GDB_DEBUG 0xff
+//constexpr unsigned int GDB_DEBUG = (GDB_DBG_WPTe) /* | GDB_DBG_RTE) */;
+//constexpr unsigned int GDB_DEBUG = 0xff;
+constexpr unsigned int GDB_DEBUG = 0x00;
 
 #define DBG(a, b)		if ((GDB_DEBUG & (a)) && (b))
 
 
-inline bool operator==(const GdbFormat::WptNameKey& lhs, const GdbFormat::WptNameKey &rhs) noexcept
+inline bool operator==(const GdbFormat::WptNameKey& lhs, const GdbFormat::WptNameKey& rhs) noexcept
 {
   return lhs.shortname.compare(rhs.shortname, Qt::CaseInsensitive) == 0;
 }
 
-inline bool operator==(const GdbFormat::WptNamePosnKey& lhs, const GdbFormat::WptNamePosnKey &rhs) noexcept
+inline bool operator==(const GdbFormat::WptNamePosnKey& lhs, const GdbFormat::WptNamePosnKey& rhs) noexcept
 {
   return
     (lhs.shortname.compare(rhs.shortname, Qt::CaseInsensitive) == 0) &&
@@ -100,43 +97,29 @@ GdbFormat::gdb_flush_waypt_queue(WptNamePosnHash& Q)
   Q = WptNamePosnHash();
 }
 
-#if GDB_DEBUG
 void
 GdbFormat::disp_summary(const gbfile* f) const
 {
-  int i, len;
+  if constexpr(GDB_DEBUG) {
+    int len = strlen(gbLogCStr(f->name));
 
-  len = strlen(f->name);
+    gbWarning("%s\n", QByteArray(len + 21, '=').constData());
 
-  warning(MYNAME ": =====================");
-  for (i = 0; i < len; i++) {
-    warning("=");
+    gbWarning("%s summary for \"%s\"\n",
+              (f->mode == 'r') ? "Reader" : "Writer", gbLogCStr(f->name));
+
+    gbWarning("%s\n", QByteArray(len + 21, '-').constData());
+
+    gbWarning("%d waypoint(s)\n", waypt_ct - waypth_ct);
+    gbWarning("%d hidden waypoint(s)\n", waypth_ct);
+    gbWarning("%d route(s) with total %d point(s)\n", rte_ct, rtept_ct);
+    gbWarning("%d track(s) with total %d point(s)\n", trk_ct, trkpt_ct);
+
+    gbWarning("%s\n", QByteArray(len + 21, '-').constData());
+  } else {
+    Q_UNUSED(f);
   }
-  warning("\n" MYNAME ": %s summary for \"%s\"\n",
-          (f->mode == 'r') ? "Reader" : "Writer", f->name);
-
-  warning(MYNAME ": ---------------------");
-  for (i = 0; i < len; i++) {
-    warning("-");
-  }
-
-  warning("\n" MYNAME ": %d waypoint(s)\n", waypt_ct - waypth_ct);
-  warning(MYNAME ": %d hidden waypoint(s)\n", waypth_ct);
-  warning(MYNAME ": %d route(s) with total %d point(s)\n", rte_ct, rtept_ct);
-  warning(MYNAME ": %d track(s) with total %d point(s)\n", trk_ct, trkpt_ct);
-  warning(MYNAME ": ---------------------");
-
-  for (i = 0; i < len; i++) {
-    warning("-");
-  }
-  warning("\n");
 }
-#else
-void
-GdbFormat::disp_summary(const gbfile* /* f */) const
-{
-}
-#endif
 
 /*******************************************************************************/
 /* TOOLS AND MACROS FOR THE READER */
@@ -258,15 +241,13 @@ GdbFormat::gdb_add_route_waypt(route_head* rte, Waypoint* ref, const int wpt_cla
     /* At this point we have found a waypoint with same name,
        but probably from another data stream. Check coordinates!
     */
-    double dist = radtometers(gcdist(
-                                RAD(ref->latitude), RAD(ref->longitude),
-                                RAD(tmp->latitude), RAD(tmp->longitude)));
+    double dist = radtometers(gcdist(ref->position(), tmp->position()));
 
     if (fabs(dist) > 100) {
-      fatal(MYNAME ": Route point mismatch!\n" \
-            "  \"%s\" from waypoints differs to \"%s\"\n" \
-            "  from route table by more than %0.1f meters!\n", \
-            qPrintable(tmp->shortname), qPrintable(ref->shortname), dist);
+      gbFatal("Route point mismatch!\n" \
+              "  \"%s\" from waypoints differs to \"%s\"\n" \
+              "  from route table by more than %0.1f meters!\n", \
+              gbLogCStr(tmp->shortname), gbLogCStr(ref->shortname), dist);
     }
   }
   Waypoint* res = nullptr;
@@ -385,28 +366,28 @@ GdbFormat::read_file_header()
   	misinterpreted.
   */
   if (strcmp(buf, "MsRcf") != 0) {
-    fatal(MYNAME ": Invalid file \"%s\"!", fin->name);
+    gbFatal("Invalid file \"%s\"!\n", gbLogCStr(fin->name));
   }
 
   int reclen = FREAD_i32;
   Q_UNUSED(reclen);
   QByteArray drec = FREAD_STR();
   if (drec.at(0) != 'D') {
-    fatal(MYNAME ": Invalid file \"%s\"!", fin->name);
+    gbFatal("Invalid file \"%s\"!\n", gbLogCStr(fin->name));
   }
 
   gdb_ver = drec.at(1) - 'k' + 1;
   if ((gdb_ver < kGDBVerMin) || (gdb_ver > kGDBVerMax)) {
-    fatal(MYNAME ": Unknown or/and unsupported GDB version (%d.0)!", gdb_ver);
+    gbFatal("Unknown or/and unsupported GDB version (%d.0)!\n", gdb_ver);
   }
 
   if (global_opts.verbose_status > 0) {
-    printf(MYNAME ": Reading Garmin GPS Database version %d.0\n", gdb_ver);
+    gbInfo("Reading Garmin GPS Database version %d.0\n", gdb_ver);
   }
 
   reclen = FREAD_i32;
   if (reclen + 1 > int(sizeof(buf))) {
-    fatal(MYNAME ": Invalid record length\n");
+    gbFatal("Invalid record length\n");
   }
   (void) FREAD(buf, reclen + 1);
   if (global_opts.verbose_status > 0) {
@@ -416,12 +397,12 @@ GdbFormat::read_file_header()
     } else if (strstr(name, "neaderhi") == nullptr) {
       name = "MapSource BETA";
     }
-    warning(MYNAME ": File created with \"%s\"\n", name);
+    gbWarning("File created with \"%s\"\n", name);
   }
 
   QByteArray applicationField = FREAD_STR();
   if (!((applicationField == "MapSource") || (applicationField == "BaseCamp"))) {
-    fatal(MYNAME ": Not a recognized signature in header");
+    gbFatal("Not a recognized signature in header\n");
   }
 }
 
@@ -440,7 +421,7 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
   waypt_ct++;
   res = new Waypoint;
 
-  gmsd = garmin_fs_alloc(-1);
+  gmsd = new garmin_fs_t(-1);
   res->fs.FsChainAdd(gmsd);
   res->shortname = fread_cstr();
   wpt_class = (gt_waypt_classes_e) FREAD_i32;
@@ -467,41 +448,41 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
     double alt = FREAD_DBL;
     if (alt < 1.0e24) {
       res->altitude = alt;
-#if GDB_DEBUG
-      DBG(GDB_DBG_WPTe, true)
-      printf(MYNAME "-wpt \"%s\" (%d): Altitude = %.1f\n",
-             qPrintable(res->shortname), wpt_class, alt);
-#endif
+      if constexpr(GDB_DEBUG) {
+        DBG(GDB_DBG_WPTe, true)
+        gbDebug("wpt \"%s\" (%d): Altitude = %.1f\n",
+                gbLogCStr(res->shortname), wpt_class, alt);
+      }
     }
   }
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPT, true)
-  printf(MYNAME "-wpt \"%s\": coordinates = %c%0.6f %c%0.6f\n",
-         qPrintable(res->shortname),
-         res->latitude < 0 ? 'S' : 'N', res->latitude,
-         res->longitude < 0 ? 'W' : 'E', res->longitude);
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPT, true)
+    gbDebug("wpt \"%s\": coordinates = %c%0.6f %c%0.6f\n",
+            gbLogCStr(res->shortname),
+            res->latitude < 0 ? 'S' : 'N', res->latitude,
+            res->longitude < 0 ? 'W' : 'E', res->longitude);
+  }
   res->notes = fread_cstr();
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPTe, !res->notes.isNull())
-  printf(MYNAME "-wpt \"%s\" (%d): notes = %s\n",
-         qPrintable(res->shortname), wpt_class,
-         qPrintable(QString(res->notes).replace("\r\n", ", ")));
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPTe, !res->notes.isNull())
+    gbDebug("wpt \"%s\" (%d): notes = %s\n",
+            gbLogCStr(res->shortname), wpt_class,
+            gbLogCStr(QString(res->notes).replace("\r\n", ", ")));
+  }
   if (FREAD_C == 1) {
     res->set_proximity(FREAD_DBL);
-#if GDB_DEBUG
-    DBG(GDB_DBG_WPTe, res->proximity_has_value())
-    printf(MYNAME "-wpt \"%s\" (%d): Proximity = %.1f\n",
-           qPrintable(res->shortname), wpt_class, res->proximity_value() / 1000);
-#endif
+    if constexpr(GDB_DEBUG) {
+      DBG(GDB_DBG_WPTe, res->proximity_has_value())
+      gbDebug("wpt \"%s\" (%d): Proximity = %.1f\n",
+              gbLogCStr(res->shortname), wpt_class, res->proximity_value() / 1000);
+    }
   }
   int display = FREAD_i32;
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPTe, true)
-  printf(MYNAME "-wpt \"%s\" (%d): display = %d\n",
-         qPrintable(res->shortname), wpt_class, display);
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPTe, true)
+    gbDebug("wpt \"%s\" (%d): display = %d\n",
+            gbLogCStr(res->shortname), wpt_class, display);
+  }
   switch (display) {			/* display value */
   case gt_gdb_display_mode_symbol:
     display = gt_display_mode_symbol;
@@ -526,11 +507,11 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
 
   if (FREAD_C == 1) {
     res->set_depth(FREAD_DBL);
-#if GDB_DEBUG
-    DBG(GDB_DBG_WPTe, res->depth_has_value())
-    printf(MYNAME "-wpt \"%s\" (%d): Depth = %.1f\n",
-           qPrintable(res->shortname), wpt_class, res->depth_value());
-#endif
+    if constexpr(GDB_DEBUG) {
+      DBG(GDB_DBG_WPTe, res->depth_has_value())
+      gbDebug("wpt \"%s\" (%d): Depth = %.1f\n",
+              gbLogCStr(res->shortname), wpt_class, res->depth_value());
+    }
   }
 
   /* VERSION DEPENDENT CODE */
@@ -545,14 +526,14 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
       FREAD(buf, 2);
     }
 
-#if GDB_DEBUG
-    QString temp = FREAD_CSTR_AS_QSTR;				/* undocumented & unused string */
-    DBG(GDB_DBG_WPTe, !temp.isEmpty())
-    printf(MYNAME "-wpt \"%s\" (%d): Unknown string = %s\n",
-           qPrintable(res->shortname), wpt_class, qPrintable(temp));
-#else
-    (void) FREAD_CSTR_AS_QSTR;				/* undocumented & unused string */
-#endif
+    if constexpr(GDB_DEBUG) {
+      QString temp = FREAD_CSTR_AS_QSTR;				/* undocumented & unused string */
+      DBG(GDB_DBG_WPTe, !temp.isEmpty())
+      gbDebug("wpt \"%s\" (%d): Unknown string = %s\n",
+              gbLogCStr(res->shortname), wpt_class, gbLogCStr(temp));
+    } else {
+      (void) FREAD_CSTR_AS_QSTR;				/* undocumented & unused string */
+    }
 
     QString linky = FREAD_CSTR_AS_QSTR;
     UrlLink l(linky);
@@ -575,51 +556,51 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
     if (wpt_class == gt_waypt_class_map_intersection || wpt_class == gt_waypt_class_map_line) {
       garmin_fs_t::set_duration(gmsd, duration);
       res->notes = QStringLiteral("[%1]").arg(gdb_to_ISO8601_duration(duration));
-#if GDB_DEBUG
-      DBG(GDB_DBG_WPTe, true)
-      printf(MYNAME "-wpt \"%s\" (%d): duration = %u\n",
-             qPrintable(res->shortname), wpt_class, duration);
-#endif
+      if constexpr(GDB_DEBUG) {
+        DBG(GDB_DBG_WPTe, true)
+        gbDebug("wpt \"%s\" (%d): duration = %u\n",
+                gbLogCStr(res->shortname), wpt_class, duration);
+      }
     }
     int url_ct = FREAD_i32;
     for (int i = url_ct; (i); i--) {
       QString str = FREAD_CSTR_AS_QSTR;
       if (!str.isEmpty()) {
         waypt_add_url(res, str, nullptr);
-#if GDB_DEBUG
-        DBG(GDB_DBG_WPTe, true)
-        printf(MYNAME "-wpt \"%s\" (%d): url(%d) = %s\n",
-               qPrintable(res->shortname), wpt_class, url_ct - i, qPrintable(str));
-#endif
+        if constexpr(GDB_DEBUG) {
+          DBG(GDB_DBG_WPTe, true)
+          gbDebug("wpt \"%s\" (%d): url(%d) = %s\n",
+                  gbLogCStr(res->shortname), wpt_class, url_ct - i, gbLogCStr(str));
+        }
       }
     }
   }
 
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPTe, !res->description.isNull())
-  printf(MYNAME "-wpt \"%s\" (%d): description = %s\n",
-         qPrintable(res->shortname), wpt_class, qPrintable(res->description));
-  DBG(GDB_DBG_WPTe, res->urls.HasUrlLink())
-  printf(MYNAME "-wpt \"%s\" (%d): url = %s\n",
-         qPrintable(res->shortname), wpt_class, qPrintable(res->urls.GetUrlLink().url_));
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPTe, !res->description.isNull())
+    gbDebug("wpt \"%s\" (%d): description = %s\n",
+            gbLogCStr(res->shortname), wpt_class, gbLogCStr(res->description));
+    DBG(GDB_DBG_WPTe, res->urls.HasUrlLink())
+    gbDebug("wpt \"%s\" (%d): url = %s\n",
+            gbLogCStr(res->shortname), wpt_class, gbLogCStr(res->urls.GetUrlLink().url_));
+  }
   int category = FREAD_i16;
   if (category != 0) {
     garmin_fs_t::set_category(gmsd, category);
   }
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPTe, category)
-  printf(MYNAME "-wpt \"%s\" (%d): category = %d\n",
-         qPrintable(res->shortname), wpt_class, category);
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPTe, category)
+    gbDebug("wpt \"%s\" (%d): category = %d\n",
+            gbLogCStr(res->shortname), wpt_class, category);
+  }
 
   if (FREAD_C == 1) {
     res->set_temperature(FREAD_DBL);
-#if GDB_DEBUG
-    DBG(GDB_DBG_WPTe, res->temperature_has_value())
-    printf(MYNAME "-wpt \"%s\" (%d): temperature = %.1f\n",
-           qPrintable(res->shortname), wpt_class, res->temperature_value());
-#endif
+    if constexpr(GDB_DEBUG) {
+      DBG(GDB_DBG_WPTe, res->temperature_has_value())
+      gbDebug("wpt \"%s\" (%d): temperature = %.1f\n",
+              gbLogCStr(res->shortname), wpt_class, res->temperature_value());
+    }
   }
 
   /* VERSION DEPENDENT CODE */
@@ -644,11 +625,11 @@ GdbFormat::read_waypoint(gt_waypt_classes_e* waypt_class_out)
 
   res->icon_descr = gt_find_desc_from_icon_number(icon, GDB);
 
-#if GDB_DEBUG
-  DBG(GDB_DBG_WPTe, icon != kGDBDefIcon)
-  printf(MYNAME "-wpt \"%s\" (%d): icon = \"%s\" (MapSource symbol %d)\n",
-         qPrintable(res->shortname), wpt_class, qPrintable(res->icon_descr), icon);
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_WPTe, icon != kGDBDefIcon)
+    gbDebug("wpt \"%s\" (%d): icon = \"%s\" (MapSource symbol %d)\n",
+            gbLogCStr(res->shortname), wpt_class, gbLogCStr(res->icon_descr), icon);
+  }
   QString str;
   if (!(str = garmin_fs_t::get_cc(gmsd, nullptr)).isEmpty()) {
     if (!(garmin_fs_t::has_country(gmsd))) {
@@ -697,11 +678,11 @@ GdbFormat::read_route()
 
   int points = FREAD_i32;
 
-#if GDB_DEBUG
-  DBG(GDB_DBG_RTE, true)
-  printf(MYNAME "-rte \"%s\": loading route with %d point(s)...\n",
-         qPrintable(rte->rte_name), points);
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_RTE, true)
+    gbDebug("rte \"%s\": loading route with %d point(s)...\n",
+            gbLogCStr(rte->rte_name), points);
+  }
 
   for (int i = 0; i < points; i++) {
     char buf[128];
@@ -727,59 +708,50 @@ GdbFormat::read_route()
     if ((buf[0] != 0x00) && (buf[0] != 0x01) && (buf[0] != 0x03)) {
       warnings++;
       if (warnings > 3) {
-        fatal(MYNAME "-rte_pt \"%s\": too many warnings!\n", qPrintable(wpt->shortname));
+        gbFatal("rte_pt \"%s\": too many warnings!\n", gbLogCStr(wpt->shortname));
       }
-      warning(MYNAME "-rte_pt \"%s\" (class %d): possible error in route.\n", qPrintable(wpt->shortname), wpt_class);
-      warning(MYNAME "-rte_pt (dump):");
+      gbWarning("rte_pt \"%s\" (class %d): possible error in route.\n", gbLogCStr(wpt->shortname), wpt_class);
+      gbWarning("rte_pt (dump):");
       for (int idx = 0; idx < 18; idx++) {
-        warning(" %02x", (unsigned char)buf[idx]);
+        gbWarning(" %02x", (unsigned char)buf[idx]);
       }
-      warning("\n");
+      gbWarning("\n");
     }
 
     int links = FREAD_i32;
-    garmin_ilink_t* il_anchor = nullptr;
-    garmin_ilink_t* il_root = nullptr;
-#if GDB_DEBUG
-    DBG(GDB_DBG_RTE, links)
-    printf(MYNAME "-rte_pt \"%s\" (%d): %d interlink step(s)\n",
-           qPrintable(wpt->shortname), wpt_class, links);
-#endif
+    QList<garmin_ilink_t> il_list;
+    if constexpr(GDB_DEBUG) {
+      DBG(GDB_DBG_RTE, links)
+      gbDebug("rte_pt \"%s\" (%d): %d interlink step(s)\n",
+              gbLogCStr(wpt->shortname), wpt_class, links);
+    }
     for (int j = 0; j < links; j++) {
-      auto* il_step = (garmin_ilink_t*) xmalloc(sizeof(garmin_ilink_t));
+      garmin_ilink_t il_step;
 
-      il_step->ref_count = 1;
-
-      il_step->lat = FREAD_LATLON;
-      il_step->lon = FREAD_LATLON;
+      il_step.lat = FREAD_LATLON;
+      il_step.lon = FREAD_LATLON;
       if (FREAD_C == 1) {
-        il_step->alt = FREAD_DBL;
+        il_step.alt = FREAD_DBL;
       } else {
-        il_step->alt = unknown_alt;
+        il_step.alt = unknown_alt;
       }
 
       if (j == 0) {
-        wpt->latitude = il_step->lat;
-        wpt->longitude = il_step->lon;
-        wpt->altitude = il_step->alt;
+        wpt->latitude = il_step.lat;
+        wpt->longitude = il_step.lon;
+        wpt->altitude = il_step.alt;
       }
 
-      il_step->next = nullptr;
-      if (il_anchor == nullptr) {
-        il_root = il_step;
-      } else {
-        il_anchor->next = il_step;
-      }
-      il_anchor = il_step;
+      il_list.append(il_step);
 
-#if GDB_DEBUG
-      DBG(GDB_DBG_RTEe, true) {
-        printf(MYNAME "-rte_il \"%s\" (%d of %d): %c%0.6f %c%0.6f\n",
-               qPrintable(wpt->shortname), j + 1, links,
-               il_step->lat < 0 ? 'S' : 'N', il_step->lat,
-               il_step->lon < 0 ? 'W' : 'E', il_step->lon);
+      if constexpr(GDB_DEBUG) {
+        DBG(GDB_DBG_RTEe, true) {
+          gbDebug("rte_il \"%s\" (%d of %d): %c%0.6f %c%0.6f\n",
+                  gbLogCStr(wpt->shortname), j + 1, links,
+                  il_step.lat < 0 ? 'S' : 'N', il_step.lat,
+                  il_step.lon < 0 ? 'W' : 'E', il_step.lon);
+        }
       }
-#endif
     }
 
     bounds bounds;
@@ -806,11 +778,11 @@ GdbFormat::read_route()
         wpt = new Waypoint(*tmp);
       } else {
         if (waypt_bounds_valid(&bounds)) {
-          warning(MYNAME ": (has bounds)\n");
+          gbWarning("(has bounds)\n");
         }
 
-        warning(MYNAME ": Data corruption detected!\n");
-        fatal(MYNAME ": Sleeping route point without coordinates!\n");
+        gbWarning("Data corruption detected!\n");
+        gbFatal("Sleeping route point without coordinates!\n");
       }
     }
 
@@ -821,30 +793,24 @@ GdbFormat::read_route()
         FREAD(buf, 2);
       }
     }
-#if GDB_DEBUG
-    DBG(GDB_DBG_RTE, true)
-    printf(MYNAME "-rte_pt \"%s\": coordinates = %c%0.6f, %c%0.6f\n",
-           qPrintable(wpt->shortname),
-           wpt->latitude < 0 ? 'S' : 'N', wpt->latitude,
-           wpt->longitude < 0 ? 'W' : 'E', wpt->longitude);
-#endif
+    if constexpr(GDB_DEBUG) {
+      DBG(GDB_DBG_RTE, true)
+      gbDebug("rte_pt \"%s\": coordinates = %c%0.6f, %c%0.6f\n",
+              gbLogCStr(wpt->shortname),
+              wpt->latitude < 0 ? 'S' : 'N', wpt->latitude,
+              wpt->longitude < 0 ? 'W' : 'E', wpt->longitude);
+    }
     wpt = gdb_add_route_waypt(rte, wpt, wpt_class);
     if (wpt != nullptr) {
       garmin_fs_t* gmsd = garmin_fs_t::find(wpt);
       if (gmsd == nullptr) {
-        gmsd = garmin_fs_alloc(-1);
+        gmsd = new garmin_fs_t(-1);
         wpt->fs.FsChainAdd(gmsd);
       }
       garmin_fs_t::set_wpt_class(gmsd, wpt_class);
-      gmsd->ilinks = il_root;
-      il_root = nullptr;
+      gmsd->ilinks = il_list;
     }
 
-    while (il_root) {
-      garmin_ilink_t* il = il_root;
-      il_root = il_root->next;
-      xfree(il);
-    }
   } /* ENDFOR: for (i = 0; i < points; i++) */
 
   /* VERSION DEPENDENT CODE */
@@ -869,19 +835,19 @@ GdbFormat::read_route()
       driving_speed[3] = FREAD_DBL;
       driving_speed[4] = FREAD_DBL;
       FREAD(tbuf, 8); /* unknown bytes */
-#if GDB_DEBUG
-      DBG(GDB_DBG_RTE, true)
-      printf(MYNAME "-rte_pt: autoroute info: route style %d, calculation type %d, vehicle type %d, road selection %d\n"
-             "                            driving speeds (kph) %.0f, %.0f, %.0f, %.0f, %.0f\n",
-             route_style, calc_type, vehicle_type, road_selection,
-             driving_speed[0], driving_speed[1], driving_speed[2], driving_speed[3], driving_speed[4]);
-#else
-      Q_UNUSED(route_style);
-      Q_UNUSED(calc_type);
-      Q_UNUSED(vehicle_type);
-      Q_UNUSED(road_selection);
-      Q_UNUSED(driving_speed);
-#endif
+      if constexpr(GDB_DEBUG) {
+        DBG(GDB_DBG_RTE, true)
+        gbDebug("rte_pt: autoroute info: route style %d, calculation type %d, vehicle type %d, road selection %d\n"
+                "                            driving speeds (kph) %.0f, %.0f, %.0f, %.0f, %.0f\n",
+                route_style, calc_type, vehicle_type, road_selection,
+                driving_speed[0], driving_speed[1], driving_speed[2], driving_speed[3], driving_speed[4]);
+      } else {
+        Q_UNUSED(route_style);
+        Q_UNUSED(calc_type);
+        Q_UNUSED(vehicle_type);
+        Q_UNUSED(road_selection);
+        Q_UNUSED(driving_speed);
+      }
     }
 
     rte->rte_desc = fread_cstr();
@@ -950,11 +916,11 @@ GdbFormat::read_track()
   } else { /* if (gdb_ver <= kGDBVer2) */
     res->rte_urls.AddUrlLink(UrlLink(FREAD_CSTR_AS_QSTR));
   }
-#if GDB_DEBUG
-  DBG(GDB_DBG_TRK, res->rte_urls.HasUrlLink())
-  printf(MYNAME "-trk \"%s\": url = %s\n",
-         qPrintable(res->rte_name), qPrintable(res->rte_urls.GetUrlLink().url_));
-#endif
+  if constexpr(GDB_DEBUG) {
+    DBG(GDB_DBG_TRK, res->rte_urls.HasUrlLink())
+    gbDebug("trk \"%s\": url = %s\n",
+            gbLogCStr(res->rte_name), gbLogCStr(res->rte_urls.GetUrlLink().url_));
+  }
   return res;
 }
 
@@ -963,8 +929,8 @@ GdbFormat::read_track()
 void
 GdbFormat::rd_init(const QString& fname)
 {
-  fin = gbfopen_le(fname, "rb", MYNAME);
-  ftmp = gbfopen_le(nullptr, "wb", MYNAME);
+  fin = gbfopen_le(fname, "rb");
+  ftmp = gbfopen_le(nullptr, "wb");
   read_file_header();
 
   waypt_nameposn_in_hash.clear();
@@ -1007,11 +973,12 @@ GdbFormat::read()
     char typ;
     gt_waypt_classes_e wpt_class;
     Waypoint* wpt;
-    route_head* trk, *rte;
+    route_head* trk;
+    route_head* rte;
 
     int len = FREAD_i32;
     if (FREAD(&typ, 1) < 1) {
-      fatal(MYNAME ": Attempt to read past EOF.");
+      gbFatal("Attempt to read past EOF.\n");
     }
     if (typ == 'V') {
       break;  /* break the loop */
@@ -1060,7 +1027,7 @@ GdbFormat::read()
 
     int delta = len - gbftell(ftmp);
     if (delta > 1000000) {
-      fatal("Internal consistency error.  Delta too big");
+      gbFatal("Internal consistency error.  Delta too big\n");
     }
 
     // Avoid finite loop on bogus beta files from '06.
@@ -1069,26 +1036,26 @@ GdbFormat::read()
 
     if (dump && delta) {
       if (! incomplete++) {
-        warning(MYNAME ":==========================================\n");
-        warning(MYNAME ":===          W A R N I N G             ===\n");
+        gbWarning("==========================================\n");
+        gbWarning("===          W A R N I N G             ===\n");
       }
       if (typ == 'W')
-        warning(MYNAME ":(%d%c-%02d): delta = %d (flag=%3d/%02x)-",
-                gdb_ver, typ, wpt_class, delta, waypt_flag, waypt_flag);
+        gbWarning("(%d%c-%02d): delta = %d (flag=%3d/%02x)-",
+                  gdb_ver, typ, wpt_class, delta, waypt_flag, waypt_flag);
       else {
-        warning(MYNAME ":(%d%c): delta = %d -", gdb_ver, typ, delta);
+        gbWarning("(%d%c): delta = %d -", gdb_ver, typ, delta);
       }
       if (delta > 0) {
         char* buf = (char*) xmalloc(delta);
         if (FREAD(buf, delta) < 1) {
-          fatal(MYNAME ": Attempt to read past EOF.\n");
+          gbFatal("Attempt to read past EOF.\n");
         }
         for (int i = 0; i < delta; i++) {
-          warning(" %02x", (unsigned char)buf[i]);
+          gbWarning(" %02x", (unsigned char)buf[i]);
         }
         xfree(buf);
       }
-      warning("\n");
+      gbWarning("\n");
     }
 
     fin = fsave;
@@ -1096,13 +1063,13 @@ GdbFormat::read()
 
 
   if (incomplete) {
-    warning(MYNAME ":------------------------------------------\n");
-    warning(MYNAME ": \"%s\"\n", fin->name);
-    warning(MYNAME ":------------------------------------------\n");
-    warning(MYNAME ":       Please mail this information\n");
-    warning(MYNAME "     and, if you can, the used GDB file\n");
-    warning(MYNAME ":  to gpsbabel-misc@lists.sourceforge.net\n");
-    warning(MYNAME ":==========================================\n");
+    gbWarning("------------------------------------------\n");
+    gbWarning("\"%s\"\n", gbLogCStr(fin->name));
+    gbWarning("------------------------------------------\n");
+    gbWarning("Please mail this information\n");
+    gbWarning("and, if you can, the used GDB file\n");
+    gbWarning("to gpsbabel-misc@lists.sourceforge.net\n");
+    gbWarning("==========================================\n");
   }
 }
 
@@ -1143,14 +1110,14 @@ GdbFormat::write_header()
   fout = ftmp;
   FWRITE_i16(605); // program version 6.5 -> 6*100 + 5
 
-   /*
-    * This is our "Watermark" to show this file was created by GPSbabel.
-    * The date/time used to be from CVS, and may be from git in the future.
-    */
-  static const QDateTime gdb_release_dt = QDateTime(QDate(2011, 4, 14), QTime(1, 30, 1), Qt::UTC);
+  /*
+   * This is our "Watermark" to show this file was created by GPSbabel.
+   * The date/time used to be from CVS, and may be from git in the future.
+   */
+  static const QDateTime gdb_release_dt = QDateTime(QDate(2011, 4, 14), QTime(1, 30, 1), QtUTC);
   gdb_write_cstr(QStringLiteral("GPSBabel-%1").arg(gpsbabel_version));
-  gdb_write_cstr(gdb_release_dt.toString("MMM dd yyyy"));
-  gdb_write_cstr(gdb_release_dt.toString("HH:mm:ss"));
+  gdb_write_cstr(gdb_release_dt.toString(u"MMM dd yyyy"));
+  gdb_write_cstr(gdb_release_dt.toString(u"HH:mm:ss"));
 
   finalize_item(fsave, 'A');
 
@@ -1168,36 +1135,18 @@ GdbFormat::write_header()
 void
 GdbFormat::gdb_check_waypt(Waypoint* wpt)
 {
-  double lat_orig = wpt->latitude;
-  double lon_orig = wpt->longitude;
-
-  if (wpt->latitude < -90) {
-    wpt->latitude += 180;
-  } else if (wpt->latitude > +90) {
-    wpt->latitude -= 180;
-  }
-  if (wpt->longitude < -180) {
-    wpt->longitude += 360;
-  } else if (wpt->longitude > +180) {
-    wpt->longitude -= 360;
-  }
-
-  if ((wpt->latitude < -90) || (wpt->latitude > 90.0))
-    fatal("Invalid latitude %f in waypoint %s.\n",
-          lat_orig, !wpt->shortname.isEmpty() ? qPrintable(wpt->shortname) : "<no name>");
-  if ((wpt->longitude < -180) || (wpt->longitude > 180.0))
-    fatal("Invalid longitude %f in waypoint %s.\n",
-          lon_orig, !wpt->shortname.isEmpty() ? qPrintable(wpt->shortname) : "<no name>");
+  wpt->NormalizePosition();
 }
 
 /*-----------------------------------------------------------------------------*/
 
 void
 GdbFormat::write_waypoint(
-  const Waypoint* wpt, const QString& shortname, garmin_fs_t* gmsd,
+  const Waypoint* wpt, const QString& shortname, const garmin_fs_t* gmsd,
   const int icon, const int display)
 {
-  char zbuf[32], ffbuf[32];
+  char zbuf[32];
+  char ffbuf[32];
 
   waypt_ct++;	/* increase informational number of written waypoints */
 
@@ -1250,7 +1199,7 @@ GdbFormat::write_waypoint(
     FWRITE(zbuf, 4);
     QString ld;
     if (wpt->HasUrlLink()) {
-      UrlLink l = wpt->GetUrlLink();
+      const UrlLink& l = wpt->GetUrlLink();
       ld = l.url_;
     }
     QString descr = (wpt_class < gt_waypt_class_map_point) ?
@@ -1266,7 +1215,7 @@ GdbFormat::write_waypoint(
     QString str;
 
     if (wpt_class < gt_waypt_class_map_point) {	/* street address */
-      str  = garmin_fs_t::get_addr(gmsd, "");
+      str = garmin_fs_t::get_addr(gmsd, "");
     } else {
       str = "";
     }
@@ -1350,7 +1299,8 @@ void
 GdbFormat::write_route(const route_head* rte, const QString& rte_name)
 {
   bounds bounds;
-  char zbuf[32], ffbuf[32];
+  char zbuf[32];
+  char ffbuf[32];
 
   memset(zbuf, 0, sizeof(zbuf));
   memset(ffbuf, 0xFF, sizeof(ffbuf));
@@ -1364,23 +1314,22 @@ GdbFormat::write_route(const route_head* rte, const QString& rte_name)
   int points = rte->rte_waypt_ct();
   FWRITE_i32(points);
 
-  int index = 0;
-
-  for (auto it =rte->waypoint_list.cbegin(); it != rte->waypoint_list.cend(); ++it) {
+  for (auto begin = rte->waypoint_list.cbegin(), end = rte->waypoint_list.cend(), it = begin;
+       it != end; ++it) {
 
+    bool firstpass = it == begin;
     Waypoint* wpt = *it;
-    Waypoint* next = nullptr;
-    if (index < points) {
-      next = *std::next(it);
-    }
 
-    index++;
+    auto next_it = std::next(it);
+    bool lastpass = next_it == end;
+    Waypoint* next = lastpass? nullptr : *next_it;
+
     rtept_ct++;	/* increase informational number of written route points */
 
-    if (index == 1) {
+    if (firstpass) {
       gdb_check_waypt(wpt);
     }
-    if (index < points) {
+    if (!lastpass) {
       gdb_check_waypt(next);
     }
 
@@ -1388,10 +1337,10 @@ GdbFormat::write_route(const route_head* rte, const QString& rte_name)
     if (test != nullptr) {
       wpt = test;
     } else {
-      fatal(MYNAME ": Sorry, that should never happen!!!\n");
+      gbFatal("Sorry, that should never happen!!!\n");
     }
 
-    garmin_fs_t* gmsd = garmin_fs_t::find(wpt);
+    const garmin_fs_t* gmsd = garmin_fs_t::find(wpt);
 
     /* extra_data may contain a modified shortname */
     gdb_write_cstr((wpt->extra_data) ? *static_cast<QString*>(wpt->extra_data) : wpt->shortname);
@@ -1418,10 +1367,10 @@ GdbFormat::write_route(const route_head* rte, const QString& rte_name)
     FWRITE(ffbuf, 4);
     FWRITE(zbuf, 10);
 
-    if (index == points) {
+    if (lastpass) {
       FWRITE_i32(0);		/* no more steps */
       FWRITE_C(1);		/* skip bounds */
-    } else { /* if (index < points) */
+    } else { /* !last_pass */
       FWRITE_i32(2);		/* two interstep links */
 
       FWRITE_LATLON(wpt->latitude);
@@ -1540,7 +1489,7 @@ GdbFormat::write_waypoint_cb(const Waypoint* refpt)
   Waypoint* test = gdb_find_wayptq(waypt_nameposn_out_hash, refpt);
 
   if (refpt->HasUrlLink() && test && test->HasUrlLink() && route_flag == 0) {
-    UrlLink orig_link = refpt->GetUrlLink();
+    const UrlLink& orig_link = refpt->GetUrlLink();
     UrlLink test_link = test->GetUrlLink();
     if (orig_link.url_ != test_link.url_) {
       test = nullptr;
@@ -1564,7 +1513,7 @@ GdbFormat::write_waypoint_cb(const Waypoint* refpt)
     fout = ftmp;
 
     /* prepare the waypoint */
-    garmin_fs_t* gmsd = garmin_fs_t::find(wpt);
+    const garmin_fs_t* gmsd = garmin_fs_t::find(wpt);
 
     int wpt_class = garmin_fs_t::get_wpt_class(gmsd, -1);
     if (wpt_class == -1) {
@@ -1670,21 +1619,21 @@ GdbFormat::write_track_cb(const route_head* trk)
 void
 GdbFormat::wr_init(const QString& fname)
 {
-  fout = gbfopen_le(fname, "wb", MYNAME);
-  ftmp = gbfopen_le(nullptr, "wb", MYNAME);
+  fout = gbfopen_le(fname, "wb");
+  ftmp = gbfopen_le(nullptr, "wb");
 
-  gdb_category = (gdb_opt_category) ? xstrtoi(gdb_opt_category, nullptr, 10) : 0;
-  gdb_ver = (gdb_opt_ver && *gdb_opt_ver) ? xstrtoi(gdb_opt_ver, nullptr, 10) : 0;
+  gdb_category = gdb_opt_category ? gdb_opt_category.get_result() : 0;
+  gdb_ver = gdb_opt_ver.get_result();
 
   if (gdb_category) {
     if ((gdb_category < 1) || (gdb_category > 16)) {
-      fatal(MYNAME ": cat must be between 1 and 16!");
+      gbFatal("cat must be between 1 and 16!\n");
     }
     gdb_category = 1 << (gdb_category - 1);
   }
 
   if (gdb_opt_bitcategory) {
-    gdb_category = strtol(gdb_opt_bitcategory, nullptr, 0);
+    gdb_category = gdb_opt_bitcategory.get_result();
   }
 
   waypt_nameposn_out_hash.clear();
@@ -1712,9 +1661,6 @@ GdbFormat::wr_deinit()
 void
 GdbFormat::write()
 {
-  if (gdb_opt_ver) {
-    gdb_ver = xstrtoi(gdb_opt_ver, nullptr, 10);
-  }
   write_header();
 
   reset_short_handle("WPT");
