@@ -36,7 +36,6 @@
  */
 
 #include <cstdint>
-#include <cstdio>               // for printf
 #include <cstdlib>              // for free, malloc
 
 #include <QByteArray>           // for QByteArray
@@ -45,7 +44,6 @@
 #include <QString>              // for QString
 #include <QTime>                // for QTime
 #include <QTimeZone>            // for QTimeZone
-#include <Qt>                   // for LocalTime
 #include <QtGlobal>             // for qPrintable
 
 #include "defs.h"
@@ -55,16 +53,14 @@
 #include "src/core/datetime.h"  // for DateTime
 
 
-#define MYNAME "GlobalsatSport"
-
 void
 GlobalsatSportFormat::serial_init(const char* fname)
 {
   if (serial_handle = gbser_init(fname), nullptr == serial_handle) {
-    fatal(MYNAME ": Can't open port '%s'\n", fname);
+    gbFatal("Can't open port '%s'\n", fname);
   }
   if (gbser_set_speed(serial_handle, 115200) != gbser_OK) {
-    fatal(MYNAME ": Can't configure port '%s'\n", fname);
+    gbFatal("Can't configure port '%s'\n", fname);
   }
   // Toss anything that came in before our speed was set
   gbser_flush(serial_handle);
@@ -74,12 +70,12 @@ void
 GlobalsatSportFormat::serial_deinit()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " serial_deinit()\n");
+    gbDebug("serial_deinit()\n");
   }
   gbser_deinit(serial_handle);
   serial_handle = nullptr;
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " serial_deinit() Done\n");
+    gbDebug("serial_deinit() Done\n");
   }
 }
 
@@ -90,25 +86,25 @@ GlobalsatSportFormat::serial_recv_byte() const
   int result = gbser_readc_wait(serial_handle, 4000);
   switch (result) {
   case gbser_ERROR:
-    fatal("serial_recv_byte(): error reading one byte\n");
+    gbFatal("serial_recv_byte(): error reading one byte\n");
     break;
   case gbser_NOTHING:
-    fatal("serial_recv_byte(): read timeout\n");
+    gbFatal("serial_recv_byte(): read timeout\n");
     break;
   }
   return result;
 }
 
 void
-GlobalsatSportFormat::serial_write_byte(uint8_t byte) const
+GlobalsatSportFormat::serial_write_byte(uint8_t byte)
 {
   if (global_opts.debug_level > 1) {
-    printf("0x%02x (%d), ", byte, byte);
+    gbDebug("0x%02x (%d), ", byte, byte);
   }
 
   int n = gbser_writec(serial_handle, byte);
   if (n == gbser_ERROR) {
-    fatal("globalsat_probe_device(): write failed\n");
+    gbFatal("globalsat_probe_device(): write failed\n");
   }
 }
 
@@ -122,7 +118,7 @@ GlobalsatSportFormat::recv_byte()
   } else {
     result = gbfgetc(in_file);
     if (result < 0) {
-      fatal(MYNAME ": read error");
+      gbFatal("read error\n");
     }
   }
   // Check if byte should be dumped also into a file
@@ -177,7 +173,7 @@ GlobalsatSportFormat::globalsat_write_package(uint8_t* payload, uint32_t size)
   }
   write_byte(crc);
   if (global_opts.debug_level > 1) {
-    printf("\n");
+    gbDebug("\n");
   }
 }
 
@@ -189,7 +185,7 @@ GlobalsatSportFormat::globalsat_read_package(int* out_length, uint8_t* out_Devic
 
   uint8_t DeviceCommand = recv_byte();
   if (global_opts.debug_level > 1) {
-    printf("DeviceCommand: 0x%02x ", DeviceCommand);
+    gbDebug("DeviceCommand: 0x%02x ", DeviceCommand);
   }
   uint8_t len_h = recv_byte();
   calc_crc ^= len_h;
@@ -198,7 +194,7 @@ GlobalsatSportFormat::globalsat_read_package(int* out_length, uint8_t* out_Devic
 
   int length = (len_h << 8) + len_l;
   if (global_opts.debug_level > 1) {
-    printf("len=%d Payload:", length);
+    gbDebug("len=%d Payload:", length);
   }
 
   auto* payload = (uint8_t*) malloc(length);
@@ -213,7 +209,7 @@ GlobalsatSportFormat::globalsat_read_package(int* out_length, uint8_t* out_Devic
 
   crc = recv_byte();
   if (global_opts.debug_level > 1) {
-    printf("crc=0x%x should be=0x%x\n", crc, calc_crc);
+    gbDebug("crc=0x%x should be=0x%x\n", crc, calc_crc);
   }
   if (crc == calc_crc) {
     *out_DeviceCommand = DeviceCommand;
@@ -251,7 +247,7 @@ GlobalsatSportFormat::globalsat_probe_device()
   uint8_t* payload = globalsat_read_package(&len, &DeviceCommand);
   if ((len > 0) && (payload != nullptr)) {
     if (global_opts.debug_level > 1) {
-      printf("Got package!!!\n");
+      gbDebug("Got package!!!\n");
     }
     //TODO figure out what device it is if we start to support more devices then gh625XT
   }
@@ -265,15 +261,15 @@ void
 GlobalsatSportFormat::rd_init(const QString& fname)
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " rd_init()\n");
+    gbDebug("rd_init()\n");
   }
   if (opt_dump_file) {
-    dumpfile = gbfopen(opt_dump_file, "wb", MYNAME);
+    dumpfile = gbfopen(opt_dump_file, "wb");
     if (!dumpfile) {
-      printf(MYNAME " rd_init() creating dumpfile %s FAILED continue anyway\n", opt_dump_file);
+      gbWarning("rd_init() creating dumpfile %s FAILED continue anyway\n", gbLogCStr(opt_dump_file));
     } else {
       if (global_opts.debug_level > 1) {
-        printf(MYNAME " rd_init() creating dumpfile %s for writing binary copy of serial stream\n", opt_dump_file);
+        gbDebug("rd_init() creating dumpfile %s for writing binary copy of serial stream\n", gbLogCStr(opt_dump_file));
       }
     }
   }
@@ -281,18 +277,18 @@ GlobalsatSportFormat::rd_init(const QString& fname)
     serial_init(qPrintable(fname));
   } else {
     // read from dump-file instead of serial
-    in_file = gbfopen(fname, "rb", MYNAME);
+    in_file = gbfopen(fname, "rb");
     if (!in_file) {
-      fatal("Could not open dumpfile for input: %s", qPrintable(fname));
+      gbFatal("Could not open dumpfile for input: %s\n", gbLogCStr(fname));
     }
 
   }
   if (opt_timezone) {
-    if (QTimeZone::isTimeZoneIdAvailable(opt_timezone)) {
-      timezn = new QTimeZone(opt_timezone);
+    if (QTimeZone::isTimeZoneIdAvailable(opt_timezone.get().toUtf8())) {
+      timezn = new QTimeZone(opt_timezone.get().toUtf8());
     } else {
       list_timezones();
-      fatal(MYNAME ": Requested time zone \"%s\" not available.\n", opt_timezone);
+      gbFatal("Requested time zone \"%s\" not available.\n", gbLogCStr(opt_timezone));
     }
   } else {
     timezn = nullptr;
@@ -304,7 +300,7 @@ void
 GlobalsatSportFormat::rd_deinit()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " rd_deinit()\n");
+    gbDebug("rd_deinit()\n");
   }
   if (!opt_input_dump_file) {
     serial_deinit();
@@ -322,7 +318,7 @@ GlobalsatSportFormat::rd_deinit()
     timezn = nullptr;
   }
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " rd_deinit() Done\n");
+    gbDebug("rd_deinit() Done\n");
   }
 }
 
@@ -330,7 +326,7 @@ void
 GlobalsatSportFormat::waypoint_read()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME "   waypoint_read()\n");
+    gbDebug("  waypoint_read()\n");
   }
   //CommandGetTrackFileHeaders
   globalsat_send_simple(CommandGetWaypoints);
@@ -340,7 +336,7 @@ GlobalsatSportFormat::waypoint_read()
   uint8_t* in_payload = globalsat_read_package(&len, &DeviceCommand);
   if ((len > 0) && (in_payload != nullptr)) {
     if (global_opts.debug_level > 1) {
-      printf("Got package!!!\n");
+      gbDebug("Got package!!!\n");
     }
   }
   if (in_payload) {
@@ -353,12 +349,12 @@ void
 GlobalsatSportFormat::track_read()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME "   track_read()\n");
+    gbDebug("  track_read()\n");
   }
   //CommandGetTrackFileHeaders
   globalsat_send_simple(CommandGetTrackFileHeaders);
   if (global_opts.debug_level > 1) {
-    printf("Sent...\n");
+    gbDebug("Sent...\n");
   }
 
   int length;
@@ -366,12 +362,12 @@ GlobalsatSportFormat::track_read()
   uint8_t* payload = globalsat_read_package(&length, &DeviceCommand);
   if ((length > 0) && (payload != nullptr)) {
     if (global_opts.debug_level > 1) {
-      printf("Got package!!! headers\n");
+      gbDebug("Got package!!! headers\n");
     }
     //payload is packed with a number of trainingheaders with the size of 29bytes each
     int number_headers = length / 29;	//29=packed sizeof(gh_trainheader)
     if (global_opts.debug_level > 1) {
-      printf("length=%d sizeof(gh_trainheader)=%d number_headers=%d\n", length, 29, number_headers);
+      gbDebug("length=%d sizeof(gh_trainheader)=%d number_headers=%d\n", length, 29, number_headers);
     }
 
     for (int i = 0; i < number_headers; i++) {
@@ -393,17 +389,17 @@ GlobalsatSportFormat::track_read()
       th_header.DataType = th_hdr[28];
 
       if (showlist || global_opts.debug_level > 1) {
-        printf("Track[%02i]: %02d-%02d-%02d ", i, th_header.dateStart.Year, th_header.dateStart.Month, th_header.dateStart.Day);
-        printf("%02d:%02d:%02d ", th_header.timeStart.Hour, th_header.timeStart.Minute, th_header.timeStart.Second);
+        gbDebug("Track[%02i]: %02d-%02d-%02d ", i, th_header.dateStart.Year, th_header.dateStart.Month, th_header.dateStart.Day);
+        gbDebug("%02d:%02d:%02d ", th_header.timeStart.Hour, th_header.timeStart.Minute, th_header.timeStart.Second);
         int time_s=th_header.TotalTime / 10;
         int time_h=time_s/(60*60);
         time_s-=time_h*(60*60);
         int time_m=time_s/60;
         time_s-=time_m*60;
-        printf("Points:%6u Time:%02d:%02d:%02d Dist:%9um LapCnts:%5d ", th_header.TotalPoint, time_h, time_m, time_s, th_header.TotalDistance, th_header.LapCnts);
-        printf("Index/StartPt:%u ", th_header.gh_ptrec.Index);
-        printf("LapIndex/EndPt:%u ", th_header.gh_laprec.LapIndex);
-        printf("DataType:0x%x\n", th_header.DataType);
+        gbDebug("Points:%6u Time:%02d:%02d:%02d Dist:%9um LapCnts:%5d ", th_header.TotalPoint, time_h, time_m, time_s, th_header.TotalDistance, th_header.LapCnts);
+        gbDebug("Index/StartPt:%u ", th_header.gh_ptrec.Index);
+        gbDebug("LapIndex/EndPt:%u ", th_header.gh_laprec.LapIndex);
+        gbDebug("DataType:0x%x\n", th_header.DataType);
       }
 
       if (!showlist) {
@@ -432,7 +428,7 @@ GlobalsatSportFormat::track_read()
         int track_length;
         uint8_t* track_payload = globalsat_read_package(&track_length, &trackDeviceCommand);
         if ((track_length == 0) || (track_payload == nullptr)) {
-          fatal(MYNAME ": track length is 0 bytes or payload nonexistent.\n");
+          gbFatal("track length is 0 bytes or payload nonexistent.\n");
         }
         //      printf("Got track package!!! Train data\n");
 
@@ -470,12 +466,12 @@ GlobalsatSportFormat::track_read()
         db_train.Sport5 = dbtrain[57];
 
         if (global_opts.debug_level > 1) {
-          printf("\nTrainData:%02d-%02d-%02d ", db_train.dateStart.Year, db_train.dateStart.Month, db_train.dateStart.Day);
-          printf("%02d:%02d:%02d ", db_train.timeStart.Hour, db_train.timeStart.Minute, db_train.timeStart.Second);
-          printf("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", db_train.TotalPoint, db_train.TotalTime / 10, db_train.TotalDistance, db_train.LapCnts);
-          printf("Index/StartPt:%u ", db_train.gh_ptrec.Index);
-          printf("LapIndex/EndPt:%u ", db_train.gh_laprec.LapIndex);
-          printf("MultiSport:0x%x ", db_train.MultiSport);
+          gbDebug("\nTrainData:%02d-%02d-%02d ", db_train.dateStart.Year, db_train.dateStart.Month, db_train.dateStart.Day);
+          gbDebug("%02d:%02d:%02d ", db_train.timeStart.Hour, db_train.timeStart.Minute, db_train.timeStart.Second);
+          gbDebug("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", db_train.TotalPoint, db_train.TotalTime / 10, db_train.TotalDistance, db_train.LapCnts);
+          gbDebug("Index/StartPt:%u ", db_train.gh_ptrec.Index);
+          gbDebug("LapIndex/EndPt:%u ", db_train.gh_laprec.LapIndex);
+          gbDebug("MultiSport:0x%x ", db_train.MultiSport);
         }
         int total_laps = db_train.LapCnts;
         int total_laps_left = total_laps;
@@ -489,7 +485,7 @@ GlobalsatSportFormat::track_read()
           globalsat_send_simple(CommandGetNextTrackSection);
           track_payload = globalsat_read_package(&track_length, &trackDeviceCommand);
           if ((track_length == 0) || (track_payload == nullptr)) {
-            fatal(MYNAME ": track length is 0 bytes or payload nonexistent.\n");
+            gbFatal("track length is 0 bytes or payload nonexistent.\n");
           }
           //	printf("Got track package!!! Laps data\n");
 
@@ -511,12 +507,12 @@ GlobalsatSportFormat::track_read()
 
 
           if (global_opts.debug_level > 1) {
-            printf("Lap Trainheader: %02d-%02d-%02d ", header.dateStart.Year, header.dateStart.Month, header.dateStart.Day);
-            printf("%02d:%02d:%02d ", header.timeStart.Hour, header.timeStart.Minute, header.timeStart.Second);
-            printf("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", header.TotalPoint, header.TotalTime / 10, header.TotalDistance, header.LapCnts);
-            printf("Index/StartPt:%u ", header.gh_ptrec.Index);
-            printf("LapIndex/EndPt:%u ", header.gh_laprec.LapIndex);
-            printf("DataType:0x%x\n", header.DataType);
+            gbDebug("Lap Trainheader: %02d-%02d-%02d ", header.dateStart.Year, header.dateStart.Month, header.dateStart.Day);
+            gbDebug("%02d:%02d:%02d ", header.timeStart.Hour, header.timeStart.Minute, header.timeStart.Second);
+            gbDebug("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", header.TotalPoint, header.TotalTime / 10, header.TotalDistance, header.LapCnts);
+            gbDebug("Index/StartPt:%u ", header.gh_ptrec.Index);
+            gbDebug("LapIndex/EndPt:%u ", header.gh_laprec.LapIndex);
+            gbDebug("DataType:0x%x\n", header.DataType);
           }
 
           /*
@@ -529,7 +525,7 @@ GlobalsatSportFormat::track_read()
           if (timezn != nullptr) {
             gpsDateTime = gpsbabel::DateTime(QDateTime(gpsDate, gpsTime, *timezn).toUTC());
           } else {
-            gpsDateTime = gpsbabel::DateTime(QDateTime(gpsDate, gpsTime, Qt::LocalTime).toUTC());
+            gpsDateTime = gpsbabel::DateTime(QDateTime(gpsDate, gpsTime, QtLocalTime).toUTC());
           }
 
           int laps_in_package = header.gh_laprec.LapIndex - header.gh_ptrec.Index + 1;
@@ -557,13 +553,13 @@ GlobalsatSportFormat::track_read()
             db_lap.EndPt = be_read32(dblap+37);
 
             if (global_opts.debug_level > 1) {
-              printf("     lap[%d] AccruedTime:%us TotalTime:%us TotalDist:%um", lap, db_lap.AccruedTime, db_lap.TotalTime / 10, db_lap.TotalDistance);
-              printf(" Calory:%d MaxSpeed:%u Hearth max:%d avg:%d ", db_lap.Calory, db_lap.MaxSpeed, db_lap.MaxHeart, db_lap.AvgHeart);
-              printf(" Alt min:%d max:%d", db_lap.MinAlti, db_lap.MaxAlti);
-              printf(" Cadns avg:%d best:%d", db_lap.AvgCadns, db_lap.BestCadns);
-              printf(" Power avg:%d Max:%d", db_lap.AvgPower, db_lap.MaxPower);
-              printf(" MultisportIndex:%d", db_lap.MultiSportIndex);
-              printf(" StartPt:%u EndPt:%u\n", db_lap.StartPt, db_lap.EndPt);
+              gbDebug("     lap[%d] AccruedTime:%us TotalTime:%us TotalDist:%um", lap, db_lap.AccruedTime, db_lap.TotalTime / 10, db_lap.TotalDistance);
+              gbDebug(" Calory:%d MaxSpeed:%u Hearth max:%d avg:%d ", db_lap.Calory, db_lap.MaxSpeed, db_lap.MaxHeart, db_lap.AvgHeart);
+              gbDebug(" Alt min:%d max:%d", db_lap.MinAlti, db_lap.MaxAlti);
+              gbDebug(" Cadns avg:%d best:%d", db_lap.AvgCadns, db_lap.BestCadns);
+              gbDebug(" Power avg:%d Max:%d", db_lap.AvgPower, db_lap.MaxPower);
+              gbDebug(" MultisportIndex:%d", db_lap.MultiSportIndex);
+              gbDebug(" StartPt:%u EndPt:%u\n", db_lap.StartPt, db_lap.EndPt);
             }
           }
           free(track_payload);
@@ -601,12 +597,12 @@ GlobalsatSportFormat::track_read()
 
 
             if (global_opts.debug_level > 1) {
-              printf("Lap Trainheader: %02d-%02d-%02d ", laptrain_header.dateStart.Year, laptrain_header.dateStart.Month, laptrain_header.dateStart.Day);
-              printf("%02d:%02d:%02d ", laptrain_header.timeStart.Hour, laptrain_header.timeStart.Minute, laptrain_header.timeStart.Second);
-              printf("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", laptrain_header.TotalPoint, laptrain_header.TotalTime / 10, laptrain_header.TotalDistance, laptrain_header.LapCnts);
-              printf("StartPt:%u ", laptrain_header.gh_ptrec.StartPt);
-              printf("EndPt:%u ", laptrain_header.gh_laprec.EndPt);
-              printf("DataType:0x%x\n", laptrain_header.DataType);
+              gbDebug("Lap Trainheader: %02d-%02d-%02d ", laptrain_header.dateStart.Year, laptrain_header.dateStart.Month, laptrain_header.dateStart.Day);
+              gbDebug("%02d:%02d:%02d ", laptrain_header.timeStart.Hour, laptrain_header.timeStart.Minute, laptrain_header.timeStart.Second);
+              gbDebug("Total(points:%6u time:%6us dist:%9um) LapCnts:%5d ", laptrain_header.TotalPoint, laptrain_header.TotalTime / 10, laptrain_header.TotalDistance, laptrain_header.LapCnts);
+              gbDebug("StartPt:%u ", laptrain_header.gh_ptrec.StartPt);
+              gbDebug("EndPt:%u ", laptrain_header.gh_laprec.EndPt);
+              gbDebug("DataType:0x%x\n", laptrain_header.DataType);
             }
 
             int recpoints_in_package = laptrain_header.gh_laprec.EndPt - laptrain_header.gh_ptrec.StartPt + 1;
@@ -633,10 +629,10 @@ GlobalsatSportFormat::track_read()
               //   qDebug() << "DateTime2:" << gpsDateTime.toString();
               // }
               if (global_opts.debug_level > 1) {
-                printf("     recpoint[%2d] Lat:%f Long:%f Alt:%dm", recpoint, (double)((int32_t) point.Latitude) / 1000000.0, (double)((int32_t) point.Longitude) / 1000000.0, point.Altitude);
-                printf(" Speed:%f HR:%d", (double) point.Speed / 100, point.HeartRate);
-                printf(" Time:%u Cadence:%d", point.IntervalTime, point.Cadence);
-                printf(" PwrCadense:%d Power:%d\n", point.PwrCadence, point.Power);
+                gbDebug("     recpoint[%2d] Lat:%f Long:%f Alt:%dm", recpoint, (double)((int32_t) point.Latitude) / 1000000.0, (double)((int32_t) point.Longitude) / 1000000.0, point.Altitude);
+                gbDebug(" Speed:%f HR:%d", (double) point.Speed / 100, point.HeartRate);
+                gbDebug(" Time:%u Cadence:%d", point.IntervalTime, point.Cadence);
+                gbDebug(" PwrCadense:%d Power:%d\n", point.PwrCadence, point.Power);
               }
 
               auto* wpt = new Waypoint(); // waypt_new();
@@ -668,7 +664,7 @@ void
 GlobalsatSportFormat::route_read()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME "   route_read() TODO\n");
+    gbDebug("route_read() TODO\n");
   }
 }
 
@@ -676,7 +672,7 @@ void
 GlobalsatSportFormat::read()
 {
   if (global_opts.debug_level > 1) {
-    printf(MYNAME " read()\n");
+    gbDebug("read()\n");
   }
 
   if (global_opts.masked_objective & WPTDATAMASK) {
@@ -690,6 +686,6 @@ GlobalsatSportFormat::read()
   }
   if (!(global_opts.masked_objective &
         (WPTDATAMASK | TRKDATAMASK | RTEDATAMASK | POSNDATAMASK))) {
-    fatal(MYNAME ": Nothing to do.\n");
+    gbFatal("Nothing to do.\n");
   }
 }
