@@ -36,6 +36,16 @@ QT_TRANSLATE_NOOP("core","Source for name field in .dbf")
 QT_TRANSLATE_NOOP("core","Source for URL field in .dbf")
 QT_TRANSLATE_NOOP("core","ESRI shapefile")
 QT_TRANSLATE_NOOP("core","(integer sec or 'auto') Barograph to GPS time diff")
+QT_TRANSLATE_NOOP("core","Engine Noise (ENL; default=1)")
+QT_TRANSLATE_NOOP("core","True Airspeed (TAS; default=1)")
+QT_TRANSLATE_NOOP("core","Total Energy Vario (VAT; default=1)")
+QT_TRANSLATE_NOOP("core","Outside Air Temperature (OAT; default=1)")
+QT_TRANSLATE_NOOP("core","True Track (TRT; default=0)")
+QT_TRANSLATE_NOOP("core","Ground Speed (GSP; default=1)")
+QT_TRANSLATE_NOOP("core","Fix Accuracy (FXA; default=1)")
+QT_TRANSLATE_NOOP("core","# Of Sats (SIU; default=0)")
+QT_TRANSLATE_NOOP("core","Z Acceleration (ACZ; default=1)")
+QT_TRANSLATE_NOOP("core","G Force? (GFO; default=0)")
 QT_TRANSLATE_NOOP("core","FAI/IGC Flight Recorder Data Format")
 QT_TRANSLATE_NOOP("core","Read all points even if latitude or longitude is missing")
 QT_TRANSLATE_NOOP("core","Attempt to recovery data from corrupt file")
@@ -114,7 +124,6 @@ QT_TRANSLATE_NOOP("core","Write course rather than history, default yes")
 QT_TRANSLATE_NOOP("core","Sport: Biking (deflt), Running, MultiSport, Other")
 QT_TRANSLATE_NOOP("core","Garmin Training Center (.tcx/.crs/.hst/.xml)")
 QT_TRANSLATE_NOOP("core","Default icon name")
-QT_TRANSLATE_NOOP("core","Omit Placer name")
 QT_TRANSLATE_NOOP("core","Geocaching.com .loc")
 QT_TRANSLATE_NOOP("core","Compact Output. Default is off.")
 QT_TRANSLATE_NOOP("core","GeoJson")
@@ -125,7 +134,6 @@ QT_TRANSLATE_NOOP("core","Erase device data after download")
 QT_TRANSLATE_NOOP("core","Only erase device data, do not download anything")
 QT_TRANSLATE_NOOP("core","GlobalSat DG-200 Download")
 QT_TRANSLATE_NOOP("core","list tracks")
-QT_TRANSLATE_NOOP("core","get track")
 QT_TRANSLATE_NOOP("core","Dump raw data to this file")
 QT_TRANSLATE_NOOP("core","Dump raw data to this file")
 QT_TRANSLATE_NOOP("core","Time zone ID")
@@ -279,6 +287,15 @@ QT_TRANSLATE_NOOP("core","Unit used in proximity values")
 QT_TRANSLATE_NOOP("core","codec to use for reading and writing strings (default windows-1252)")
 QT_TRANSLATE_NOOP("core","OziExplorer")
 QT_TRANSLATE_NOOP("core","Qstarz BL-1000")
+QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
+QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
+QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
+QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
+QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
+QT_TRANSLATE_NOOP("core","Use shortname instead of description")
+QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
+QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
+QT_TRANSLATE_NOOP("core","See You flight analysis data")
 QT_TRANSLATE_NOOP("core","Erase device data after download")
 QT_TRANSLATE_NOOP("core","Set location finder target location as lat,lng")
 QT_TRANSLATE_NOOP("core","Configure logging parameter as tmin:tmax:dmin:dmax")
