@@ -22,18 +22,23 @@
 //------------------------------------------------------------------------
 
 #include "filterdata.h"
+#include <QChar>    // for QChar
+#include <QDate>    // for QDate
+#include <QTime>    // for QTime
+#include <QVector>  // for QVector
 
-QStringList WayPtsFilterData::makeOptionString()
+QStringList WayPtsFilterData::makeOptionString() const
 {
   QStringList args;
   if (!inUse_) {
     return args;
   }
 
+  static const QVector<QString> radius_units = {"mi", "km"};
   if (radius) {
     args << QString("-x");
     args << QString("radius,distance=%1%2,lat=%3,lon=%4")
-         .arg(radiusVal).arg("MK"[radiusUnit]).arg(latVal, 0, 'f', 8).arg(longVal, 0, 'f', 8);
+         .arg(radiusVal).arg(radius_units.at(radiusUnit)).arg(latVal, 0, 'f', 8).arg(longVal, 0, 'f', 8);
   }
   if (duplicates && (shortNames || locations)) {
     args << QString("-x");
@@ -47,9 +52,10 @@ QStringList WayPtsFilterData::makeOptionString()
     args << s;
   }
 
+  static const QVector<QString> position_units = {"ft", "m"};
   if (position) {
     args << QString("-x");
-    args << QString("position,distance=%1%2").arg(positionVal).arg("FM"[positionUnit]);
+    args << QString("position,distance=%1%2").arg(positionVal).arg(position_units.at(positionUnit));
   }
   return args;
 }
@@ -72,7 +78,7 @@ static QString optionDate(const QDateTime& dt)
 }
 
 //------------------------------------------------------------------------
-QStringList TrackFilterData::makeOptionString()
+QStringList TrackFilterData::makeOptionString() const
 {
   QStringList args;
   if (!inUse_) {
@@ -145,7 +151,7 @@ QStringList TrackFilterData::makeOptionString()
 }
 
 //------------------------------------------------------------------------
-QStringList RtTrkFilterData::makeOptionString()
+QStringList RtTrkFilterData::makeOptionString() const
 {
   QStringList args;
   if (!inUse_) {
@@ -163,7 +169,7 @@ QStringList RtTrkFilterData::makeOptionString()
 }
 
 //------------------------------------------------------------------------
-QStringList MiscFltFilterData::makeOptionString()
+QStringList MiscFltFilterData::makeOptionString() const
 {
   QStringList args;
   if (!inUse_) {
