@@ -36,6 +36,10 @@
 #include <QString>           // for QString
 #include <QWidget>           // for QWidget
 
+#include <memory>            // for unique_ptr
+#include <utility>           // for move
+#include <vector>            // for vector
+
 #include "filterdata.h"      // for MiscFltFilterData, RtTrkFilterData, TrackFilterData, WayPtsFilterData
 #include "ui_miscfltui.h"    // for Ui_MiscFltWidget
 #include "ui_rttrkui.h"      // for Ui_RtTrkWidget
@@ -56,9 +60,8 @@ public:
     fixWhatsThis();
   }
   CheckEnabler(QObject* parent, QAbstractButton* ck, QList<QWidget*>& wl):
-    QObject(parent), checkBox(ck)
+    QObject(parent), checkBox(ck), widgetList(wl)
   {
-    widgetList = wl;
     connect(ck, &QAbstractButton::clicked, this, &CheckEnabler::checkStatusChanged);
     checkStatusChanged();
     fixWhatsThis();
@@ -104,8 +107,14 @@ private:
 class FilterOption
 {
 public:
-  FilterOption() {}
-  virtual ~FilterOption() {}
+  FilterOption() = default;
+  /* Reference data members C.12 */
+  FilterOption(const FilterOption &) = delete;
+  FilterOption &operator=(const FilterOption &) = delete;
+  FilterOption(FilterOption &&) = delete;
+  FilterOption &operator=(FilterOption &&) = delete;
+  virtual ~FilterOption() = default;
+
   virtual void setWidgetValue() = 0;
   virtual void getWidgetValue() = 0;
 };
@@ -117,11 +126,11 @@ public:
   BoolFilterOption(bool& b, QAbstractButton* ck):  b(b), checkBox(ck)
   {
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     checkBox->setChecked(b);
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     b = checkBox->isChecked();
   }
@@ -139,11 +148,11 @@ public:
   {
     sb->setRange(bottom, top);
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     spinBox->setValue(val);
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     val = spinBox->value();
   }
@@ -160,11 +169,11 @@ public:
   StringFilterOption(QString& val, QLineEdit* le):  val(val), lineEdit(le)
   {
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     lineEdit->setText(val);
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     val = lineEdit->text();
   }
@@ -188,11 +197,11 @@ public:
   {
     le->setValidator(new QDoubleValidator(minVal, maxVal, decimals, le));
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     lineEdit->setText(QString("%1").arg(val, 0, format, decimals));
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     val = lineEdit->text().toDouble();
     val = qMin(val, maxVal);
@@ -214,11 +223,11 @@ public:
   DateTimeFilterOption(QDateTime& val, QDateTimeEdit* w):  val(val), w(w)
   {
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     w->setDateTime(val);
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     val = w->dateTime();
   }
@@ -235,11 +244,11 @@ public:
   ComboFilterOption(int& val, QComboBox* w):  val(val), w(w)
   {
   }
-  void setWidgetValue()
+  void setWidgetValue() override
   {
     w->setCurrentIndex(val);
   }
-  void getWidgetValue()
+  void getWidgetValue() override
   {
     val = w->currentIndex();
   }
@@ -255,25 +264,25 @@ class FilterWidget: public QWidget
 {
 public:
   FilterWidget(QWidget* parent) : QWidget(parent) {}
-  ~FilterWidget()
-  {
-    for (int i=0; i<fopts.size(); i++) {
-      delete fopts[i];
-    }
-  }
 
   void getWidgetValues()
   {
-    for (int i=0; i<fopts.size(); i++) {
-      fopts[i]->getWidgetValue();
+    for (const auto& fopt : fopts) {
+      fopt->getWidgetValue();
     }
   }
   void setWidgetValues()
   {
-    for (int i=0; i<fopts.size(); i++) {
-      fopts[i]->setWidgetValue();
+    for (const auto& fopt : fopts) {
+      fopt->setWidgetValue();
     }
   }
+
+  void addFilterOption(std::unique_ptr<FilterOption> fo)
+  {
+    fopts.push_back(std::move(fo));
+  }
+
   void addCheckEnabler(QAbstractButton* ck, QWidget* w)
   {
     enbls << new CheckEnabler(this, ck, w);
@@ -289,20 +298,28 @@ public:
     }
   }
 
-protected:
-  QList <FilterOption*> fopts;
+private:
+  std::vector<std::unique_ptr<FilterOption>> fopts;
   QList <CheckEnabler*> enbls;
 };
 
 //------------------------------------------------------------------------
 
-class TrackWidget: public FilterWidget
+class TrackWidget final: public FilterWidget
 {
   Q_OBJECT
 public:
   TrackWidget(QWidget* parent, TrackFilterData& tf);
 
-  virtual void checkChecks()
+  /* Since the TrackWidget ctor calls virtual function checkChecks() we must
+   * not derive a class from TrackWidget. To prevent this possiblity
+   * we mark TrackWidget final.
+   * "warning: Call to virtual method 'TrackWidget::checkChecks' during
+   * construction bypasses virtual dispatch
+   * [clang-analyzer-optin.cplusplus.VirtualCall]"
+   * https://www.artima.com/articles/never-call-virtual-functions-during-construction-or-destruction
+   */
+  void checkChecks() override
   {
     otherCheckX();
     FilterWidget::checkChecks();
@@ -314,11 +331,11 @@ private:
 
 private slots:
   void mergeCheckX();
-  void otherCheckX();
+  void otherCheckX() const;
   void splitDateX();
   void splitTimeX();
   void splitDistanceX();
-  void TZX();
+  void TZX() const;
   void packCheckX();
 };
 
@@ -334,8 +351,8 @@ private:
   WayPtsFilterData& wfd;
 
 private slots:
-  void locationsCkX();
-  void shortNamesCkX();
+  void locationsCkX() const;
+  void shortNamesCkX() const;
 };
 
 //------------------------------------------------------------------------
@@ -343,7 +360,7 @@ class RtTrkWidget: public FilterWidget
 {
   Q_OBJECT
 public:
-  RtTrkWidget(QWidget* parent, RtTrkFilterData& wf);
+  RtTrkWidget(QWidget* parent, RtTrkFilterData& rfd);
 
 private:
   Ui_RtTrkWidget ui;
@@ -354,11 +371,10 @@ class MiscFltWidget: public FilterWidget
 {
   Q_OBJECT
 public:
-  MiscFltWidget(QWidget*, MiscFltFilterData&);
+  MiscFltWidget(QWidget* parent, MiscFltFilterData& mfd);
 
 private:
   Ui_MiscFltWidget ui;
   MiscFltFilterData& mfd;
 };
-
 #endif
