@@ -16,7 +16,7 @@ p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;$babelfeversion$&lt;/p&gt;
-&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009-2023 Robert Lipe&lt;/p&gt;
+&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009-2024 Robert Lipe&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GUI designed and contributed by S. Khai Mong&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
@@ -38,7 +38,7 @@ p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;$babelfeversion$&lt;/p&gt;
-&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009-2022 Robert Lipe&lt;/p&gt;
+&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009-2023 Robert Lipe&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GUI designed and contributed by S. Khai Mong&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
@@ -192,12 +192,12 @@ Higher number provides more detailed diagnostics.</source>
 <context>
     <name>FileDlgManager</name>
     <message>
-        <location filename="optionsdlg.cc" line="68"/>
+        <location filename="optionsdlg.cc" line="75"/>
         <source>Select input file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="optionsdlg.cc" line="72"/>
+        <location filename="optionsdlg.cc" line="79"/>
         <source>Select output file</source>
         <translation type="unfinished"></translation>
     </message>
@@ -205,27 +205,27 @@ Higher number provides more detailed diagnostics.</source>
 <context>
     <name>FilterDialog</name>
     <message>
-        <location filename="filterdlg.cc" line="41"/>
+        <location filename="filterdlg.cc" line="47"/>
         <source>Tracks</source>
         <translation type="unfinished">Nyomvonalak</translation>
     </message>
     <message>
-        <location filename="filterdlg.cc" line="44"/>
+        <location filename="filterdlg.cc" line="50"/>
         <source>Waypoints</source>
         <translation type="unfinished">Útpontok</translation>
     </message>
     <message>
-        <location filename="filterdlg.cc" line="47"/>
+        <location filename="filterdlg.cc" line="53"/>
         <source>Routes &amp; Tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="filterdlg.cc" line="50"/>
+        <location filename="filterdlg.cc" line="56"/>
         <source>Miscellaneous</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="filterdlg.cc" line="105"/>
+        <location filename="filterdlg.cc" line="111"/>
         <source>Are you sure you want to reset all filter options to default values?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -256,137 +256,137 @@ Higher number provides more detailed diagnostics.</source>
 <context>
     <name>GMapDialog</name>
     <message>
-        <location filename="gmapdlg.cc" line="45"/>
+        <location filename="gmapdlg.cc" line="57"/>
         <source>meters</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="54"/>
+        <location filename="gmapdlg.cc" line="66"/>
         <source>feet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="58"/>
+        <location filename="gmapdlg.cc" line="70"/>
         <source>miles</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="61"/>
+        <location filename="gmapdlg.cc" line="73"/>
         <source>Length: %1 %2
   %3 %4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="71"/>
+        <location filename="gmapdlg.cc" line="83"/>
         <source>Lat: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="72"/>
+        <location filename="gmapdlg.cc" line="84"/>
         <source>Lng: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="74"/>
+        <location filename="gmapdlg.cc" line="86"/>
         <source>Desc: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="77"/>
+        <location filename="gmapdlg.cc" line="89"/>
         <source>Cmt: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="80"/>
+        <location filename="gmapdlg.cc" line="92"/>
         <source>Ele: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="114"/>
+        <location filename="gmapdlg.cc" line="126"/>
         <source>Start: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="116"/>
+        <location filename="gmapdlg.cc" line="128"/>
         <source>Stop: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="119"/>
+        <location filename="gmapdlg.cc" line="131"/>
         <source>Points: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="146"/>
+        <location filename="gmapdlg.cc" line="156"/>
         <source>Waypoints</source>
         <translation type="unfinished">Útpontok</translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="161"/>
+        <location filename="gmapdlg.cc" line="168"/>
         <source>Tracks</source>
         <translation type="unfinished">Nyomvonalak</translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="176"/>
+        <location filename="gmapdlg.cc" line="180"/>
         <source>Routes</source>
         <translation type="unfinished">Útvonalak</translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="531"/>
+        <location filename="gmapdlg.cc" line="414"/>
         <source>Show All Waypoints</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="532"/>
+        <location filename="gmapdlg.cc" line="415"/>
         <source>Hide All Waypoints</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="533"/>
-        <location filename="gmapdlg.cc" line="540"/>
-        <location filename="gmapdlg.cc" line="547"/>
+        <location filename="gmapdlg.cc" line="416"/>
+        <location filename="gmapdlg.cc" line="423"/>
+        <location filename="gmapdlg.cc" line="430"/>
         <source>Expand All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="534"/>
-        <location filename="gmapdlg.cc" line="541"/>
-        <location filename="gmapdlg.cc" line="548"/>
+        <location filename="gmapdlg.cc" line="417"/>
+        <location filename="gmapdlg.cc" line="424"/>
+        <location filename="gmapdlg.cc" line="431"/>
         <source>Collapse All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="538"/>
+        <location filename="gmapdlg.cc" line="421"/>
         <source>Show All Routes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="539"/>
+        <location filename="gmapdlg.cc" line="422"/>
         <source>Hide All Routes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="545"/>
+        <location filename="gmapdlg.cc" line="428"/>
         <source>Show All Tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="546"/>
+        <location filename="gmapdlg.cc" line="429"/>
         <source>Hide All Tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="552"/>
+        <location filename="gmapdlg.cc" line="437"/>
         <source>Show Only This Waypoint</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="557"/>
+        <location filename="gmapdlg.cc" line="439"/>
         <source>Show Only This Track</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="gmapdlg.cc" line="562"/>
+        <location filename="gmapdlg.cc" line="441"/>
         <source>Show Only This Route</source>
         <translation type="unfinished"></translation>
     </message>
@@ -398,16 +398,6 @@ Higher number provides more detailed diagnostics.</source>
         <source>Dialog</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="gmapui.ui" line="47"/>
-        <source>Copy to Clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gmapui.ui" line="50"/>
-        <source>Copy</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MainDlg</name>
@@ -455,128 +445,134 @@ Higher number provides more detailed diagnostics.</source>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cc" line="529"/>
+        <location filename="mainwindow.cc" line="506"/>
         <source>Select one or more input files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="557"/>
+        <location filename="mainwindow.cc" line="534"/>
         <source>Output File Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="621"/>
+        <location filename="mainwindow.cc" line="598"/>
         <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="632"/>
+        <location filename="mainwindow.cc" line="609"/>
         <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH
 
 This program cannot continue.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="653"/>
+        <location filename="mainwindow.cc" line="630"/>
         <source>Input and output formats do not support %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="656"/>
+        <location filename="mainwindow.cc" line="633"/>
         <source>Input does not support %1; output format supports %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="659"/>
+        <location filename="mainwindow.cc" line="636"/>
         <source>Input format supports %1; output format does not support %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="662"/>
+        <location filename="mainwindow.cc" line="639"/>
         <source>Both input and output formats support %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="683"/>
+        <location filename="mainwindow.cc" line="660"/>
         <source>waypoints</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="684"/>
+        <location filename="mainwindow.cc" line="661"/>
         <source>tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="685"/>
+        <location filename="mainwindow.cc" line="662"/>
         <source>routes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="780"/>
+        <location filename="mainwindow.cc" line="757"/>
         <source>There are no input options for format &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="786"/>
-        <location filename="mainwindow.cc" line="805"/>
+        <location filename="mainwindow.cc" line="763"/>
+        <location filename="mainwindow.cc" line="782"/>
         <source>Options for %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="799"/>
+        <location filename="mainwindow.cc" line="776"/>
         <source>There are no output options for format &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="819"/>
+        <location filename="mainwindow.cc" line="796"/>
         <source>No valid waypoints/routes/tracks translation specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="838"/>
+        <location filename="mainwindow.cc" line="815"/>
         <source>No input file specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="847"/>
+        <location filename="mainwindow.cc" line="824"/>
         <source>No valid output specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="852"/>
+        <location filename="mainwindow.cc" line="829"/>
         <source>No output file specified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="987"/>
+        <location filename="mainwindow.cc" line="964"/>
         <source>Translation successful</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1005"/>
+        <location filename="mainwindow.cc" line="977"/>
+        <source>Error preparing map: %1
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cc" line="995"/>
         <source>Error running gpsbabel: %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1128"/>
+        <location filename="mainwindow.cc" line="1118"/>
         <source>Are you sure you want to reset all format options to default values?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1157"/>
+        <location filename="mainwindow.cc" line="1147"/>
         <source>About %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1200"/>
+        <location filename="mainwindow.cc" line="1190"/>
         <source>One or more data filters are active</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cc" line="1202"/>
+        <location filename="mainwindow.cc" line="1192"/>
         <source>No data filters are active</source>
         <translation type="unfinished"></translation>
     </message>
@@ -800,17 +796,17 @@ This program cannot continue.</source>
 <context>
     <name>Map</name>
     <message>
-        <location filename="map.cc" line="127"/>
+        <location filename="map.cc" line="118"/>
         <source>Error opening &quot;gmapbase.html&quot; file.  Check installation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="map.cc" line="131"/>
+        <location filename="map.cc" line="122"/>
         <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="map.cc" line="186"/>
+        <location filename="map.cc" line="177"/>
         <source>Failed to load Google maps base page</source>
         <translation type="unfinished"></translation>
     </message>
@@ -819,28 +815,28 @@ This program cannot continue.</source>
     <name>MiscFltWidget</name>
     <message>
         <location filename="miscfltui.ui" line="97"/>
-        <location filename="filterwidgets.cc" line="270"/>
-        <location filename="filterwidgets.cc" line="271"/>
-        <location filename="filterwidgets.cc" line="274"/>
-        <location filename="filterwidgets.cc" line="275"/>
+        <location filename="filterwidgets.cc" line="293"/>
+        <location filename="filterwidgets.cc" line="294"/>
+        <location filename="filterwidgets.cc" line="297"/>
+        <location filename="filterwidgets.cc" line="298"/>
         <source>Tracks</source>
         <translation type="unfinished">Nyomvonalak</translation>
     </message>
     <message>
         <location filename="miscfltui.ui" line="104"/>
-        <location filename="filterwidgets.cc" line="270"/>
-        <location filename="filterwidgets.cc" line="272"/>
-        <location filename="filterwidgets.cc" line="273"/>
-        <location filename="filterwidgets.cc" line="275"/>
+        <location filename="filterwidgets.cc" line="293"/>
+        <location filename="filterwidgets.cc" line="295"/>
+        <location filename="filterwidgets.cc" line="296"/>
+        <location filename="filterwidgets.cc" line="298"/>
         <source>Waypoints</source>
         <translation type="unfinished">Útpontok</translation>
     </message>
     <message>
         <location filename="miscfltui.ui" line="90"/>
-        <location filename="filterwidgets.cc" line="271"/>
-        <location filename="filterwidgets.cc" line="272"/>
-        <location filename="filterwidgets.cc" line="273"/>
-        <location filename="filterwidgets.cc" line="274"/>
+        <location filename="filterwidgets.cc" line="294"/>
+        <location filename="filterwidgets.cc" line="295"/>
+        <location filename="filterwidgets.cc" line="296"/>
+        <location filename="filterwidgets.cc" line="297"/>
         <source>Routes</source>
         <translation type="unfinished">Útvonalak</translation>
     </message>
@@ -962,8 +958,8 @@ Some GPS data formats support only some subset of waypoints, tracks, and routes.
 <context>
     <name>OptionsDlg</name>
     <message>
-        <location filename="optionsdlg.cc" line="187"/>
-        <location filename="optionsdlg.cc" line="198"/>
+        <location filename="optionsdlg.cc" line="194"/>
+        <location filename="optionsdlg.cc" line="205"/>
         <source>Help</source>
         <translation type="unfinished">Segítség</translation>
     </message>
@@ -1032,7 +1028,7 @@ Some GPS data formats support only some subset of waypoints, tracks, and routes.
 <context>
     <name>QObject</name>
     <message>
-        <location filename="formatload.cc" line="182"/>
+        <location filename="formatload.cc" line="174"/>
         <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1120,48 +1116,48 @@ Additionally, if you&apos;re using this to reverse a route that navigates, say,
 <context>
     <name>RunMachine</name>
     <message>
-        <location filename="runmachine.cc" line="35"/>
+        <location filename="runmachine.cc" line="34"/>
         <source>Process failed to start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="37"/>
+        <location filename="runmachine.cc" line="36"/>
         <source>Process crashed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="39"/>
+        <location filename="runmachine.cc" line="38"/>
         <source>Process timedout</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="41"/>
+        <location filename="runmachine.cc" line="40"/>
         <source>Error while trying to write to process</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="43"/>
+        <location filename="runmachine.cc" line="42"/>
         <source>Error while trying to read from process</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="46"/>
+        <location filename="runmachine.cc" line="45"/>
         <source>Unknown process error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="145"/>
+        <location filename="runmachine.cc" line="143"/>
         <source>Process &quot;%1&quot; did not start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="177"/>
+        <location filename="runmachine.cc" line="175"/>
         <source>Process exited unsuccessfully with code %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="runmachine.cc" line="181"/>
-        <location filename="runmachine.cc" line="192"/>
+        <location filename="runmachine.cc" line="179"/>
+        <location filename="runmachine.cc" line="190"/>
         <source>Process crashed while running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1491,27 +1487,27 @@ This option computes a value for the GPS speed at each trackpoint. This is most
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="upgrade.cc" line="269"/>
+        <location filename="upgrade.cc" line="275"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="upgrade.cc" line="270"/>
+        <location filename="upgrade.cc" line="276"/>
         <source>Invalid return data at line %1: %2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="upgrade.cc" line="312"/>
+        <location filename="upgrade.cc" line="318"/>
         <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="upgrade.cc" line="329"/>
+        <location filename="upgrade.cc" line="335"/>
         <source>Do you wish to download an upgrade?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="upgrade.cc" line="322"/>
+        <location filename="upgrade.cc" line="328"/>
         <source>Upgrade</source>
         <translation type="unfinished"></translation>
     </message>
