@@ -19,69 +19,64 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 //  USA.
 //
-#include <QByteArray>                  // for QByteArray
-#include <QDate>                       // for QDate
-#include <QDateTime>                   // for QDateTime
-#include <QDir>                        // for QDir
-#include <QEvent>                      // for QEvent (& QEvent::LanguageChange, QEvent::LocaleChange)
-#include <QFile>                       // for QFile
-#include <QFileInfo>                   // for QFileInfo
-#include <QLibraryInfo>                // for QLibraryInfo, QLibraryInfo::TranslationsPath
-#include <QLocale>                     // for QLocale
-#include <QMimeData>                   // for QMimeData
-#include <QProcess>                    // for QProcess, QProcess::NotRunning
-#include <QSettings>                   // for QSettings
-#include <QString>                     // for QString
-#include <QStringList>                 // for QStringList
-#include <QTemporaryFile>              // for QTemporaryFile
-#include <QTime>                       // for QTime
-#include <QUrl>                        // for QUrl
-#include <QVariant>                    // for QVariant
-#include <Qt>                          // for SmoothTransformation, WaitCursor
-#include <QtGlobal>                    // for foreach
-#include <QCursor>                     // for QCursor
-#include <QDesktopServices>            // for QDesktopServices
-#include <QIcon>                       // for QIcon
-#include <QImage>                      // for QImage
-#include <QTextCharFormat>             // for QTextCharFormat
-#include <QAbstractButton>             // for QAbstractButton
-#include <QApplication>                // for QApplication, qApp
-#include <QCheckBox>                   // for QCheckBox
-#include <QDialogButtonBox>            // for QDialogButtonBox
-#include <QFileDialog>                 // for QFileDialog
-#include <QMessageBox>                 // for QMessageBox, operator|, QMessageBox::Yes, QMessageBox::No
-#include <QPlainTextEdit>              // for QPlainTextEdit
-#include <QPushButton>                 // for QPushButton
-#include <QRadioButton>                // for QRadioButton
-#include <QStackedWidget>              // for QStackedWidget
-
-#include <cstdlib>                     // for exit
-
 #include "mainwindow.h"
-#include "gbversion.h"                 // for VERSION
-#include "aboutdlg.h"                  // for AboutDlg
-#include "advdlg.h"                    // for AdvDlg
-#include "appname.h"                   // for appName
-#include "babeldata.h"                 // for BabelData
-#include "donate.h"                    // for Donate
-#include "filterdlg.h"                 // for FilterDialog
-#include "formatload.h"                // for FormatLoad
+#include <QAbstractButton>     // for QAbstractButton
+#include <QAction>             // for QAction
+#include <QApplication>        // for QApplication, qApp
+#include <QByteArray>          // for QByteArray
+#include <QCheckBox>           // for QCheckBox
+#include <QCursor>             // for QCursor
+#include <QDate>               // for QDate
+#include <QDateTime>           // for QDateTime
+#include <QDesktopServices>    // for QDesktopServices
+#include <QDialogButtonBox>    // for QDialogButtonBox
+#include <QDir>                // for QDir
+#include <QEvent>              // for QEvent
+#include <QFile>               // for QFile
+#include <QFileDialog>         // for QFileDialog
+#include <QFileInfo>           // for QFileInfo
+#include <QGradientStop>       // for QBrush
+#include <QImage>              // for QImage
+#include <QLibraryInfo>        // for QLibraryInfo
+#include <QLocale>             // for QLocale
+#include <QMessageBox>         // for QMessageBox, operator|
+#include <QMimeData>           // for QMimeData
+#include <QPlainTextEdit>      // for QPlainTextEdit
+#include <QProcess>            // for QProcess
+#include <QPushButton>         // for QPushButton
+#include <QRadioButton>        // for QRadioButton
+#include <QSettings>           // for QSettings
+#include <QStackedWidget>      // for QStackedWidget
+#include <QString>             // for QString, operator+, operator==, operator!=
+#include <QStringList>         // for QStringList
+#include <QTemporaryFile>      // for QTemporaryFile
+#include <QTextCharFormat>     // for QTextCharFormat
+#include <QTime>               // for QTime, operator==
+#include <QUrl>                // for QUrl
+#include <QVariant>            // for QVariant, operator!=
+#include <Qt>                  // for TransformationMode, DateFormat, CursorShape, GlobalColor
+#include <QtGlobal>            // for QForeachContainer, qMakeForeachContainer, foreach
+#include <cstdlib>             // for exit
+#include "aboutdlg.h"          // for AboutDlg
+#include "advdlg.h"            // for AdvDlg
+#include "appname.h"           // for appName
+#include "babeldata.h"         // for BabelData
+#include "donate.h"            // for Donate
+#include "filterdlg.h"         // for FilterDialog
+#include "formatload.h"        // for FormatLoad
+#include "gbversion.h"         // for VERSION, kVersionDate, kVersionSHA
 #ifndef DISABLE_MAPPREVIEW
-#include "gmapdlg.h"                   // for GMapDialog
+#include "gpx.h"               // for Gpx
+#include "gmapdlg.h"           // for GMapDialog
 #endif
-#include "help.h"                      // for ShowHelp
-#include "optionsdlg.h"                // for OptionsDlg
-#include "preferences.h"               // for Preferences
-#include "runmachine.h"                // for RunMachine
-#include "upgrade.h"                   // for UpgradeCheck
-#include "version_mismatch.h"          // for VersionMismatch
+#include "help.h"              // for ShowHelp
+#include "optionsdlg.h"        // for OptionsDlg
+#include "preferences.h"       // for Preferences
+#include "runmachine.h"        // for RunMachine
+#include "upgrade.h"           // for UpgradeCheck
+#include "version_mismatch.h"  // for VersionMismatch
 
 
-
-const int BabelData::noType_ = -1;
-const int BabelData::fileType_ = 0;
-const int BabelData::deviceType_ = 1;
-
 //------------------------------------------------------------------------
 QString MainWindow::findBabelVersion()
 {
@@ -178,13 +173,9 @@ MainWindow::MainWindow(QWidget* parent): QMainWindow(parent)
   connect(ui_.actionUpgradeCheck, &QAction::triggered, this, &MainWindow::upgradeCheckActionX);
   connect(ui_.actionPreferences, &QAction::triggered, this, &MainWindow::preferencesActionX);
 
-// TODO: Qt6 deleted the obsolete overloaded signal QComboBox::currentIndexChanged(const QString &text)
-// that required using qOverload.
-  connect(ui_.inputFormatCombo,  qOverload<int>(&QComboBox::currentIndexChanged),
+  connect(ui_.inputFormatCombo, &QComboBox::currentIndexChanged,
           this,                 &MainWindow::inputFormatChanged);
-// TODO: Qt6 deleted the obsolete overloaded signal QComboBox::currentIndexChanged(const QString &text)
-// that required using qOverload.
-  connect(ui_.outputFormatCombo, qOverload<int>(&QComboBox::currentIndexChanged),
+  connect(ui_.outputFormatCombo, &QComboBox::currentIndexChanged,
           this,                 &MainWindow::outputFormatChanged);
   connect(ui_.inputOptionsBtn,   &QAbstractButton::clicked,
           this,                 &MainWindow::inputOptionButtonClicked);
@@ -245,16 +236,6 @@ MainWindow::MainWindow(QWidget* parent): QMainWindow(parent)
   }
 }
 
-//------------------------------------------------------------------------
-// Called every time, when a menu entry of the language menu is called
-void MainWindow::slotLanguageChanged(QAction* action)
-{
-  if (nullptr != action) {
-    // load the language dependant on the action content.
-    loadLanguage(action->data().toString());
-  }
-}
-
 void MainWindow::switchTranslator(QTranslator& translator, const QString& filename)
 {
   // remove the old translator
@@ -270,11 +251,7 @@ void MainWindow::switchTranslator(QTranslator& translator, const QString& filena
   const QStringList directories = {
     QApplication::applicationDirPath() + "/translations",
     ":/translations",
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QLibraryInfo::location(QLibraryInfo::TranslationsPath)
-#else
     QLibraryInfo::path(QLibraryInfo::TranslationsPath)
-#endif
   };
 
   // Load the new translator.
@@ -987,12 +964,25 @@ void MainWindow::applyActionX()
     ui_.outputWindow->appendPlainText(tr("Translation successful"));
 #ifndef DISABLE_MAPPREVIEW
     if (babelData_.previewGmap_) {
-      this->hide();
-      GMapDialog dlg(nullptr, tempName, babelData_.debugLevel_ >=1 ? ui_.outputWindow : nullptr);
-      dlg.show();
-      dlg.exec();
+      Gpx mapData;
+      QString mapStatus = mapData.read(tempName);
       QFile(tempName).remove();
-      this->show();
+      if (!mapStatus.isNull()) {
+        QTextCharFormat defaultFormat = ui_.outputWindow->currentCharFormat();
+        QTextCharFormat errorFormat = defaultFormat;
+        errorFormat.setForeground(Qt::red);
+        errorFormat.setFontItalic(true);
+
+        ui_.outputWindow->setCurrentCharFormat(errorFormat);
+        ui_.outputWindow->appendPlainText(tr("Error preparing map: %1\n").arg(mapStatus));
+        ui_.outputWindow->setCurrentCharFormat(defaultFormat);
+      } else {
+        this->hide();
+        GMapDialog dlg(nullptr, mapData, babelData_.debugLevel_ >=1 ? ui_.outputWindow : nullptr);
+        dlg.show();
+        dlg.exec();
+        this->show();
+      }
     }
 #endif
   } else {
