@@ -29,16 +29,16 @@
 #include <QDomNode>               // for QDomNode
 #include <QDomNodeList>           // for QDomNodeList
 #include <QLocale>                // for QLocale
-#include <QMessageBox>            // for QMessageBox, QMessageBox::Yes, operator|, QMessageBox::No
+#include <QMessageBox>            // for QMessageBox, operator|
 #include <QNetworkAccessManager>  // for QNetworkAccessManager
-#include <QNetworkReply>          // for QNetworkReply, QNetworkReply::NoError
-#include <QNetworkRequest>        // for QNetworkRequest, QNetworkRequest::ContentTypeHeader, QNetworkRequest::HttpReasonPhraseAttribute, QNetworkRequest::HttpStatusCodeAttribute, QNetworkRequest::NoLessSafeRedirectPolicy, QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::RedirectionTar...
+#include <QNetworkReply>          // for QNetworkReply
+#include <QNetworkRequest>        // for QNetworkRequest
 #include <QSysInfo>               // for QSysInfo
 #include <QUrl>                   // for QUrl
 #include <QVariant>               // for QVariant, operator!=
 #include <QVersionNumber>         // for QVersionNumber, operator<, operator==
-#include <Qt>                     // for ISODate, RichText
-#include <QtGlobal>               // for qDebug, qsizetype, QT_VERSION, QT_VERSION_CHECK
+#include <Qt>                     // for DateFormat, TextFormat
+#include <QtGlobal>               // for qDebug, QT_VERSION, QT_VERSION_CHECK, qsizetype
 
 #include "babeldata.h"            // for BabelData
 #include "format.h"               // for Format
@@ -262,14 +262,20 @@ void UpgradeCheck::httpRequestFinished(QNetworkReply* reply)
   QString oresponse(reply->readAll());
 
   QDomDocument document;
-  int line = -1;
-  QString error_text;
   // This shouldn't ever be seen by a user.
-  if (!document.setContent(oresponse, &error_text, &line)) {
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
+  if (auto result = document.setContent(oresponse); !result) {
+#else
+  struct {
+    int errorLine{-1};
+    QString errorMessage;
+  } result;
+  if (!document.setContent(oresponse, &result.errorMessage, &result.errorLine)) {
+#endif
     QMessageBox::critical(nullptr, tr("Error"),
                           tr("Invalid return data at line %1: %2.")
-                          .arg(line)
-                          .arg(error_text));
+                          .arg(result.errorLine)
+                          .arg(result.errorMessage));
     babelData_.upgradeErrors_++;
     replyId_ = nullptr;
     reply->deleteLater();
