@@ -1,7 +1,7 @@
 /*
     Copyright (C) 2008  Björn Augustsson, oggust@gmail.com
     Copyright (C) 2008  Olaf Klein, o.b.klein@gpsbabel.org
-    Copyright (C) 2005-2013 Robert Lipe, robertlipe+source@gpsbabel.org
+    Copyright (C) 2005-2024 Robert Lipe, robertlipe+source@gpsbabel.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,21 +21,20 @@
 
 #include "humminbird.h"
 
-#include <QMap>                 // for QMap
+#include <QHash>                // for QHash
 #include <Qt>                   // for CaseInsensitive
 #include <QtGlobal>             // for qRound
 
-#include <cmath>                // for atan, tan, M_PI, log, sinh
-#include <cstdio>               // for snprintf, SEEK_SET
-#include <cstring>              // for strncpy, memcpy, memset
+#include <cmath>                // for atan, tan, log, sinh
+#include <cstdio>               // for SEEK_SET
+#include <cstring>              // for strncpy
+#include <numbers>              // for inv_pi, pi
 
-#include "defs.h"               // for Waypoint, be_read32, be_read16, be_write32, fatal, xfree, be_write16, route_head, xcalloc, track_add_wpt, xstrndup
+#include "defs.h"               // for Waypoint, be_read32, be_read16, be_write32, gbFatal, be_write16, route_head, track_add_wpt
 #include "mkshort.h"            // for MakeShort
 #include "src/core/datetime.h"  // for DateTime
 
 
-#define MYNAME "humminbird"
-
 #define WPT_NAME_LEN		12
 #define RTE_NAME_LEN		20
 #define TRK_NAME_LEN		20
@@ -61,12 +60,6 @@ Still, they're useful in the code as a plain signature.
 #define WPT_MAGIC2		0x02030024L // New for 2013.  No visible diff?!
 #define RTE_MAGIC		0x03030088L
 
-#define EAST_SCALE		20038297.0 /* this is i1924_equ_axis*M_PI */
-#define i1924_equ_axis		6378388.0
-#define i1924_polar_axis	6356911.946
-
-#define BAD_CHARS		"\r\n\t"
-
 /* The hwr data format is records-based, and the records are 36 bytes long. */
 
 struct HumminbirdBase::humminbird_waypt_t {
@@ -171,11 +164,9 @@ struct HumminbirdBase::group_body_t {
 double
 HumminbirdBase::geodetic_to_geocentric_hwr(const double gd_lat)
 {
-  constexpr double cos_ae = 0.9966349016452;
-  constexpr double cos2_ae = cos_ae * cos_ae;
-  const double gdr = gd_lat *M_PI / 180.0;
+  const double gdr = gd_lat * std::numbers::pi / 180.0;
 
-  return atan(cos2_ae * tan(gdr)) * 180.0/M_PI;
+  return atan(cos2_ae * tan(gdr)) * 180.0 * std::numbers::inv_pi;
 }
 
 /* Takes a latitude in degrees,
@@ -183,11 +174,9 @@ HumminbirdBase::geodetic_to_geocentric_hwr(const double gd_lat)
 double
 HumminbirdBase::geocentric_to_geodetic_hwr(const double gc_lat)
 {
-  constexpr double cos_ae = 0.9966349016452;
-  constexpr double cos2_ae = cos_ae * cos_ae;
-  const double gcr = gc_lat *M_PI / 180.0;
+  const double gcr = gc_lat * std::numbers::pi / 180.0;
 
-  return atan(tan(gcr)/cos2_ae) * 180.0/M_PI;
+  return atan(tan(gcr)/cos2_ae) * 180.0 * std::numbers::inv_pi;
 }
 
 /* Takes a projected "north" value, returns latitude in degrees. */
@@ -196,15 +185,15 @@ HumminbirdBase::gudermannian_i1924(const double x)
 {
   const double norm_x = x/i1924_equ_axis;
 
-  return atan(sinh(norm_x)) * 180.0/M_PI;
+  return atan(sinh(norm_x)) * 180.0 * std::numbers::inv_pi;
 }
 
 /* Takes latitude in degrees, returns projected "north" value. */
 double
 HumminbirdBase::inverse_gudermannian_i1924(const double x)
 {
-  const double x_r = x/180.0 * M_PI;
-  const double guder = log(tan(M_PI/4.0 + x_r/2.0));
+  const double x_r = x/180.0 * std::numbers::pi;
+  const double guder = log(tan(std::numbers::pi/4.0 + x_r/2.0));
 
   return guder * i1924_equ_axis;
 }
@@ -216,7 +205,9 @@ HumminbirdBase::inverse_gudermannian_i1924(const double x)
 void
 HumminbirdBase::humminbird_rd_init(const QString& fname)
 {
-  fin_ = gbfopen_be(fname, "rb", MYNAME);
+  fin_ = gbfopen_be(fname, "rb");
+
+  wpt_num_to_wpt_hash.clear();
 }
 
 void
@@ -228,10 +219,11 @@ HumminbirdBase::humminbird_rd_deinit() const
 void
 HumminbirdBase::humminbird_read_wpt(gbfile* fin)
 {
-  humminbird_waypt_t w;
+  humminbird_waypt_t w{0};
+  static_assert(sizeof(w) == 32);
 
   if (! gbfread(&w, 1, sizeof(w), fin)) {
-    fatal(MYNAME ": Unexpected end of file!\n");
+    gbFatal("Unexpected end of file!\n");
   }
 
   /* Fix endianness - these are now BE */
@@ -246,24 +238,20 @@ HumminbirdBase::humminbird_read_wpt(gbfile* fin)
 
   auto* wpt = new Waypoint;
 
-  // Could probably find a way to eliminate the alloc/copy.
-  char* s = xstrndup(w.name, sizeof(w.name));
-  wpt->shortname = s;
-  xfree(s);
-
+  wpt->shortname = QByteArray(w.name, static_cast<int>(qstrnlen(w.name, sizeof(w.name))));
   wpt->SetCreationTime(w.time);
 
   double guder = gudermannian_i1924(w.north);
   wpt->latitude = geocentric_to_geodetic_hwr(guder);
-  wpt->longitude = (double)w.east / EAST_SCALE * 180.0;
+  wpt->longitude = static_cast<double>(w.east) / EAST_SCALE * 180.0;
 
-  wpt->altitude  = 0.0; /* It's from a fishfinder... */
+  wpt->altitude = 0.0; /* It's from a fishfinder... */
 
   if (w.depth != 0) {
-    wpt->set_depth((double)w.depth / 100.0);
+    wpt->set_depth(static_cast<double>(w.depth) / 100.0);
   }
 
-  int num_icons = sizeof(humminbird_icons) / sizeof(humminbird_icons[0]);
+  int num_icons = std::size(humminbird_icons);
   if (w.icon < num_icons) {
     wpt->icon_descr = humminbird_icons[w.icon];
   }
@@ -278,6 +266,8 @@ HumminbirdBase::humminbird_read_wpt(gbfile* fin)
   case 2: // Waypoint temporary.
   case 3: // Waypoint man-overboard.
     waypt_add(wpt);
+    /* register the point over his internal Humminbird "Number" */
+    wpt_num_to_wpt_hash[w.num] = wpt;
     break;
   case 16: // Waypoint group header.
   case 17: // Waypoint group body.
@@ -286,20 +276,16 @@ HumminbirdBase::humminbird_read_wpt(gbfile* fin)
     delete wpt;
     break;
   }
-
-  /* register the point over his internal Humminbird "Number" */
-  QString buff = QString::number(w.num);
-  map[buff] = wpt;
 }
 
 void
 HumminbirdBase::humminbird_read_route(gbfile* fin) const
 {
-
-  humminbird_rte_t hrte;
+  humminbird_rte_t hrte{0};
+  static_assert(sizeof(hrte) == 132);
 
   if (! gbfread(&hrte, 1, sizeof(hrte), fin)) {
-    fatal(MYNAME ": Unexpected end of file!\n");
+    gbFatal("Unexpected end of file!\n");
   }
 
   hrte.time = be_read32(&hrte.time);
@@ -309,21 +295,14 @@ HumminbirdBase::humminbird_read_route(gbfile* fin) const
     route_head* rte = nullptr;
 
     for (int i = 0; i < hrte.count; i++) {
-      char buff[10];
       hrte.points[i] = be_read16(&hrte.points[i]);
 
       /* locate the point over his internal Humminbird "Number" */
-      snprintf(buff, sizeof(buff), "%d", hrte.points[i]);
-      if ((map.value(buff))) {
-        const Waypoint* wpt = map.value(buff);
-        if (rte == nullptr) {
+      if (const Waypoint* wpt = wpt_num_to_wpt_hash.value(hrte.points[i], nullptr); wpt != nullptr) {
+      	if (rte == nullptr) {
           rte = new route_head;
           route_add_head(rte);
-          // TODO: find a way to eliminate the copy.
-          char* s = xstrndup(hrte.name, sizeof(hrte.name));
-          rte->rte_name = s;
-          xfree(s);
-          /* rte->rte_num = hrte.num + 1; only internal number */
+          rte->rte_name = QByteArray(hrte.name, static_cast<int>(qstrnlen(hrte.name, sizeof(hrte.name))));
         }
         route_add_wpt(rte, new Waypoint(*wpt));
       }
@@ -334,11 +313,11 @@ HumminbirdBase::humminbird_read_route(gbfile* fin) const
 void
 HumminbirdBase::humminbird_read_track(gbfile* fin)
 {
-
-  humminbird_trk_header_t th;
+  humminbird_trk_header_t th{0};
+  static_assert(sizeof(th) == 64);
 
   if (! gbfread(&th, 1, sizeof(th), fin)) {
-    fatal(MYNAME ": Unexpected end of file reading header!\n");
+    gbFatal("Unexpected end of file reading header!\n");
   }
 
   th.trk_num     = be_read16(&th.trk_num);
@@ -362,15 +341,15 @@ HumminbirdBase::humminbird_read_track(gbfile* fin)
   }
 
   if (th.num_points > max_points) {
-    fatal(MYNAME ": Too many track points! (%d)\n", th.num_points);
+    gbFatal("Too many track points! (%d)\n", th.num_points);
   }
 
   /* num_points is actually one too big, because it includes the value in
      the header. But we want the extra point at the end because the
      freak-value filter below looks at points[i+1] */
-  auto* points = (humminbird_trk_point_t*) xcalloc(th.num_points, sizeof(humminbird_trk_point_t));
+  auto* points = new humminbird_trk_point_t[th.num_points]();
   if (! gbfread(points, sizeof(humminbird_trk_point_t), th.num_points-1, fin)) {
-    fatal(MYNAME ": Unexpected end of file reading points!\n");
+    gbFatal("Unexpected end of file reading points!\n");
   }
 
   int32_t accum_east = th.start_east;
@@ -379,10 +358,7 @@ HumminbirdBase::humminbird_read_track(gbfile* fin)
   auto* trk = new route_head;
   track_add_head(trk);
 
-  // TODO: find a way to eliminate the copy.
-  char* s = xstrndup(th.name, sizeof(th.name));
-  trk->rte_name = s;
-  xfree(s);
+  trk->rte_name = QByteArray(th.name, static_cast<int>(qstrnlen(th.name, sizeof(th.name))));
   trk->rte_num  = th.trk_num;
 
   /* We create one wpt for the info in the header */
@@ -395,7 +371,7 @@ HumminbirdBase::humminbird_read_track(gbfile* fin)
   /* No depth info in the header. */
   track_add_wpt(trk, first_wpt);
 
-  for (int i = 0 ; i<th.num_points-1 ; i++) {
+  for (int i = 0 ; i < th.num_points-1 ; i++) {
     auto* wpt = new Waypoint;
 
     points[i].depth      = be_read16(&points[i].depth);
@@ -427,7 +403,7 @@ HumminbirdBase::humminbird_read_track(gbfile* fin)
     wpt->altitude  = 0.0;
 
     if (points[i].depth != 0) {
-      wpt->set_depth((double)points[i].depth / 100.0);
+      wpt->set_depth(static_cast<double>(points[i].depth) / 100.0);
     }
 
     if (i == th.num_points-2 && th.time != 0) {
@@ -439,20 +415,18 @@ HumminbirdBase::humminbird_read_track(gbfile* fin)
     }
     track_add_wpt(trk, wpt);
   }
-  xfree(points);
+  delete[] points;
 }
 
 void
 HumminbirdBase::humminbird_read_track_old(gbfile* fin)
 {
-
-  humminbird_trk_header_old_t th;
+  humminbird_trk_header_old_t th{0};
   constexpr int file_len = 8048;
   char namebuf[TRK_NAME_LEN];
 
-
   if (! gbfread(&th, 1, sizeof(th), fin)) {
-    fatal(MYNAME ": Unexpected end of file reading header!\n");
+    gbFatal("Unexpected end of file reading header!\n");
   }
 
   th.trk_num     = be_read16(&th.trk_num);
@@ -469,15 +443,15 @@ HumminbirdBase::humminbird_read_track_old(gbfile* fin)
   int max_points = (file_len - (sizeof(th) + sizeof(uint32_t) + TRK_NAME_LEN)) / sizeof(humminbird_trk_point_old_t);
 
   if (th.num_points > max_points) {
-    fatal(MYNAME ": Too many track points! (%d)\n", th.num_points);
+    gbFatal("Too many track points! (%d)\n", th.num_points);
   }
 
   /* num_points is actually one too big, because it includes the value in
      the header. But we want the extra point at the end because the
      freak-value filter below looks at points[i+1] */
-  auto* points = (humminbird_trk_point_old_t*)xcalloc(th.num_points, sizeof(humminbird_trk_point_old_t));
+  auto* points = new humminbird_trk_point_old_t[th.num_points]();
   if (! gbfread(points, sizeof(humminbird_trk_point_old_t), th.num_points-1, fin)) {
-    fatal(MYNAME ": Unexpected end of file reading points!\n");
+    gbFatal("Unexpected end of file reading points!\n");
   }
 
   int32_t accum_east = th.start_east;
@@ -491,8 +465,8 @@ HumminbirdBase::humminbird_read_track_old(gbfile* fin)
 
   gbfseek(fin, file_len-TRK_NAME_LEN, SEEK_SET);
   gbfread(&namebuf, 1, TRK_NAME_LEN, fin);
-  trk->rte_name = xstrndup(namebuf, sizeof(namebuf));
 
+  trk->rte_name = QByteArray(namebuf, static_cast<int>(qstrnlen(namebuf, sizeof(namebuf))));
   trk->rte_num  = th.trk_num;
 
   /* We create one wpt for the info in the header */
@@ -504,7 +478,7 @@ HumminbirdBase::humminbird_read_track_old(gbfile* fin)
   first_wpt->altitude  = 0.0;
   track_add_wpt(trk, first_wpt);
 
-  for (int i = 0 ; i<th.num_points-1 ; i++) {
+  for (int i = 0 ; i < th.num_points-1 ; i++) {
     auto* wpt = new Waypoint;
 
     points[i].deltaeast  = be_read16(&points[i].deltaeast);
@@ -546,16 +520,14 @@ HumminbirdBase::humminbird_read_track_old(gbfile* fin)
     }
     track_add_wpt(trk, wpt);
   }
-  xfree(points);
+  delete[] points;
 }
 
 void
 HumminbirdBase::humminbird_read()
 {
   while (! gbfeof(fin_)) {
-    uint32_t signature = gbfgetuint32(fin_);
-
-    switch (signature) {
+    switch (uint32_t signature = gbfgetuint32(fin_)) {
     case WPT_MAGIC:
     case WPT_MAGIC2:
       humminbird_read_wpt(fin_);
@@ -570,7 +542,7 @@ HumminbirdBase::humminbird_read()
       humminbird_read_track_old(fin_);
       return; /* Don't continue. The rest of the file is all zeores */
     default:
-      fatal(MYNAME ": Invalid record header \"0x%08X\" (no or unknown humminbird file)!\n", signature);
+      gbFatal("Invalid record header \"0x%08X\" (no or unknown humminbird file)!\n", signature);
     }
   }
 }
@@ -581,12 +553,12 @@ HumminbirdBase::humminbird_read()
 void
 HumminbirdBase::humminbird_wr_init(const QString& fname)
 {
-  fout_ = gbfopen_be(fname, "wb", MYNAME);
+  fout_ = gbfopen_be(fname, "wb");
 
   wptname_sh = new MakeShort;
 
   wptname_sh->set_length(WPT_NAME_LEN - 1);
-  wptname_sh->set_badchars(BAD_CHARS);
+  wptname_sh->set_badchars(kBadChars);
   wptname_sh->set_mustupper(false);
   wptname_sh->set_mustuniq(false);
   wptname_sh->set_whitespace_ok(true);
@@ -595,7 +567,7 @@ HumminbirdBase::humminbird_wr_init(const QString& fname)
 
   rtename_sh = new MakeShort;
   rtename_sh->set_length(RTE_NAME_LEN - 1);
-  rtename_sh->set_badchars(BAD_CHARS);
+  rtename_sh->set_badchars(kBadChars);
   rtename_sh->set_mustupper(false);
   rtename_sh->set_mustuniq(false);
   rtename_sh->set_whitespace_ok(true);
@@ -604,7 +576,7 @@ HumminbirdBase::humminbird_wr_init(const QString& fname)
 
   trkname_sh = new MakeShort;
   trkname_sh->set_length(RTE_NAME_LEN - 1);
-  trkname_sh->set_badchars(BAD_CHARS);
+  trkname_sh->set_badchars(kBadChars);
   trkname_sh->set_mustupper(false);
   trkname_sh->set_mustuniq(false);
   trkname_sh->set_whitespace_ok(true);
@@ -613,6 +585,8 @@ HumminbirdBase::humminbird_wr_init(const QString& fname)
 
   waypoint_num = 0;
   rte_num_ = 0;
+
+  wpt_id_to_wpt_num_hash.clear();
 }
 
 void
@@ -630,8 +604,7 @@ HumminbirdBase::humminbird_wr_deinit()
 void
 HumminbirdFormat::humminbird_write_waypoint(const Waypoint* wpt)
 {
-  humminbird_waypt_t hum;
-  int num_icons = sizeof(humminbird_icons) / sizeof(humminbird_icons[0]);
+  humminbird_waypt_t hum{0};
 
   be_write16(&hum.num, waypoint_num++);
   hum.zero   = 0;
@@ -639,20 +612,26 @@ HumminbirdFormat::humminbird_write_waypoint(const Waypoint* wpt)
   hum.icon   = 255;
 
   // Icon....
-  if (!wpt->icon_descr.isNull()) {
-    for (int i = 0; i < num_icons; i++) {
-      if (!wpt->icon_descr.compare(humminbird_icons[i], Qt::CaseInsensitive)) {
+  QString icon = wpt->icon_descr;
+  if (!icon.isEmpty()) {
+    int i = 0;
+    for (const auto& hi : humminbird_icons) {
+      if (!icon.compare(hi, Qt::CaseInsensitive)) {
         hum.icon = i;
         break;
       }
+      i++;
     }
-    if (hum.icon == 255) {	/* no success, no try to find the item in a more comlex name */
+
+    if (hum.icon == 255) { /* no success, now try to find the item in a more complex name */
       hum.icon = 0;	/* i.e. "Diamond" as part of "Diamond, Green" or "Green Diamond" */
-      for (int i = 0; i < num_icons; i++) {
-        if (wpt->icon_descr.contains(humminbird_icons[i], Qt::CaseInsensitive)) {
+      i = 0;
+      for (const auto& hi : humminbird_icons) {
+        if (icon.contains(hi, Qt::CaseInsensitive)) {
           hum.icon = i;
           break;
         }
+        i++;
       }
     }
   }
@@ -672,8 +651,7 @@ HumminbirdFormat::humminbird_write_waypoint(const Waypoint* wpt)
   QString name = (global_opts.synthesize_shortnames)
                  ? wptname_sh->mkshort_from_wpt(wpt)
                  : wptname_sh->mkshort(wpt->shortname);
-  memset(&hum.name, 0, sizeof(hum.name));
-  memcpy(&hum.name, CSTR(name), name.length());
+  strncpy(hum.name, CSTR(name), sizeof(hum.name)-1);
 
   gbfputuint32(WPT_MAGIC, fout_);
   gbfwrite(&hum, sizeof(hum), 1, fout_);
@@ -687,9 +665,8 @@ HumminbirdHTFormat::humminbird_track_head(const route_head* trk)
   trk_head = nullptr;
   last_time = 0;
   if (!trk->rte_waypt_empty()) {
-    trk_head = (humminbird_trk_header_t*) xcalloc(1, sizeof(humminbird_trk_header_t));
-    trk_points = (humminbird_trk_point_t*) xcalloc(max_points, sizeof(humminbird_trk_point_t));
-
+    trk_head = new humminbird_trk_header_t();
+    trk_points = new humminbird_trk_point_t[max_points]();
     QString name = trkname_sh->mkshort(trk->rte_name);
     strncpy(trk_head->name, CSTR(name), sizeof(trk_head->name)-1);
     be_write16(&trk_head->trk_num, trk->rte_num);
@@ -726,8 +703,8 @@ HumminbirdHTFormat::humminbird_track_tail(const route_head* /*unused*/)
   gbfwrite(trk_points, max_points, sizeof(humminbird_trk_point_t), fout_);
   gbfputuint16(0, fout_); /* Odd but true. The format doesn't fit an int nr of entries. */
 
-  xfree(trk_head);
-  xfree(trk_points);
+  delete trk_head;
+  delete[] trk_points;
 
   trk_head   = nullptr;
   trk_points = nullptr;
@@ -767,8 +744,8 @@ HumminbirdHTFormat::humminbird_track_cb(const Waypoint* wpt)
   } else {
     /* These points are 16-bit differential. */
     int j = i-1;
-    trk_points[j].deltaeast = east - last_east;
-    trk_points[j].deltanorth = north - last_north;
+    trk_points[j].deltaeast = static_cast<int16_t>(east - last_east);
+    trk_points[j].deltanorth =  static_cast<int16_t>(north - last_north);
     trk_points[j].depth = qRound(wpt->depth_value_or(0) * 100.0);
 
     /* BE-ify */
@@ -818,7 +795,7 @@ HumminbirdFormat::humminbird_rte_head(const route_head* rte)
 {
   humrte = nullptr;
   if (!rte->rte_waypt_empty()) {
-    humrte = (humminbird_rte_t*) xcalloc(1, sizeof(*humrte));
+    humrte = new humminbird_rte_t();
   }
 }
 
@@ -846,46 +823,47 @@ HumminbirdFormat::humminbird_rte_tail(const route_head* rte)
     gbfwrite(humrte, sizeof(*humrte), 1, fout_);
   }
 
-  xfree(humrte);
+  delete humrte;
   humrte = nullptr;
 }
 
+QString HumminbirdFormat::wpt_to_id(const Waypoint* wpt)
+{
+  QString id = QStringLiteral("%1\01%2\01%3").arg(wpt->shortname)
+                .arg(wpt->latitude, 0, 'f', 9).arg(wpt->longitude, 0, 'f', 9);
+  return id;
+}
+
 void
 HumminbirdFormat::humminbird_write_rtept(const Waypoint* wpt) const
 {
   if (humrte == nullptr) {
     return;
   }
-  int i = gb_ptr2int(wpt->extra_data);
-  if (i <= 0) {
+  QString id = wpt_to_id(wpt);
+
+  if (!wpt_id_to_wpt_num_hash.contains(id)) {
+    // This should not occur, we just scanned all waypoints and routes.
+    gbWarning("Missing waypoint reference in route, point dropped from route.\n");
     return;
   }
 
   if (humrte->count < MAX_RTE_POINTS) {
-    humrte->points[humrte->count] = i - 1;
+    humrte->points[humrte->count] = wpt_id_to_wpt_num_hash.value(id);
     humrte->count++;
   } else {
-    warning(MYNAME ": Sorry, routes are limited to %d points!\n", MAX_RTE_POINTS);
-    fatal(MYNAME ": You can use our simplify filter to reduce the number of route points.\n");
+    gbWarning("Sorry, routes are limited to %d points!\n", MAX_RTE_POINTS);
+    gbFatal("You can use our simplify filter to reduce the number of route points.\n");
   }
 }
 
 void
 HumminbirdFormat::humminbird_write_waypoint_wrapper(const Waypoint* wpt)
 {
-  Waypoint* tmpwpt;
-
-  QString key = QStringLiteral("%1\01%2\01%3").arg(wpt->shortname)
-                .arg(wpt->latitude, 0, 'f', 9).arg(wpt->longitude, 0, 'f', 9);
-  if (!(tmpwpt = map[key])) {
-    tmpwpt = const_cast<Waypoint*>(wpt);
-    map[key] = const_cast<Waypoint*>(wpt);
-    tmpwpt->extra_data = gb_int2ptr(waypoint_num + 1);	/* NOT NULL */
+  QString id = wpt_to_id(wpt);
+  if (!wpt_id_to_wpt_num_hash.contains(id)) {
+    wpt_id_to_wpt_num_hash[id] = waypoint_num;
     humminbird_write_waypoint(wpt);
-  } else {
-    void* p = tmpwpt->extra_data;
-    tmpwpt = const_cast<Waypoint*>(wpt);
-    tmpwpt->extra_data = p;
   }
 }
 
