@@ -45,7 +45,6 @@
 #include <QTime>                // for operator<, operator==, QTime
 #include <Qt>                   // for UTC, SkipEmptyParts
 #include <QtGlobal>             // for foreach, qPrintable
-#include <QDebug>               // DELETEME for debugging
 
 #include "defs.h"
 #include "gbfile.h"             // for gbfprintf, gbfclose, gbfopen, gbfputs, gbfgetstr, gbfile
@@ -55,7 +54,6 @@
 
 
 
-#define MYNAME "IGC"
 #define HDRMAGIC "IGCHDRS"
 #define HDRDELIM "~"
 #define DATEMAGIC "IGCDATE"
@@ -100,7 +98,7 @@ retry:
   }
 
   if (len < 3 || c[0] < 'A' || c[0] > 'Z') {
-    warning(MYNAME " bad input record: '%s'\n", c);
+    gbWarning("bad input record: '%s'\n", c);
     return rec_bad;
   }
   return (igc_rec_type_t) c[0];
@@ -110,10 +108,10 @@ void IgcFormat::rd_init(const QString& fname)
 {
   char* ibuf;
 
-  file_in = gbfopen(fname, "r", MYNAME);
+  file_in = gbfopen(fname, "r");
   // File must begin with a manufacturer/ID record
   if (get_record(&ibuf) != rec_manuf_id || sscanf(ibuf, "A%3[A-Z]", manufacturer) != 1) {
-    fatal(MYNAME ": %s is not an IGC file\n", qPrintable(fname));
+    gbFatal("%s is not an IGC file\n", gbLogCStr(fname));
   }
 }
 
@@ -129,9 +127,14 @@ void IgcFormat::rd_deinit()
  */
 void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
 {
-  unsigned int lat_deg, lat_min, lat_frac;
-  unsigned int lon_deg, lon_min, lon_frac;
-  char lat_hemi[2], lon_hemi[2];
+  unsigned int lat_deg;
+  unsigned int lat_min;
+  unsigned int lat_frac;
+  unsigned int lon_deg;
+  unsigned int lon_min;
+  unsigned int lon_frac;
+  char lat_hemi[2];
+  char lon_hemi[2];
   char tmp_str[kMaxRecLen];
 
   // First task record identifies the task to follow
@@ -150,7 +153,7 @@ void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
                &day, &month, &year,
                &hour, &minute, &second,
                flight_date, task_num, &num_tp, task_desc) < 9) {
-      fatal(MYNAME ": task id (C) record parse error A. \n'%s'", rec);
+      gbFatal("task id (C) record parse error A. \n'%s'\n", rec);
     }
     task_num[4] = '\0';
     if (year < 70) {
@@ -158,9 +161,9 @@ void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
     } else {
       year += 1900;
     }
-    creation = QDateTime(QDate(year, month, day), QTime(hour, minute, second), Qt::UTC);
+    creation = QDateTime(QDate(year, month, day), QTime(hour, minute, second), QtUTC);
     if (!creation.isValid()) {
-      fatal(MYNAME ": bad date time\n%s\n", rec);
+      gbFatal("bad date time\n%s\n", rec);
     }
 
     // Create a route to store the task data in.
@@ -176,7 +179,7 @@ void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
   if (sscanf(rec, "C%2u%2u%3u%1[NS]%3u%2u%3u%1[WE]%78[^\r]\r\n",
              &lat_deg, &lat_min, &lat_frac, lat_hemi,
              &lon_deg, &lon_min, &lon_frac, lon_hemi, tmp_str) < 8) {
-    fatal(MYNAME ": task waypoint (C) record parse error\n%s", rec);
+    gbFatal("task waypoint (C) record parse error\n%s\n", rec);
   }
 
   auto* wpt = new Waypoint;
@@ -220,7 +223,7 @@ void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
     break;
 
   default:
-    fatal(MYNAME ": task id (C) record internal error B\n%s", rec);
+    gbFatal("task id (C) record internal error B\n%s\n", rec);
     break;
   }
 
@@ -235,14 +238,22 @@ void IgcFormat::TaskRecordReader::igc_task_rec(const char* rec)
 void IgcFormat::read()
 {
   char* ibuf;
-  int hours, mins, secs;
-  unsigned int lat_deg, lat_min, lat_frac;
-  unsigned int lon_deg, lon_min, lon_frac;
-  char lat_hemi[2], lon_hemi[2];
+  int hours;
+  int mins;
+  int secs;
+  unsigned int lat_deg;
+  unsigned int lat_min;
+  unsigned int lat_frac;
+  unsigned int lon_deg;
+  unsigned int lon_min;
+  unsigned int lon_frac;
+  char lat_hemi[2];
+  char lon_hemi[2];
   char validity;
   route_head* pres_head = nullptr;
   route_head* gnss_head = nullptr;
-  int pres_alt, gnss_alt;
+  int pres_alt;
+  int gnss_alt;
   char pres_valid = 0;
   char gnss_valid = 0;
   Waypoint* pres_wpt = nullptr;
@@ -261,7 +272,7 @@ void IgcFormat::read()
 
   while (true) {
     if (global_opts.debug_level >= 8) {
-      printf(MYNAME ": Processing IGC file line %i\n", current_line);
+      gbDebug("Processing IGC file line %i\n", current_line);
     }
     igc_rec_type_t rec_type = get_record(&ibuf);
     current_line++;
@@ -269,13 +280,13 @@ void IgcFormat::read()
     switch (rec_type) {
     case rec_manuf_id:
       // Manufacturer/ID record already found in rd_init().
-      warning(MYNAME ": duplicate manufacturer/ID record\n");
+      gbWarning("duplicate manufacturer/ID record\n");
       break;
 
     case rec_header:
       // Get the header sub type
       if (sscanf(ibuf, "H%*1[FOPS]%3s", tmp_str) != 1) {
-        fatal(MYNAME ": header (H) record parse error\n%s\n%s\n", ibuf, tmp_str);
+        gbFatal("header (H) record parse error\n%s\n%s\n", ibuf, tmp_str);
       }
       // Optional long name of record sub type is followed by a
       // colon.  Actual header data follows that.
@@ -291,7 +302,7 @@ void IgcFormat::read()
         int month;
         int year;
         if (sscanf(hdr_data, "%2d%2d%2d", &day, &month, &year) != 3) {
-          fatal(MYNAME ": date (H) record parse error\n'%s'\n", ibuf);
+          gbFatal("date (H) record parse error\n'%s'\n", ibuf);
         }
         if (year < 70) {
           year += 2000;
@@ -300,7 +311,7 @@ void IgcFormat::read()
         }
         date = QDate(year, month, day);
         if (!date.isValid()) {
-          fatal(MYNAME ": bad date\n%s\n", ibuf);
+          gbFatal("bad date\n%s\n", ibuf);
         }
       } else {
         // Store other header data in the track descriptions
@@ -316,7 +327,7 @@ void IgcFormat::read()
     case rec_fix: {
       // Date must appear in file before the first fix record
       if (!date.isValid()) {
-        fatal(MYNAME ": bad date\n");
+        gbFatal("bad date\n");
       }
       // Create a track for pressure altitude waypoints
       if (!pres_head) {
@@ -338,7 +349,7 @@ void IgcFormat::read()
                  &hours, &mins, &secs, &lat_deg, &lat_min, &lat_frac,
                  lat_hemi, &lon_deg, &lon_min, &lon_frac, lon_hemi,
                  &validity, &pres_alt, &gnss_alt) != 14) {
-        fatal(MYNAME ": fix (B) record parse error\n%s\n", ibuf);
+        gbFatal("fix (B) record parse error\n%s\n", ibuf);
       }
       pres_wpt = new Waypoint;
 
@@ -350,7 +361,7 @@ void IgcFormat::read()
 
       tod = QTime(hours, mins, secs);
       if (!tod.isValid()) {
-        fatal(MYNAME ": bad time\n%s\n", ibuf);
+        gbFatal("bad time\n%s\n", ibuf);
       }
 
       // Increment date if we pass midnight UTC
@@ -367,26 +378,26 @@ void IgcFormat::read()
       if (!ext_types_list.isEmpty()) {
         auto* fsdata = new igc_fsdata;
         if (global_opts.debug_level >= 7) {
-          printf(MYNAME ": Record: %s\n",qPrintable(ibuf_q));
+          gbDebug("Record: %s\n",gbLogCStr(ibuf_q));
         }
         if (global_opts.debug_level >= 6) {
-          printf(MYNAME ": Adding extension data:");
+          gbDebug("Adding extension data:");
         }
         for (const auto& [name, ext, start, len, factor] : ext_types_list) {
           double ext_data = ibuf_q.mid(start,len).toInt() / factor;
 
           fsdata->set_value(ext, ext_data, pres_wpt);
           if (global_opts.debug_level >= 6) {
-            printf(" %s:%f", qPrintable(name), ext_data);
+            gbDebug(" %s:%f", gbLogCStr(name), ext_data);
           }
         }
         if (global_opts.debug_level >= 6) {
-          printf("\n");
+          gbDebug("\n");
         }
         pres_wpt->fs.FsChainAdd(fsdata);
       }
 
-      pres_wpt->SetCreationTime(QDateTime(date, tod, Qt::UTC));
+      pres_wpt->SetCreationTime(QDateTime(date, tod, QtUTC));
 
       // Add the waypoint to the pressure altitude track
       if (pres_alt) {
@@ -418,22 +429,22 @@ void IgcFormat::read()
     case rec_log_book:
       // Get the log book sub type
       if (sscanf(ibuf, "L%3s", tmp_str) != 1) {
-        fatal(MYNAME ": log book (L) record parse error\n'%s'\n", ibuf);
+        gbFatal("log book (L) record parse error\n'%s'\n", ibuf);
       }
 
       if (strcmp(tmp_str, "PFC") == 0) {
         // Create a route for each post-flight declaration
         task_record_reader.igc_task_rec(ibuf + 4);
         break;
-      } else if (global_opts.debug_level >= 4) {
+      } else if (global_opts.debug_level >= 5) {
         if (strcmp(tmp_str, "OOI") == 0) {
-          printf(MYNAME ": Observer Input> %s\n", ibuf + 4);
+          gbDebug("Observer Input> %s\n", ibuf + 4);
         } else if (strcmp(tmp_str, "PLT") == 0) {
-          printf(MYNAME ": Pilot Input> %s\n", ibuf + 4);
+          gbDebug("Pilot Input> %s\n", ibuf + 4);
         } else if (strcmp(tmp_str, manufacturer) == 0) {
-          printf(MYNAME ": Manufacturer Input> %s\n", ibuf + 4);
+          gbDebug("Manufacturer Input> %s\n", ibuf + 4);
         } else {
-          printf(MYNAME ": Anonymous Input> %s\n", ibuf + 1);
+          gbDebug("Anonymous Input> %s\n", ibuf + 1);
         }
       }
       break;
@@ -452,15 +463,12 @@ void IgcFormat::read()
 
       QList<QString> unsupported_extensions;  // For determining how often unspported extensions exist
       QList<QString> supported_extensions;    // For debug output, determining how often supported extensions exist
-      if (global_opts.debug_level >= 1) {
-        printf(MYNAME ": I record: %s\n" MYNAME ": ", qPrintable(ibuf_q));
-      }
+      QList<QString> present_extensions;      // List of all extensions present in IGC file
+
       for (int i=3; i < ibuf_q.length(); i+=7) {
         QString ext_type = ibuf_q.mid(i+4, 3);
         QString extension_definition = ibuf_q.mid(i,7);
-        if (global_opts.debug_level >= 1) {
-          printf(" %s;",qPrintable(ext_type));
-        }
+        present_extensions.append(ext_type);
         // -1 because IGC records are one-initialized and QStrings are zero-initialized
         int begin = extension_definition.mid(0,2).toInt() - 1;
         int end = extension_definition.mid(2,2).toInt() - 1;
@@ -468,32 +476,31 @@ void IgcFormat::read()
         QString name = extension_definition.mid(4,3);
         igc_ext_type_t ext = get_ext_type(ext_type);
         if (ext != igc_ext_type_t::ext_rec_unknown) {
-          int factor = get_ext_factor(ext);
-          ext_types_list.append(std::make_tuple(name, ext, begin, len, factor));
           supported_extensions.append(name);
+          bool enabled = *ext_option_map.value(ext);
+          if (enabled) {
+            int factor = get_ext_factor(ext);
+            ext_types_list.append(std::make_tuple(name, ext, begin, len, factor));
+          }
         } else {
           unsupported_extensions.append(name);
         }
       }
       if (global_opts.debug_level >= 1) {
-        printf("\n");
+        gbDebug("I record: %s\n", gbLogCStr(ibuf_q));
+        gbDebug("Extensions present: %s\n", gbLogCStr(present_extensions.join(' ')));
       }
       if (global_opts.debug_level >= 2) {
-        printf(MYNAME ": Extensions defined in I record:\n");
-        printf(MYNAME ": (Note: IGC records are one-initialized. QStrings are zero-initialized.)\n");
+        gbDebug("Non-excluded extensions defined in I record:\n");
+        gbDebug("(Note: IGC records are one-initialized. QStrings are zero-initialized.)\n");
         for (const auto& [name, ext, begin, len, factor] : ext_types_list) {
-          printf(MYNAME ":    Extension %s (%i): Begin: %i; Length: %i\n", qPrintable(name), int(ext), begin, len);
+          gbDebug("   Extension %s (%i): Begin: %i; Length: %i\n", gbLogCStr(name), int(ext), begin, len);
         }
         if (global_opts.debug_level >= 3) {
-          printf("\n" MYNAME "Supported extensions:");
-          foreach (QString ext, supported_extensions) {
-            printf(" %s", qPrintable(ext));
-          }
-          printf("\nUnsupported extensions:");
-          foreach (QString ext, unsupported_extensions) {
-            printf(" %s", qPrintable(ext));
-          }
-          printf("\n");
+          gbDebug("Unsupported extensions (I will not ingest these, they are unsupported):\t%s\n",
+                 gbLogCStr(unsupported_extensions.join(' ')));
+          gbDebug("Supported extensions (These are present in the I record and supported):\t%s\n",
+                 gbLogCStr(supported_extensions.join(' ')));
         }
       }
     }
@@ -527,7 +534,7 @@ void IgcFormat::read()
 
     default:
     case rec_bad:
-      fatal(MYNAME ": failure reading file\n");
+      gbFatal("failure reading file\n");
       break;
     }
   }
@@ -631,25 +638,25 @@ QByteArray IgcFormat::latlon2str(const Waypoint* wpt)
   char str[18];
   if (snprintf(str, sizeof(str), "%02ld%05ld%c%03ld%05ld%c",
                lat_digits.quot, lat_digits.rem, lat_hemi, lon_digits.quot, lon_digits.rem, lon_hemi) != 17) {
-    fatal(MYNAME ": Bad waypoint format '%s'\n", str);
+    gbFatal("Bad waypoint format '%s'\n", str);
   }
   return str;
 }
 
 QByteArray IgcFormat::date2str(const gpsbabel::DateTime& dt)
 {
-  QByteArray str = dt.toUTC().toString("ddMMyy").toUtf8();
+  QByteArray str = dt.toUTC().toString(u"ddMMyy").toUtf8();
   if (str.size() != 6) {
-    fatal(MYNAME ": Bad date format '%s'\n", str.constData());
+    gbFatal("Bad date format '%s'\n", str.constData());
   }
   return str;
 }
 
 QByteArray IgcFormat::tod2str(const gpsbabel::DateTime& tod)
 {
-  QByteArray str = tod.toUTC().toString("hhmmss").toUtf8();
+  QByteArray str = tod.toUTC().toString(u"hhmmss").toUtf8();
   if (str.size() != 6) {
-    fatal(MYNAME ": Bad time of day format '%s'\n", str.constData());
+    gbFatal("Bad time of day format '%s'\n", str.constData());
   }
   return str;
 }
@@ -672,7 +679,7 @@ void IgcFormat::wr_header()
     // Date in header record is that of the first fix record
     date = track->waypoint_list.front()->GetCreationTime();
     if (!date.isValid()) {
-      fatal(MYNAME ": Bad track timestamp\n");
+      gbFatal("Bad track timestamp\n");
     }
   } else {
     // This is a bit silly, there aren't any tracks!
@@ -688,11 +695,7 @@ void IgcFormat::wr_header()
   // Other header data may have been stored in track description
   if (track && track->rte_desc.startsWith(HDRMAGIC)) {
     QString desc = track->rte_desc.mid(QString(HDRMAGIC).size());
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-    const QStringList fields = desc.split(HDRDELIM, QString::SkipEmptyParts);
-#else
     const QStringList fields = desc.split(HDRDELIM, Qt::SkipEmptyParts);
-#endif
     for (const auto& field : fields) {
       gbfprintf(file_out, "%s\r\n", CSTR(field));
     }
@@ -729,7 +732,7 @@ void IgcFormat::wr_task_hdr(const route_head* rte, unsigned int task_num)
   int num_tps = rte->rte_waypt_ct() - 2;
 
   if (num_tps < 0) {
-    fatal(MYNAME ": Empty task route\n");
+    gbFatal("Empty task route\n");
   }
   // See if the takeoff and landing waypoints are there or if we need to
   // generate them.
@@ -743,9 +746,9 @@ void IgcFormat::wr_task_hdr(const route_head* rte, unsigned int task_num)
     num_tps--;
   }
   if (num_tps < 0) {
-    fatal(MYNAME ": Too few waypoints in task route\n");
+    gbFatal("Too few waypoints in task route\n");
   } else if (num_tps > 99) {
-    fatal(MYNAME ": Too much waypoints (more than 99) in task route.\n");
+    gbFatal("Too much waypoints (more than 99) in task route.\n");
   }
   // Gather data to write to the task identification (first) record
   gpsbabel::DateTime rte_time = wpt->GetCreationTime().isValid() ? wpt->GetCreationTime() : current_time();
@@ -805,7 +808,7 @@ void IgcFormat::wr_fix_record(const Waypoint* wpt, int pres_alt, int gnss_alt)
 {
   gpsbabel::DateTime tt = wpt->GetCreationTime();
   if (!tt.isValid()) {
-    fatal(MYNAME ": Bad track timestamp\n");
+    gbFatal("Bad track timestamp\n");
   }
 
   if (unknown_alt == pres_alt) {
@@ -849,7 +852,7 @@ int IgcFormat::correlate_tracks(const route_head* pres_track, const route_head*
   } while (alt_diff > -10.0);
   gpsbabel::DateTime pres_time = (*std::prev(wpt_rit))->GetCreationTime();
   if (global_opts.debug_level >= 1) {
-    printf(MYNAME ": pressure landing time %s\n", CSTR(pres_time.toPrettyString()));
+    gbDebug("pressure landing time %s\n", CSTR(pres_time.toPrettyString()));
   }
 
   // Deduce the landing time from the GNSS altitude track based on
@@ -865,21 +868,20 @@ int IgcFormat::correlate_tracks(const route_head* pres_track, const route_head*
     // Get a crude indication of groundspeed from the change in lat/lon
     int deltat_msec = (*wpt_rit)->GetCreationTime().msecsTo(wpt->GetCreationTime());
     speed = (deltat_msec == 0) ? 0:
-            radtometers(gcdist(RAD(wpt->latitude), RAD(wpt->longitude),
-                               RAD((*wpt_rit)->latitude), RAD((*wpt_rit)->longitude))) /
+            radtometers(gcdist(wpt->position(), (*wpt_rit)->position())) /
             (0.001 * deltat_msec);
     if (global_opts.debug_level >= 2) {
-      printf(MYNAME ": speed=%.2fm/s\n", speed);
+      gbDebug("speed=%.2fm/s\n", speed);
     }
   } while (speed < 2.5);
   gpsbabel::DateTime gnss_time = (*std::prev(wpt_rit))->GetCreationTime();
   if (global_opts.debug_level >= 1) {
-    printf(MYNAME ": gnss landing time %s\n", CSTR(gnss_time.toPrettyString()));
+    gbDebug("gnss landing time %s\n", CSTR(gnss_time.toPrettyString()));
   }
   // Time adjustment is difference between the two estimated landing times
   int time_diff = gnss_time.secsTo(pres_time);
   if (15 * 60 < abs(time_diff)) {
-    warning(MYNAME ": excessive time adjustment %ds\n", time_diff);
+    gbWarning("excessive time adjustment %ds\n", time_diff);
   }
   return time_diff;
 }
@@ -944,16 +946,16 @@ void IgcFormat::wr_track()
   // If both found, attempt to merge them
   if (pres_track && gnss_track) {
     if (timeadj) {
-      if (strcmp(timeadj, "auto") == 0) {
+      if (timeadj.get() == "auto") {
         time_adj = correlate_tracks(pres_track, gnss_track);
-      } else if (sscanf(timeadj, "%d", &time_adj) != 1) {
-        fatal(MYNAME ": bad timeadj argument '%s'\n", timeadj);
+      } else {
+        time_adj = timeadj.toInt();
       }
     } else {
       time_adj = 0;
     }
     if (global_opts.debug_level >= 1) {
-      printf(MYNAME ": adjusting time by %ds\n", time_adj);
+      gbDebug("adjusting time by %ds\n", time_adj);
     }
     // Iterate through waypoints in both tracks simultaneously
     Interpolater interpolater;
@@ -983,7 +985,7 @@ void IgcFormat::wr_track()
 
 void IgcFormat::wr_init(const QString& fname)
 {
-  file_out = gbfopen(fname, "wb", MYNAME);
+  file_out = gbfopen(fname, "wb");
 }
 
 void IgcFormat::wr_deinit()
