@@ -37,14 +37,12 @@
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Off(const char* port)
+int32_t GPS_Command_Off(const char* port)
 {
   static UC data[2];
   gpsdevh* fd;
-  GPS_PPacket tra;
-  GPS_PPacket rec;
-
-  GPS_Util_Little();
+  GPS_Packet tra;
+  GPS_Packet rec;
 
   if (!GPS_Device_On(port, &fd)) {
     return gps_errno;
@@ -84,9 +82,9 @@ int32 GPS_Command_Off(const char* port)
 ** @return [int32] number of waypoint entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Waypoint(const char* port, GPS_PWay** way, pcb_fn cb)
+int32_t GPS_Command_Get_Waypoint(const char* port, GPS_PWay** way, pcb_fn cb)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   /*
    * It's a bit tacky to do this up front without ticking the
@@ -95,7 +93,7 @@ int32 GPS_Command_Get_Waypoint(const char* port, GPS_PWay** way, pcb_fn cb)
   if (gps_category_transfer) {
     ret = GPS_A101_Get(port);
     if (!ret) {
-      fatal("blah");
+      gbFatal("blah\n");
       return PROTOCOL_ERROR;
     }
 
@@ -126,9 +124,9 @@ int32 GPS_Command_Get_Waypoint(const char* port, GPS_PWay** way, pcb_fn cb)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Waypoint(const char* port, GPS_PWay* way, int32 n, int (*cb)(GPS_SWay**))
+int32_t GPS_Command_Send_Waypoint(const char* port, GPS_PWay* way, int32_t n, int (*cb)(GPS_SWay**))
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   switch (gps_waypt_transfer) {
   case pA100:
@@ -153,9 +151,9 @@ int32 GPS_Command_Send_Waypoint(const char* port, GPS_PWay* way, int32 n, int (*
 ** @return [int32] number of waypoint entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Route(const char* port, GPS_PWay** way)
+int32_t GPS_Command_Get_Route(const char* port, GPS_PWay** way)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   switch (gps_route_transfer) {
   case pA200:
@@ -185,9 +183,9 @@ int32 GPS_Command_Get_Route(const char* port, GPS_PWay** way)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Route(const char* port, GPS_PWay* way, int32 n)
+int32_t GPS_Command_Send_Route(const char* port, GPS_PWay* way, int32_t n)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
 
   switch (gps_route_transfer) {
@@ -216,9 +214,9 @@ int32 GPS_Command_Send_Route(const char* port, GPS_PWay* way, int32 n)
 ** @return [int32] number of track entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Track(const char* port, GPS_PTrack** trk, pcb_fn cb)
+int32_t GPS_Command_Get_Track(const char* port, GPS_PTrack** trk, pcb_fn cb)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_trk_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -253,9 +251,9 @@ int32 GPS_Command_Get_Track(const char* port, GPS_PTrack** trk, pcb_fn cb)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Track(const char* port, GPS_PTrack* trk, int32 n, int eraset)
+int32_t GPS_Command_Send_Track(const char* port, GPS_PTrack* trk, int32_t n, int eraset)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_trk_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -293,9 +291,9 @@ int32 GPS_Command_Send_Track(const char* port, GPS_PTrack* trk, int32 n, int era
 ** @return [int32] number of waypoint entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Proximity(const char* port, GPS_PWay** way)
+int32_t GPS_Command_Get_Proximity(const char* port, GPS_PWay** way)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_prx_waypt_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -326,9 +324,9 @@ int32 GPS_Command_Get_Proximity(const char* port, GPS_PWay** way)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Proximity(const char* port, GPS_PWay* way, int32 n)
+int32_t GPS_Command_Send_Proximity(const char* port, GPS_PWay* way, int32_t n)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
 
   if (gps_prx_waypt_transfer == -1) {
@@ -360,9 +358,9 @@ int32 GPS_Command_Send_Proximity(const char* port, GPS_PWay* way, int32 n)
 ** @return [int32] number of almanac entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Almanac(const char* port, GPS_PAlmanac** alm)
+int32_t GPS_Command_Get_Almanac(const char* port, GPS_PAlmanac** alm)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_almanac_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -393,9 +391,9 @@ int32 GPS_Command_Get_Almanac(const char* port, GPS_PAlmanac** alm)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Almanac(const char* port, GPS_PAlmanac* alm, int32 n)
+int32_t GPS_Command_Send_Almanac(const char* port, GPS_PAlmanac* alm, int32_t n)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_almanac_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -458,7 +456,7 @@ time_t GPS_Command_Get_Time(const char* port)
 ** @return [int32] true if OK
 ************************************************************************/
 
-int32 GPS_Command_Send_Time(const char* port, time_t Time)
+int32_t GPS_Command_Send_Time(const char* port, time_t Time)
 {
   time_t ret=0;
 
@@ -488,9 +486,9 @@ int32 GPS_Command_Send_Time(const char* port, time_t Time)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Get_Position(const char* port, double* lat, double* lon)
+int32_t GPS_Command_Get_Position(const char* port, double* lat, double* lon)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   switch (gps_position_transfer) {
   case pA700:
@@ -524,9 +522,9 @@ int32 GPS_Command_Get_Position(const char* port, double* lat, double* lon)
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Position(const char* port, double lat, double lon)
+int32_t GPS_Command_Send_Position(const char* port, double lat, double lon)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   switch (gps_position_transfer) {
   case pA700:
@@ -551,9 +549,9 @@ int32 GPS_Command_Send_Position(const char* port, double lat, double lon)
 ** @return [int32] success if supported and GPS starts sending
 ************************************************************************/
 
-int32 GPS_Command_Pvt_On(const char* port, gpsdevh** fd)
+int32_t GPS_Command_Pvt_On(const char* port, gpsdevh** fd)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
 
   if (gps_pvt_transfer == -1) {
@@ -580,15 +578,14 @@ int32 GPS_Command_Pvt_On(const char* port, gpsdevh** fd)
 **
 ** Instruct GPS to stop sending Pvt data every second
 **
-** @param [r] port [const char *] serial port
-** @param [w] fd [int32 *] file descriptor
+** @param [r] fd [int32] file descriptor
 **
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Pvt_Off(const char* port, gpsdevh** fd)
+int32_t GPS_Command_Pvt_Off(gpsdevh* fd)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
 
   if (gps_pvt_transfer == -1) {
@@ -597,7 +594,7 @@ int32 GPS_Command_Pvt_Off(const char* port, gpsdevh** fd)
 
   switch (gps_pvt_transfer) {
   case pA800:
-    ret = GPS_A800_Off(port,fd);
+    ret = GPS_A800_Off(fd);
     break;
   default:
     GPS_Error("Pvt_Off: Unknown position protocol");
@@ -613,15 +610,15 @@ int32 GPS_Command_Pvt_Off(const char* port, gpsdevh** fd)
 **
 ** Get a single PVT info entry
 **
-** @param [w] fd [int32 *] file descriptor
+** @param [r] fd [int32] file descriptor
 ** @param [w] pvt [GPS_PPvt_Data *] pvt data structure to fill
 **
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Pvt_Get(gpsdevh** fd, GPS_PPvt_Data* pvt)
+int32_t GPS_Command_Pvt_Get(gpsdevh* fd, GPS_PPvt_Data* pvt)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_pvt_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -651,9 +648,9 @@ int32 GPS_Command_Pvt_Get(gpsdevh** fd, GPS_PPvt_Data* pvt)
 ** @return [int32] number of lap entries
 ************************************************************************/
 
-int32 GPS_Command_Get_Lap(const char* port, GPS_PLap** lap, pcb_fn cb)
+int32_t GPS_Command_Get_Lap(const char* port, GPS_PLap** lap, pcb_fn cb)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_lap_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -688,18 +685,18 @@ int32 GPS_Command_Get_Lap(const char* port, GPS_PLap** lap, pcb_fn cb)
 **
 ** @return [int32] number of course entries
 ************************************************************************/
-int32  GPS_Command_Get_Course
+int32_t GPS_Command_Get_Course
 (const char* port,
  GPS_PCourse** crs,
  GPS_PCourse_Lap** clp,
  GPS_PTrack** trk,
  GPS_PCourse_Point** cpt,
- int32* n_clp,
- int32* n_trk,
- int32* n_cpt,
+ int32_t* n_clp,
+ int32_t* n_trk,
+ int32_t* n_cpt,
  pcb_fn cb)
 {
-  int32 ret=0;
+	int32_t ret = 0;
 
   if (gps_course_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -768,24 +765,24 @@ int32  GPS_Command_Get_Course
 **
 ** @return [int32] Success
 ************************************************************************/
-int32  GPS_Command_Send_Course
+int32_t GPS_Command_Send_Course
 (const char* port,
  GPS_PCourse* crs,
  GPS_PCourse_Lap* clp,
  GPS_PTrack* trk,
  GPS_PCourse_Point* cpt,
- int32 n_crs,
- int32 n_clp,
- int32 n_trk,
- int32 n_cpt)
+ int32_t n_crs,
+ int32_t n_clp,
+ int32_t n_trk,
+ int32_t n_cpt)
 {
   gpsdevh* fd;
   GPS_OCourse_Limits limits;
-  int32 ret;
-  int32 ret_crs=0;
-  int32 ret_clp=0;
-  int32 ret_trk=0;
-  int32 ret_cpt=0;
+  int32_t ret;
+  int32_t ret_crs = 0;
+  int32_t ret_clp = 0;
+  int32_t ret_trk = 0;
+  int32_t ret_cpt = 0;
 
   if (gps_course_transfer == -1 || gps_course_limits_transfer == -1) {
     return GPS_UNSUPPORTED;
@@ -886,9 +883,9 @@ int32  GPS_Command_Send_Course
 **
 ** @return [uint32] course index
 ************************************************************************/
-static uint32 Unique_Course_Index(GPS_PCourse* crs, int n_crs)
+static uint32_t Unique_Course_Index(GPS_PCourse* crs, int n_crs)
 {
-  uint32 idx;
+	uint32_t idx;
   int i;
 
   for (idx=0; ; idx++) {
@@ -913,9 +910,9 @@ static uint32 Unique_Course_Index(GPS_PCourse* crs, int n_crs)
 **
 ** @return [uint32] track index
 ************************************************************************/
-static uint32 Unique_Track_Index(GPS_PCourse* crs, int n_crs)
+static uint32_t Unique_Track_Index(GPS_PCourse* crs, int n_crs)
 {
-  uint32 idx;
+	uint32_t idx;
   int i;
 
   for (idx=0; ; idx++) {
@@ -1082,7 +1079,7 @@ restart_laps:
   /* Remove unreferenced tracks */
 restart_tracks:
   for (i=0; i<*n_ctk; i++) {
-    uint32 trk_idx;
+	  uint32_t trk_idx;
 
     if (!ctk[i]->ishdr) {
       continue;
@@ -1150,8 +1147,8 @@ restart_course_points:
 ** @return [int32] success
 ************************************************************************/
 
-int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32 n_trk,
-                                       GPS_PWay* wpt, int32 n_wpt, int eraset)
+int32_t GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32_t n_trk,
+                                         GPS_PWay* wpt, int32_t n_wpt, int eraset)
 {
   GPS_PCourse* crs = nullptr;
   GPS_PCourse_Lap* clp = nullptr;
@@ -1159,7 +1156,7 @@ int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32
   GPS_PCourse_Point* cpt = nullptr;
   int n_crs, n_clp=0, n_ctk=0, n_cpt=0;
   int i, j, trk_end, new_crs, first_new_ctk;
-  int32 ret;
+  int32_t ret;
 
   /* Read existing courses from device */
   if (eraset) {
@@ -1248,7 +1245,7 @@ int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32
   cpt = (GPS_SCourse_Point**) xrealloc(cpt, (n_cpt+n_wpt) * sizeof(GPS_PCourse_Point));
   for (i=0; i<n_wpt; i++) {
     double dist, min_dist = DBL_MAX;
-    uint32 min_dist_idx = 0, trk_idx = 0, min_dist_trk_idx = 0;
+    uint32_t min_dist_idx = 0, trk_idx = 0, min_dist_trk_idx = 0;
 
     /* Find closest track point */
     for (j=first_new_ctk; j<n_ctk; j++) {
@@ -1257,7 +1254,7 @@ int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32
         continue;
       }
       if (wpt[i] == nullptr || ctk[j] == nullptr) {
-        fatal("Internal error in GPS_Command_Send_Track_As_Course");
+        gbFatal("Internal error in GPS_Command_Send_Track_As_Course\n");
       }
       dist = gcgeodist(wpt[i]->lat, wpt[i]->lon, ctk[j]->lat, ctk[j]->lon);
       if (dist < min_dist) {
@@ -1268,7 +1265,7 @@ int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32
     }
 
     if (wpt[i] == nullptr) {
-      fatal("Internal error in GPS_Command_Send_Track_As_Course: no wpt");
+      gbFatal("Internal error in GPS_Command_Send_Track_As_Course: no wpt\n");
     }
     cpt[i+n_cpt] = GPS_Course_Point_New();
     strncpy(cpt[i+n_cpt]->name, wpt[i]->cmnt,
@@ -1314,22 +1311,23 @@ int32 GPS_Command_Send_Track_As_Course(const char* port, GPS_PTrack* trk, int32
 }
 
 /*Stubs for unimplemented stuff*/
-int32  GPS_Command_Get_Workout(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
+int32_t GPS_Command_Get_Workout(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
 {
   return 0;
 }
 
-int32  GPS_Command_Get_Fitness_User_Profile(const char* /* port */, void**  /* lap */, int (* /* cb */)(int, GPS_SWay**))
+int32_t GPS_Command_Get_Fitness_User_Profile(const char* /* port */, void** /* lap */,
+                                             int (* /* cb */)(int, GPS_SWay**))
 {
   return 0;
 }
 
-int32  GPS_Command_Get_Workout_Limits(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
+int32_t GPS_Command_Get_Workout_Limits(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
 {
   return 0;
 }
 
-int32  GPS_Command_Get_Course_Limits(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
+int32_t GPS_Command_Get_Course_Limits(const char* /* port */, void** /* lap */, int (* /* cb */)(int, GPS_SWay**))
 {
   return 0;
 }
