@@ -20,8 +20,6 @@
 
 */
 
-#include <cstring>                     // for strlen, strchr, st
-
 #include <QByteArray>                  // for QByteArray
 #include <QIODevice>                   // for operator|, QIODevice, QIODevice::Text, QIODevice::WriteOnly
 #include <QLatin1String>               // for QLatin1String
@@ -34,12 +32,10 @@
 #include "osm.h"
 #include "src/core/datetime.h"         // for DateTime
 #include "src/core/xmlstreamwriter.h"  // for XmlStreamWriter
-#include "xmlgeneric.h"                // for xg_string, build_xg_tag_map, xml_deinit, xml_init, xml_read
+#include "xmlgeneric.h"                // for xml_deinit, xml_init, xml_read
 
 
-#define MYNAME "osm"
-
-const char* const OsmFormat::osm_features[] = {
+const QStringList OsmFormat::osm_features = {
   "- dummy -",	/*  0 */
   "aeroway",	/*  1 */
   "amenity",	/*  2 */
@@ -60,12 +56,11 @@ const char* const OsmFormat::osm_features[] = {
   "tourism",	/* 17 */
   "waterway",	/* 18 */
   "aerialway",	/* 19 */
-  nullptr
 };
 
 /* based on <http://wiki.openstreetmap.org/index.php/Map_Features> */
 
-const OsmFormat::osm_icon_mapping_t OsmFormat::osm_icon_mappings[] = {
+const QVector<OsmFormat::osm_icon_mapping_t> OsmFormat::osm_icon_mappings = {
 
   /* cycleway ...*/
 
@@ -364,8 +359,6 @@ const OsmFormat::osm_icon_mapping_t OsmFormat::osm_icon_mappings[] = {
 //	{ 13, "locality",		"?" },
 //	{ 13, "island",			"?" },
 //	{ 13, "User Defined",		"?" },
-
-  { -1, nullptr, nullptr }
 };
 
 /*******************************************************************************/
@@ -376,24 +369,24 @@ void
 OsmFormat::osm_features_init()
 {
   /* the first of osm_features is a place holder */
-  for (int i = 1; osm_features[i]; ++i) {
+  for (int i = 1; i < osm_features.size(); ++i) {
     keys.insert(osm_features[i], i);
   }
 
-  for (int i = 0; osm_icon_mappings[i].value; ++i) {
-    QPair<int, QString> key(osm_icon_mappings[i].key, osm_icon_mappings[i].value);
-    values.insert(key, &osm_icon_mappings[i]);
+  for (const auto& mapping : osm_icon_mappings) {
+    QPair<int, QString> key(mapping.key, mapping.value);
+    values.insert(key, &mapping);
   }
 }
 
-char
+int
 OsmFormat::osm_feature_ikey(const QString& key) const
 {
   return keys.value(key, -1);
 }
 
 QString
-OsmFormat::osm_feature_symbol(const int ikey, const char* value) const
+OsmFormat::osm_feature_symbol(const int ikey, const QString& value) const
 {
   QPair<int, QString> key(ikey, value);
 
@@ -413,7 +406,7 @@ OsmFormat::osm_strip_html(const QString& str)
 }
 
 void
-OsmFormat::osm_node_end(xg_string /*unused*/, const QXmlStreamAttributes* /*unused*/)
+OsmFormat::osm_node_end(const QString& /*unused*/, const QXmlStreamAttributes* /*unused*/)
 {
   if (wpt) {
     if (wpt->wpt_flags.fmt_use) {
@@ -426,7 +419,7 @@ OsmFormat::osm_node_end(xg_string /*unused*/, const QXmlStreamAttributes* /*unus
 }
 
 void
-OsmFormat::osm_node(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_node(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
   wpt = new Waypoint;
 
@@ -434,7 +427,7 @@ OsmFormat::osm_node(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
     QString atstr = attrv->value("id").toString();
     wpt->description =  "osm-id " + atstr;
     if (waypoints.contains(atstr)) {
-      warning(MYNAME ": Duplicate osm-id %s!\n", qPrintable(atstr));
+      gbWarning("Duplicate osm-id %s!\n", gbLogCStr(atstr));
     } else {
       waypoints.insert(atstr, wpt);
       wpt->wpt_flags.fmt_use = 1;
@@ -457,10 +450,10 @@ OsmFormat::osm_node(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
 }
 
 void
-OsmFormat::osm_node_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_node_tag(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
-  QString key, value;
-  signed char ikey;
+  QString key;
+  QString value;
 
   if (attrv->hasAttribute("k")) {
     key = attrv->value("k").toString();
@@ -477,8 +470,8 @@ OsmFormat::osm_node_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
     }
   } else if (key == QLatin1String("name:en")) {
     wpt->shortname = str;
-  } else if ((ikey = osm_feature_ikey(key)) >= 0) {
-    wpt->icon_descr = osm_feature_symbol(ikey, CSTR(value));
+  } else if (int ikey = osm_feature_ikey(key); ikey >= 0) {
+    wpt->icon_descr = osm_feature_symbol(ikey, value);
   } else if (key == QLatin1String("note")) {
     if (wpt->notes.isEmpty()) {
       wpt->notes = str;
@@ -487,13 +480,13 @@ OsmFormat::osm_node_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
       wpt->notes += str;
     }
   } else if (key == QLatin1String("gps:hdop")) {
-    wpt->hdop = str.toDouble();
+    wpt->hdop = str.toFloat();
   } else if (key == QLatin1String("gps:vdop")) {
-    wpt->vdop = str.toDouble();
+    wpt->vdop = str.toFloat();
   } else if (key == QLatin1String("gps:pdop")) {
-    wpt->pdop = str.toDouble();
+    wpt->pdop = str.toFloat();
   } else if (key == QLatin1String("gps:sat")) {
-    wpt->sat = str.toDouble();
+    wpt->sat = str.toInt();
   } else if (key == QLatin1String("gps:fix")) {
     if (str == QLatin1String("2d")) {
       wpt->fix = fix_2d;
@@ -510,7 +503,7 @@ OsmFormat::osm_node_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
 }
 
 void
-OsmFormat::osm_way(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_way(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
   rte = new route_head;
   // create a wpt to represent the route center if it has a center tag
@@ -521,7 +514,7 @@ OsmFormat::osm_way(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
 }
 
 void
-OsmFormat::osm_way_nd(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_way_nd(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
   if (attrv->hasAttribute("ref")) {
     QString atstr = attrv->value("ref").toString();
@@ -531,16 +524,16 @@ OsmFormat::osm_way_nd(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
       auto* tmp = new Waypoint(*ctmp);
       route_add_wpt(rte, tmp);
     } else {
-      warning(MYNAME ": Way reference id \"%s\" wasn't listed under nodes!\n", qPrintable(atstr));
+      gbWarning("Way reference id \"%s\" wasn't listed under nodes!\n", gbLogCStr(atstr));
     }
   }
 }
 
 void
-OsmFormat::osm_way_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_way_tag(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
-  QString key, value;
-  signed char ikey;
+  QString key;
+  QString value;
 
   if (attrv->hasAttribute("k")) {
     key = attrv->value("k").toString();
@@ -561,8 +554,8 @@ OsmFormat::osm_way_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
 
     wpt->shortname = str;
     // The remaining cases only apply to the center node
-  } else if ((ikey = osm_feature_ikey(key)) >= 0) {
-    wpt->icon_descr = osm_feature_symbol(ikey, CSTR(value));
+  } else if (int ikey = osm_feature_ikey(key); ikey >= 0) {
+    wpt->icon_descr = osm_feature_symbol(ikey, value);
   } else if (key == "note") {
     if (wpt->notes.isEmpty()) {
       wpt->notes = str;
@@ -574,7 +567,7 @@ OsmFormat::osm_way_tag(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
 }
 
 void
-OsmFormat::osm_way_center(xg_string /*unused*/, const QXmlStreamAttributes* attrv)
+OsmFormat::osm_way_center(const QString& /*unused*/, const QXmlStreamAttributes* attrv)
 {
   wpt->wpt_flags.fmt_use = 1;
 
@@ -587,7 +580,7 @@ OsmFormat::osm_way_center(xg_string /*unused*/, const QXmlStreamAttributes* attr
 }
 
 void
-OsmFormat::osm_way_end(xg_string /*unused*/, const QXmlStreamAttributes* /*unused*/)
+OsmFormat::osm_way_end(const QString& /*unused*/, const QXmlStreamAttributes* /*unused*/)
 {
   if (rte) {
     route_add_head(rte);
@@ -615,19 +608,22 @@ OsmFormat::rd_init(const QString& fname)
     osm_features_init();
   }
 
-  xml_init(fname, build_xg_tag_map(this, osm_map), nullptr, nullptr, nullptr, true);
+  xml_reader = new XmlGenericReader;
+  xml_reader->xml_init(fname, this, osm_map);
 }
 
 void
 OsmFormat::read()
 {
-  xml_read();
+  xml_reader->xml_read();
 }
 
 void
 OsmFormat::rd_deinit()
 {
-  xml_deinit();
+  delete xml_reader;
+  xml_reader = nullptr;
+
   waypoints.clear();
 }
 
@@ -642,8 +638,8 @@ OsmFormat::osm_init_icons()
     return;
   }
 
-  for (int i = 0; osm_icon_mappings[i].value; ++i) {
-    icons.insert(osm_icon_mappings[i].icon, &osm_icon_mappings[i]);
+  for (const auto& mapping : osm_icon_mappings) {
+    icons.insert(mapping.icon, &mapping);
   }
 }
 
@@ -718,7 +714,7 @@ OsmFormat::osm_waypt_disp(const Waypoint* waypoint)
   fout->writeAttribute(QStringLiteral("lat"), QString::number(waypoint->latitude, 'f', 7));
   fout->writeAttribute(QStringLiteral("lon"), QString::number(waypoint->longitude, 'f', 7));
   if (waypoint->creation_time.isValid()) {
-    // osm readers don't uniformally support fractional seconds, and may only accept time zone designation Z.
+    // osm readers don't uniformly support fractional seconds, and may only accept time zone designation Z.
     fout->writeAttribute(QStringLiteral("timestamp"), waypoint->creation_time.toUTC().toString(Qt::ISODate));
   }
 
@@ -756,15 +752,14 @@ OsmFormat::osm_waypt_disp(const Waypoint* waypoint)
     break;
   }
 
-  if (strlen(created_by) !=0) {
-    QString value(created_by);
+  if (QString creator = created_by; !creator.isEmpty()) {
     if (!gpsbabel_testmode()) {
-      if (strcmp("GPSBabel",created_by)==0) {
-        value += '-';
-        value += gpsbabel_version;
+      if (creator == "GPSBabel") {
+        creator += '-';
+        creator += gpsbabel_version;
       }
     }
-    osm_write_tag(QStringLiteral("created_by"), value);
+    osm_write_tag(QStringLiteral("created_by"), creator);
   }
 
   osm_write_tag("name", waypoint->shortname);
@@ -816,23 +811,20 @@ OsmFormat::osm_rte_disp_trail(const route_head* route)
     return;
   }
 
-  if (strlen(created_by) !=0) {
-    QString value(created_by);
+  if (QString creator = created_by; !creator.isEmpty()) {
     if (!gpsbabel_testmode()) {
-      if (strcmp("GPSBabel",created_by)==0) {
-        value += '-';
-        value += gpsbabel_version;
+      if (creator == "GPSBabel") {
+        creator += '-';
+        creator += gpsbabel_version;
       }
     }
-    osm_write_tag(QStringLiteral("created_by"), value);
+    osm_write_tag(QStringLiteral("created_by"), creator);
   }
 
   osm_write_tag("name", route->rte_name);
   osm_write_tag("note", route->rte_desc);
 
-  if (opt_tag && (case_ignore_strncmp(opt_tag, "tagnd", 5) != 0)) {
-    osm_write_opt_tag(opt_tag);
-  }
+  osm_write_opt_tag(opt_tag);
 
   fout->writeEndElement(); // way
 }
@@ -874,11 +866,11 @@ OsmFormat::write()
   route_disp_all(nullptr, nullptr, osm_waypt_disp_lambda);
   track_disp_all(nullptr, nullptr, osm_waypt_disp_lambda);
 
-  auto osm_rte_disp_head_lambda = [this](const route_head* rte)->void {
-    osm_rte_disp_head(rte);
+  auto osm_rte_disp_head_lambda = [this](const route_head* rh)->void {
+    osm_rte_disp_head(rh);
   };
-  auto osm_rte_disp_trail_lambda = [this](const route_head* rte)->void {
-    osm_rte_disp_trail(rte);
+  auto osm_rte_disp_trail_lambda = [this](const route_head* rh)->void {
+    osm_rte_disp_trail(rh);
   };
   auto osm_rtept_disp_lambda = [this](const Waypoint* waypointp)->void {
     osm_rtept_disp(waypointp);
