@@ -36,140 +36,49 @@
 
  */
 
-#include <cctype>                 // for tolower
+#include "ozi.h"
+
 #include <cmath>                  // for lround
 
 #include <QByteArray>             // for QByteArray
 #include <QChar>                  // for operator==, QChar
 #include <QFile>                  // for QFile
 #include <QFileInfo>              // for QFileInfo
-#include <QIODevice>              // for operator|, QIODevice::WriteOnly, QIODevice::ReadOnly, QIODevice, QIODevice::OpenModeFlag
-#include <QString>                // for QString
+#include <QFlags>                 // for QFlags
+#include <QIODevice>              // for operator&, QIODevice
+#include <QList>                  // for QList, QList<>::const_iterator
+#include <QString>                // for QString, operator==
 #include <QStringList>            // for QStringList
+#include <QStringLiteral>         // for qMakeStringPrivate, QStringLiteral
 #include <QTextStream>            // for QTextStream, operator<<, qSetRealNumberPrecision, QTextStream::FixedNotation
-#include <QVector>                // for QVector
 #include <Qt>                     // for CaseInsensitive
 #include <QtGlobal>               // for qPrintable
 
 #include "defs.h"
 #include "csv_util.h"             // for csv_stringclean
-#include "formspec.h"             // for FsChainAdd, FsChainFind, kFsOzi, FormatSpecificData
-#include "jeeps/gpsmath.h"        // for GPS_Math_Known_Datum_To_WGS84_M
+#include "formspec.h"             // for FormatSpecificDataList, kFsOzi
+#include "jeeps/gpsmath.h"        // for GPS_Lookup_Datum_Index, GPS_Math_Known_Datum_To_WGS84_M
 #include "mkshort.h"              // for MakeShort
 #include "src/core/datetime.h"    // for DateTime
 #include "src/core/textstream.h"  // for TextStream
 
 
-#define MYNAME        "OZI"
 #define BADCHARS	",\r\n"
 #define DAYS_SINCE_1990	25569
 
-struct ozi_fsdata : FormatSpecificData {
-  ozi_fsdata() : FormatSpecificData(kFsOzi) {}
-
-  ozi_fsdata* clone() const override
-  {
-    return new ozi_fsdata(*this);
-  }
-
-  int fgcolor{0};
-  int bgcolor{65535};
-};
-
-static gpsbabel::TextStream* stream = nullptr;
-
-static MakeShort* mkshort_handle;
-static route_head* trk_head;
-static route_head* rte_head;
-
-static int track_out_count;
-static int route_out_count;
-static int route_wpt_count;
-static int new_track;
-
-static char* snlenopt = nullptr;
-static char* snwhiteopt = nullptr;
-static char* snupperopt = nullptr;
-static char* snuniqueopt = nullptr;
-static char* wptfgcolor = nullptr;
-static char* wptbgcolor = nullptr;
-static char* pack_opt = nullptr;
-static int datum;
-static char* proximityarg = nullptr;
-static double proximity;
-static char* altunit_opt;
-static char* proxunit_opt;
-static char altunit;
-static char proxunit;
-static double alt_scale;
-static double prox_scale;
-static char* opt_codec;
-
-static
-QVector<arglist_t> ozi_args = {
-  {
-    "pack", &pack_opt, "Write all tracks into one file",
-    nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
-  },
-  {
-    "snlen", &snlenopt, "Max synthesized shortname length",
-    "32", ARGTYPE_INT, "1", nullptr, nullptr
-  },
-  {
-    "snwhite", &snwhiteopt, "Allow whitespace synth. shortnames",
-    nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
-  },
-  {
-    "snupper", &snupperopt, "UPPERCASE synth. shortnames",
-    nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
-  },
-  {
-    "snunique", &snuniqueopt, "Make synth. shortnames unique",
-    nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
-  },
-  {
-    "wptfgcolor", &wptfgcolor, "Waypoint foreground color",
-    "black", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-  {
-    "wptbgcolor", &wptbgcolor, "Waypoint background color",
-    "yellow", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-  {
-    "proximity", &proximityarg, "Proximity distance",
-    "0", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-  {
-    "altunit", &altunit_opt, "Unit used in altitude values",
-    "feet", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-  {
-    "proxunit", &proxunit_opt, "Unit used in proximity values",
-    "miles", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-  {
-    "codec", &opt_codec, "codec to use for reading and writing strings (default windows-1252)",
-    "windows-1252", ARGTYPE_STRING, ARG_NOMINMAX, nullptr
-  },
-};
-
-static gpsdata_type ozi_objective;
-
-static QString ozi_ofname;
-
-static void
-ozi_open_io(const QString& fname, QIODevice::OpenModeFlag mode)
+void
+OziFormat::ozi_open_io(const QString& fname, QIODevice::OpenModeFlag mode)
 {
   stream = new gpsbabel::TextStream;
-  stream->open(fname, mode, MYNAME, opt_codec);
+  stream->open(fname, mode, opt_codec.get().toUtf8());
 
   if (mode & QFile::WriteOnly) {
     stream->setRealNumberNotation(QTextStream::FixedNotation);
   }
 }
 
-static void
-ozi_close_io()
+void
+OziFormat::ozi_close_io()
 {
   if (!stream) {
     return;
@@ -179,9 +88,8 @@ ozi_close_io()
   stream = nullptr;
 }
 
-static
-ozi_fsdata*
-ozi_alloc_fsdata()
+OziFormat::ozi_fsdata*
+OziFormat::ozi_alloc_fsdata()
 {
   auto* fsdata = new ozi_fsdata;
 
@@ -192,8 +100,8 @@ ozi_alloc_fsdata()
   return fsdata;
 }
 
-static QString
-ozi_get_time_str(const Waypoint* waypointp)
+QString
+OziFormat::ozi_get_time_str(const Waypoint* waypointp)
 {
   if (waypointp->creation_time.isValid()) {
     double time = (waypt_time(waypointp) / SECONDS_PER_DAY) + DAYS_SINCE_1990;
@@ -202,8 +110,8 @@ ozi_get_time_str(const Waypoint* waypointp)
   return QString("");
 }
 
-static void
-ozi_set_time_str(const QString& str, Waypoint* waypointp)
+void
+OziFormat::ozi_set_time_str(const QString& str, Waypoint* waypointp)
 {
   double ozi_time = str.toDouble();
 
@@ -213,11 +121,13 @@ ozi_set_time_str(const QString& str, Waypoint* waypointp)
   }
 }
 
-static void
-ozi_convert_datum(Waypoint* wpt)
+void
+OziFormat::ozi_convert_datum(Waypoint* wpt) const
 {
-  if (datum != kDautmWGS84) {
-    double lat, lon, alt;
+  if (datum != kDatumWGS84) {
+    double lat;
+    double lon;
+    double alt;
     GPS_Math_Known_Datum_To_WGS84_M(wpt->latitude, wpt->longitude, 0.0,
                                     &lat, &lon, &alt, datum);
     wpt->latitude = lat;
@@ -225,8 +135,8 @@ ozi_convert_datum(Waypoint* wpt)
   }
 }
 
-static void
-ozi_openfile(const QString& fname)
+void
+OziFormat::ozi_openfile(const QString& fname)
 {
   const char* ozi_extensions[] = {nullptr, "plt", "wpt", "rte"};
 
@@ -266,8 +176,8 @@ ozi_openfile(const QString& fname)
   ozi_open_io(tmpname, QFile::WriteOnly);
 }
 
-static void
-ozi_track_hdr(const route_head* rte)
+void
+OziFormat::ozi_track_hdr(const route_head* rte)
 {
   if ((! pack_opt) || (track_out_count == 0)) {
     ozi_openfile(ozi_ofname);
@@ -285,8 +195,8 @@ ozi_track_hdr(const route_head* rte)
   new_track = 1;
 }
 
-static void
-ozi_track_disp(const Waypoint* waypointp)
+void
+OziFormat::ozi_track_disp(const Waypoint* waypointp)
 {
   double alt;
 
@@ -307,14 +217,20 @@ ozi_track_disp(const Waypoint* waypointp)
   new_track = 0;
 }
 
-static void
-ozi_track_pr()
+void
+OziFormat::ozi_track_pr()
 {
-  track_disp_all(ozi_track_hdr, nullptr, ozi_track_disp);
+  auto ozi_track_hdr_lambda = [this](const route_head* rte)->void {
+    ozi_track_hdr(rte);
+  };
+  auto ozi_track_disp_lambda = [this](const Waypoint* waypointp)->void {
+    ozi_track_disp(waypointp);
+  };
+  track_disp_all(ozi_track_hdr_lambda, nullptr, ozi_track_disp_lambda);
 }
 
-static void
-ozi_route_hdr(const route_head* rte)
+void
+OziFormat::ozi_route_hdr(const route_head* rte)
 {
   /* prologue on 1st pass only */
   if (route_out_count == 0) {
@@ -344,8 +260,8 @@ ozi_route_hdr(const route_head* rte)
                    << rte->rte_desc << ",\r\n";
 }
 
-static void
-ozi_route_disp(const Waypoint* waypointp)
+void
+OziFormat::ozi_route_disp(const Waypoint* waypointp)
 {
   route_wpt_count++;
 
@@ -390,65 +306,67 @@ ozi_route_disp(const Waypoint* waypointp)
 
 }
 
-static void
-ozi_route_pr()
+void
+OziFormat::ozi_route_pr()
 {
-  route_disp_all(ozi_route_hdr, nullptr, ozi_route_disp);
+  auto ozi_route_hdr_lambda = [this](const route_head* rte)->void {
+    ozi_route_hdr(rte);
+  };
+  auto ozi_route_disp_lambda = [this](const Waypoint* waypointp)->void {
+    ozi_route_disp(waypointp);
+  };
+  route_disp_all(ozi_route_hdr_lambda, nullptr, ozi_route_disp_lambda);
 }
 
-static void
-ozi_init_units(const int direction)	/* 0 = in; 1 = out */
+void
+OziFormat::ozi_init_units(const int direction)	/* 0 = in; 1 = out */
 {
-  altunit = tolower(*altunit_opt);
-  switch (altunit) {
-  case 'm': /* meters, okay */
-    alt_scale = 1.0;
-    break;
-  case 'f': /* feet, okay */
-    alt_scale = FEET_TO_METERS(1.0);
-    break;
-  default:
-    fatal(MYNAME ": Unknown value (%s) for option 'altunit'!\n", altunit_opt);
+  if (altunit_opt.get().startsWith('m', Qt::CaseInsensitive)) {
+    altunit = 'm';
+    alt_scale = 1.0; /* meters */
+  } else if (altunit_opt.get().startsWith('f', Qt::CaseInsensitive)) {
+    altunit = 'f';
+    alt_scale = FEET_TO_METERS(1.0); /* feet */
+  } else {
+    gbFatal("Unknown value (%s) for option 'altunit'!\n", gbLogCStr(altunit_opt));
   }
   if (direction != 0) {
-    alt_scale = 1 / alt_scale;
+    alt_scale = 1.0 / alt_scale;
   }
 
-  proxunit = tolower(*proxunit_opt);
-  switch (proxunit) {
-  case 'm': /* miles, okay */
-    prox_scale = MILES_TO_METERS(1.0);
-    break;
-  case 'n': /* nautical miles, okay */
-    prox_scale = NMILES_TO_METERS(1.0);
-    break;
-  case 'k': /* kilometers, okay */
-    prox_scale = 1000.0;
-    break;
-  default:
-    fatal(MYNAME ": Unknown value (%s) for option 'proxunit'!\n", proxunit_opt);
+  if (proxunit_opt.get().startsWith('m')) {
+    proxunit = 'm';
+    prox_scale = MILES_TO_METERS(1.0); /* miles */
+  } else if (proxunit_opt.get().startsWith('n')) {
+    proxunit = 'n';
+    prox_scale = NMILES_TO_METERS(1.0); /* nautical miles */
+  } else if (proxunit_opt.get().startsWith('k')) {
+    proxunit = 'k';
+    prox_scale = 1000.0; /* kilometers */
+  } else {
+    gbFatal("Unknown value (%s) for option 'proxunit'!\n", gbLogCStr(proxunit_opt));
   }
   if (direction != 0) {
-    prox_scale = 1 / prox_scale;
+    prox_scale = 1.0 / prox_scale;
   }
 }
 
-static void
-rd_init(const QString& fname)
+void
+OziFormat::rd_init(const QString& fname)
 {
   ozi_open_io(fname, QFile::ReadOnly);
 
   ozi_init_units(0);
 }
 
-static void
-rd_deinit()
+void
+OziFormat::rd_deinit()
 {
   ozi_close_io();
 }
 
-static void
-wr_init(const QString& fname)
+void
+OziFormat::wr_init(const QString& fname)
 {
 
   /* At this point, we have no idea whether we'll be writing waypoint,
@@ -463,29 +381,29 @@ wr_init(const QString& fname)
   /* set mkshort options from the command line if applicable */
   if (global_opts.synthesize_shortnames) {
 
-    mkshort_handle->set_length(xstrtoi(snlenopt, nullptr, 10));
+    mkshort_handle->set_length(snlenopt.get_result());
 
-    if (snwhiteopt) {
-      mkshort_handle->set_whitespace_ok(xstrtoi(snwhiteopt, nullptr, 10));
+    if (snwhiteopt.has_value()) {
+      mkshort_handle->set_whitespace_ok(snwhiteopt);
     }
 
-    if (snupperopt) {
-      mkshort_handle->set_mustupper(xstrtoi(snupperopt, nullptr, 10));
+    if (snupperopt.has_value()) {
+      mkshort_handle->set_mustupper(snupperopt);
     }
 
-    if (snuniqueopt) {
-      mkshort_handle->set_mustuniq(xstrtoi(snuniqueopt, nullptr, 10));
+    if (snuniqueopt.has_value()) {
+      mkshort_handle->set_mustuniq(snuniqueopt);
     }
 
     mkshort_handle->set_badchars("\",");
   }
 
   ozi_init_units(1);
-  parse_distance(proximityarg, &proximity, 1 / prox_scale, MYNAME);
+  parse_distance(proximityarg, &proximity, 1.0 / prox_scale);
 }
 
-static void
-wr_deinit()
+void
+OziFormat::wr_deinit()
 {
   ozi_close_io();
   ozi_ofname.clear();
@@ -494,8 +412,8 @@ wr_deinit()
   mkshort_handle = nullptr;
 }
 
-static void
-ozi_parse_waypt(int field, const QString& str, Waypoint* wpt_tmp, ozi_fsdata* fsdata)
+void
+OziFormat::ozi_parse_waypt(int field, const QString& str, Waypoint* wpt_tmp, ozi_fsdata* fsdata) const
 {
   double alt;
 
@@ -589,8 +507,8 @@ ozi_parse_waypt(int field, const QString& str, Waypoint* wpt_tmp, ozi_fsdata* fs
   }
 }
 
-static void
-ozi_parse_track(int field, const QString& str, Waypoint* wpt_tmp, char* trk_name)
+void
+OziFormat::ozi_parse_track(int field, const QString& str, Waypoint* wpt_tmp, char* trk_name)
 {
   if (str.isEmpty()) {
     return;
@@ -634,8 +552,8 @@ ozi_parse_track(int field, const QString& str, Waypoint* wpt_tmp, char* trk_name
   }
 }
 
-static void
-ozi_parse_routepoint(int field, const QString& str, Waypoint* wpt_tmp)
+void
+OziFormat::ozi_parse_routepoint(int field, const QString& str, Waypoint* wpt_tmp)
 {
   if (str.isEmpty()) {
     return;
@@ -694,8 +612,8 @@ ozi_parse_routepoint(int field, const QString& str, Waypoint* wpt_tmp)
   }
 }
 
-static void
-ozi_parse_routeheader(int field, const QString& str)
+void
+OziFormat::ozi_parse_routeheader(int field, const QString& str)
 {
 
   switch (field) {
@@ -724,8 +642,8 @@ ozi_parse_routeheader(int field, const QString& str)
   }
 }
 
-static void
-data_read()
+void
+OziFormat::read()
 {
   QString buff;
   char* trk_name = nullptr;
@@ -752,7 +670,7 @@ data_read()
       datum = GPS_Lookup_Datum_Index(buff);
 
       if (datum < 0) {
-        fatal(MYNAME ": Unsupported datum '%s'.\n", qPrintable(buff));
+        gbFatal("Unsupported datum '%s'.\n", gbLogCStr(buff));
       }
     } else if (linecount == 3) {
       if (buff.startsWith( "Altitude is in ", Qt::CaseInsensitive)) {
@@ -764,7 +682,7 @@ data_read()
           altunit = 'm';
           alt_scale = 1.0;
         } else {
-          fatal(MYNAME ": Unknown unit (%s) used by altitude values!\n", qPrintable(unit));
+          gbFatal("Unknown unit (%s) used by altitude values!\n", gbLogCStr(unit));
         }
       }
     } else if ((linecount == 5) && (ozi_objective == trkdata)) {
@@ -803,7 +721,7 @@ data_read()
           ozi_parse_waypt(i, s, wpt_tmp, fsdata);
           break;
         case posndata:
-          fatal(MYNAME ": realtime positioning not supported.\n");
+          gbFatal("realtime positioning not supported.\n");
           break;
         }
         i++;
@@ -838,7 +756,7 @@ data_read()
         }
         break;
       case posndata:
-        fatal(MYNAME ": realtime positioning not supported.\n");
+        gbFatal("realtime positioning not supported.\n");
         break;
       }
 
@@ -853,10 +771,9 @@ data_read()
   }
 }
 
-static void
-ozi_waypt_pr(const Waypoint* wpt)
+void
+OziFormat::ozi_waypt_pr(const Waypoint* wpt, int index)
 {
-  static int index = 0;
   double alt;
   QString description;
   QString shortname;
@@ -901,8 +818,6 @@ ozi_waypt_pr(const Waypoint* wpt)
     description = csv_stringclean(wpt->description, BADCHARS);
   }
 
-  index++;
-
   if (wpt->icon_descr.toInt()) {
     icon = wpt->icon_descr.toInt();
   }
@@ -931,8 +846,8 @@ ozi_waypt_pr(const Waypoint* wpt)
   }
 }
 
-static void
-data_write()
+void
+OziFormat::write()
 {
   if (waypt_count()) {
     track_out_count = route_out_count = 0;
@@ -942,7 +857,12 @@ data_write()
                      << "WGS 84\r\n"
                      << "Reserved 2\r\n"
                      << "Reserved 3\r\n";
-    waypt_disp_all(ozi_waypt_pr);
+
+    int index = 0;
+    auto ozi_waypt_pr_lambda = [this, &index](const Waypoint* waypointp)->void {
+      ozi_waypt_pr(waypointp, ++index);
+    };
+    waypt_disp_all(ozi_waypt_pr_lambda);
   }
 
   if (track_count()) {
@@ -957,17 +877,3 @@ data_write()
   }
 
 }
-
-ff_vecs_t ozi_vecs = {
-  ff_type_file,
-  FF_CAP_RW_ALL,
-  rd_init,
-  wr_init,
-  rd_deinit,
-  wr_deinit,
-  data_read,
-  data_write,
-  nullptr,
-  &ozi_args,
-  NULL_POS_OPS
-};
