@@ -22,12 +22,13 @@
 #ifndef RADIUS_H_INCLUDED_
 #define RADIUS_H_INCLUDED_
 
+#include <QList>     // for QList
 #include <QString>    // for QString
 #include <QVector>    // for QVector
 
 #include "defs.h"     // for arglist_t, ARG_NOMINMAX, ARGTYPE_FLOAT, ARGTYPE_REQUIRED, ARGTYPE_BOOL, ARGTYPE_INT, ARGTYPE_STRING, Waypoint
 #include "filter.h"   // for Filter
-#include "grtcirc.h"  // for RAD, gcdist, radtomiles
+#include "option.h"  // for OptionString, OptionBool
 
 #if FILTERS_ENABLED
 
@@ -51,44 +52,39 @@ private:
 
   /* Member Functions */
 
-  static double gc_distance(double lat1, double lon1, double lat2, double lon2)
-  {
-    return radtomiles(gcdist(RAD(lat1), RAD(lon1), RAD(lat2), RAD(lon2)));
-  }
-
   /* Data Members */
 
   double pos_dist{};
-  char* distopt = nullptr;
-  char* latopt = nullptr;
-  char* lonopt = nullptr;
-  char* exclopt = nullptr;
-  char* nosort = nullptr;
-  char* maxctarg = nullptr;
-  char* routename = nullptr;
+  OptionDouble distopt{true};
+  OptionDouble latopt;
+  OptionDouble lonopt;
+  OptionBool exclopt;
+  OptionBool nosort;
+  OptionInt maxctarg;
+  OptionString routename;
   int maxct{};
 
   Waypoint* home_pos{};
 
   QVector<arglist_t> args = {
     {
-      "lat", &latopt,       "Latitude for center point (D.DDDDD)",
+      "lat", &latopt, "Latitude for center point (D.DDDDD)",
       nullptr, ARGTYPE_FLOAT | ARGTYPE_REQUIRED, ARG_NOMINMAX, nullptr
     },
     {
-      "lon", &lonopt,       "Longitude for center point (D.DDDDD)",
+      "lon", &lonopt, "Longitude for center point (D.DDDDD)",
       nullptr, ARGTYPE_FLOAT | ARGTYPE_REQUIRED, ARG_NOMINMAX, nullptr
     },
     {
       "distance", &distopt, "Maximum distance from center",
-      nullptr, ARGTYPE_FLOAT | ARGTYPE_REQUIRED, ARG_NOMINMAX, nullptr
+      nullptr, ARGTYPE_STRING | ARGTYPE_REQUIRED, ARG_NOMINMAX, nullptr
     },
     {
-      "exclude", &exclopt,  "Exclude points close to center",
+      "exclude", &exclopt, "Exclude points close to center",
       nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
     },
     {
-      "nosort", &nosort,    "Inhibit sort by distance to center",
+      "nosort", &nosort, "Inhibit sort by distance to center",
       nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
     },
     {
