@@ -40,8 +40,6 @@
 #endif
 
 
-#define MYNAME "shape"
-
 /************************************************************************/
 /*                              SHPOpenGpsbabel()                       */
 /************************************************************************/
@@ -147,21 +145,21 @@ ShapeFormat::DBFCreateGpsbabel(const QString& pszFilename)
 [[noreturn]] void ShapeFormat::dump_fields() const
 {
   char name[12];
-  warning(MYNAME ": Database fields:\n");
+  gbWarning("Database fields:\n");
   const int nFields = DBFGetFieldCount(ihandledb);
   for (int i = 0; i < nFields; i++) {
     DBFFieldType type = DBFGetFieldInfo(ihandledb, i, name, nullptr, nullptr);
-    warning(MYNAME ": Field Index: %2d, Field Name: %12s, Field Type %d\n", i, name, type);
+    gbWarning("Field Index: %2d, Field Name: %12s, Field Type %d\n", i, name, type);
   }
-  fatal("\n");
+  gbFatal("\n");
 }
 
 void ShapeFormat::check_field_index(const int fieldIdx) const
 {
   const int maxFields = DBFGetFieldCount(ihandledb);
   if (fieldIdx < 0 || fieldIdx >= maxFields) {
-    warning(MYNAME ": dbf file for %s doesn't have a field index number %d.\n", qPrintable(ifname), fieldIdx);
-    warning(MYNAME ": the minimum field number is 0 and the maximum field number is %d.\n",maxFields-1);
+    gbWarning("dbf file for %s doesn't have a field index number %d.\n", gbLogCStr(ifname), fieldIdx);
+    gbWarning("the minimum field number is 0 and the maximum field number is %d.\n",maxFields-1);
     dump_fields();
   }
 }
@@ -170,7 +168,7 @@ int ShapeFormat::get_field_index(const QString& fieldName) const
 {
   const int fieldIdx = DBFGetFieldIndex(ihandledb, CSTR(fieldName));
   if (fieldIdx < 0) {
-    warning(MYNAME ": dbf file for %s doesn't have a field named '%s'.\n", qPrintable(ifname), qPrintable(fieldName));
+    gbWarning("dbf file for %s doesn't have a field named '%s'.\n", gbLogCStr(ifname), gbLogCStr(fieldName));
     dump_fields();
   }
   return fieldIdx;
@@ -183,21 +181,21 @@ ShapeFormat::rd_init(const QString& fname)
   // TODO: The .prj file can define the the coordinate system and projection information.
   ihandle = SHPOpenGpsbabel(fname, "rb");
   if (ihandle == nullptr) {
-    fatal(MYNAME ": Cannot open shp file %s for reading\n", qPrintable(ifname));
+    gbFatal("Cannot open shp file %s for reading\n", gbLogCStr(ifname));
   }
 
   ihandledb = DBFOpenGpsbabel(fname, "rb");
   if (ihandledb == nullptr) {
-    fatal(MYNAME ": Cannot open dbf file %s for reading\n", qPrintable(ifname));
+    gbFatal("Cannot open dbf file %s for reading\n", gbLogCStr(ifname));
   }
   const char* codepage = DBFGetCodePage(ihandledb);
   if (codepage) {
     QString qcodepage(codepage);
     if (qcodepage.compare(u"UTF-8", Qt::CaseInsensitive)) {
-      warning(MYNAME ": dbf file %s is in code page %s, but we always process dbf files as UTF-8.\n",qPrintable(ifname),codepage);
+      gbWarning("dbf file %s is in code page %s, but we always process dbf files as UTF-8.\n",gbLogCStr(ifname),codepage);
     }
   } else {
-    warning(MYNAME ": dbf file %s uses unknown code page, assuming UTF-8.\n", qPrintable(ifname));
+    gbWarning("dbf file %s uses unknown code page, assuming UTF-8.\n", gbLogCStr(ifname));
   }
 }
 
@@ -218,21 +216,17 @@ ShapeFormat::read()
     if (qopt_name.contains('+')) {
       // form a compound name from one or more fields.
       nameidx = -2;
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-      const QStringList opt_name_fields = qopt_name.split('+', QString::SkipEmptyParts);
-#else
       const QStringList opt_name_fields = qopt_name.split('+', Qt::SkipEmptyParts);
-#endif
       nameindices.reserve(opt_name_fields.size());
-      for (int oidx=0; oidx<opt_name_fields.size(); oidx++) {
+      for (const auto & opt_name_field : opt_name_fields) {
         bool ok;
-        int fieldIdx = opt_name_fields.at(oidx).toInt(&ok);
+        int fieldIdx = opt_name_field.toInt(&ok);
         if (ok) {
           // retrieve name component from given field number
           check_field_index(fieldIdx);
         } else {
           // retrieve name component from given field name.
-          fieldIdx = get_field_index(opt_name_fields.at(oidx));
+          fieldIdx = get_field_index(opt_name_field);
         }
         nameindices.append(fieldIdx);
       }
@@ -369,7 +363,7 @@ ShapeFormat::read()
     default:
 
 err:
-      warning("This file contains shapefile geometry type %s that does not naturally convert\nCustom programming is likely required.\n",
+      gbWarning("This file contains shapefile geometry type %s that does not naturally convert\nCustom programming is likely required.\n",
               etype);
       break;
     }
@@ -473,13 +467,13 @@ ShapeFormat::write()
     ohandle = SHPCreateGpsbabel(ofname, SHPT_POINT);
 
     if (ohandle == nullptr) {
-      fatal(MYNAME ": Cannot open shp file %s for writing\n",
-            qPrintable(ofname));
+      gbFatal("Cannot open shp file %s for writing\n",
+            gbLogCStr(ofname));
     }
     ohandledb = DBFCreateExGpsbabel(ofname, "UTF-8\n");
     if (ohandledb == nullptr) {
-      fatal(MYNAME ": Cannot open dbf file %s for writing\n",
-            qPrintable(ofname));
+      gbFatal("Cannot open dbf file %s for writing\n",
+            gbLogCStr(ofname));
     }
     nameFieldIdx=DBFAddField(ohandledb,"name",FTString,100,0);
     auto write_wpt_lambda = [this](const Waypoint* wpt)->void {
@@ -493,13 +487,13 @@ ShapeFormat::write()
     ohandle = SHPCreateGpsbabel(ofname, SHPT_ARC);
 
     if (ohandle == nullptr) {
-      fatal(MYNAME ": Cannot open shp file %s for writing\n",
-            qPrintable(ofname));
+      gbFatal("Cannot open shp file %s for writing\n",
+            gbLogCStr(ofname));
     }
     ohandledb = DBFCreateExGpsbabel(ofname, "UTF-8\n");
     if (ohandledb == nullptr) {
-      fatal(MYNAME ": Cannot open dbf file %s for writing\n",
-            qPrintable(ofname));
+      gbFatal("Cannot open dbf file %s for writing\n",
+            gbLogCStr(ofname));
     }
     nameFieldIdx=DBFAddField(ohandledb,"name",FTString,100,0);
     auto poly_init_lambda = [this](const route_head* rte)->void {
@@ -519,7 +513,7 @@ ShapeFormat::write()
     break;
   }
   case posndata:
-    fatal(MYNAME ": Realtime positioning not supported\n");
+    gbFatal("Realtime positioning not supported\n");
     break;
   }
 }
