@@ -57,7 +57,6 @@
 */
 
 #include <cassert>
-#include <cstdlib>              // for strtol
 #include <iterator>             // for prev
 
 #include <QDateTime>            // for QDateTime
@@ -66,12 +65,11 @@
 
 #include "defs.h"
 #include "smplrout.h"
-#include "grtcirc.h"            // for gcdist, linedist, radtometers, radtomiles, linepart
+#include "grtcirc.h"            // for gcdist, linedist, radtometers, linepart
 #include "src/core/datetime.h"  // for DateTime
 
 
 #if FILTERS_ENABLED
-#define MYNAME "simplify"
 
 inline bool operator<(const SimplifyRouteFilter::trackerror& lhs, const SimplifyRouteFilter::trackerror& rhs)
 {
@@ -96,19 +94,16 @@ double SimplifyRouteFilter::compute_track_error(const neighborhood& nb) const
   double track_error;
   switch (metric) {
   case metric_t::crosstrack:
-    track_error = radtomiles(linedist(
-                               wpt1->latitude, wpt1->longitude,
-                               wpt2->latitude, wpt2->longitude,
-                               wpt3->latitude, wpt3->longitude));
+    track_error = radtometers(linedist(
+                               wpt1->position(),
+                               wpt2->position(),
+                               wpt3->position()));
     break;
   case metric_t::length:
-    track_error = radtomiles(
-                    gcdist(wpt1->latitude, wpt1->longitude,
-                           wpt3->latitude, wpt3->longitude) +
-                    gcdist(wpt3->latitude, wpt3->longitude,
-                           wpt2->latitude, wpt2->longitude) -
-                    gcdist(wpt1->latitude, wpt1->longitude,
-                           wpt2->latitude, wpt2->longitude));
+    track_error = radtometers(
+                    gcdist(wpt1->position(), wpt3->position()) +
+                    gcdist(wpt3->position(), wpt2->position()) -
+                    gcdist(wpt1->position(), wpt2->position()));
     break;
   case metric_t::relative:
   default: // eliminate false positive warning with g++ 11.3.0: ‘error’ may be used uninitialized in this function [-Wmaybe-uninitialized]
@@ -119,18 +114,15 @@ double SimplifyRouteFilter::compute_track_error(const neighborhood& nb) const
         (wpt1->GetCreationTime() != wpt2->GetCreationTime())) {
       double frac = static_cast<double>(wpt1->GetCreationTime().msecsTo(wpt3->GetCreationTime())) /
                     static_cast<double>(wpt1->GetCreationTime().msecsTo(wpt2->GetCreationTime()));
-      double reslat, reslon;
-      linepart(wpt1->latitude, wpt1->longitude,
-               wpt2->latitude, wpt2->longitude,
-               frac, &reslat, &reslon);
-      track_error = radtometers(gcdist(
-                                  wpt3->latitude, wpt3->longitude,
-                                  reslat, reslon));
+      auto respos = linepart(wpt1->position(),
+                             wpt2->position(),
+                             frac);
+      track_error = radtometers(gcdist(wpt3->position(), respos));
     } else { // else distance to connecting line
       track_error = radtometers(linedist(
-                                  wpt1->latitude, wpt1->longitude,
-                                  wpt2->latitude, wpt2->longitude,
-                                  wpt3->latitude, wpt3->longitude));
+                                  wpt1->position(),
+                                  wpt2->position(),
+                                  wpt3->position()));
     }
     // error relative to horizontal precision
     track_error /= (6 * wpt3->hdop);
@@ -167,7 +159,7 @@ void SimplifyRouteFilter::routesimple_head(const route_head* rte)
     if (metric == metric_t::relative) {
       // check hdop is available for compute_track_error
       if (wpt->hdop == 0) {
-        fatal(MYNAME ": relative needs hdop information.\n");
+        gbFatal("relative needs hdop information.\n");
       }
     }
 
@@ -209,7 +201,7 @@ void SimplifyRouteFilter::routesimple_head(const route_head* rte)
     neighborhood goner = errormap.last();
     goner.wpt->wpt_flags.marked_for_deletion = 1;
     // errormap.remove(lastKey());  // with Qt 5.12.12, 5.15.2 results in asan heap-use-after-free errors in build_extra_tests.sh
-    errormap.erase(std::prev(errormap.end())); // in Qt6 can use cend().
+    errormap.erase(std::prev(errormap.cend())); // in Qt6 can use cend().
     // wpthash.remove(goner.wpt); // removal not necessary
 
     /* recompute neighbors of point marked for deletion. */
@@ -278,7 +270,7 @@ void SimplifyRouteFilter::init()
   } else if (countopt && !erroropt) {
     limit_basis = limit_basis_t::count;
   } else {
-    fatal(MYNAME ": You must specify either count or error, but not both.\n");
+    gbFatal("You must specify either count or error, but not both.\n");
   }
 
   if (!lenopt && !relopt) {
@@ -288,19 +280,20 @@ void SimplifyRouteFilter::init()
   } else if (!xteopt && !lenopt && relopt) {
     metric = metric_t::relative;
   } else {
-    fatal(MYNAME ": You may specify only one of crosstrack, length, or relative.\n");
+    gbFatal("You may specify only one of crosstrack, length, or relative.\n");
   }
 
   switch (limit_basis) {
   case limit_basis_t::count:
-    count = strtol(countopt, nullptr, 10);
+    count = countopt.get_result();
     break;
   case limit_basis_t::error: {
-    int res = parse_distance(erroropt, &error, 1.0, MYNAME);
-    if (res == 0) {
-      error = 0;
-    } else if (res == 2) { /* parameter with unit */
-      error = METERS_TO_MILES(error);
+    if (metric == metric_t::relative) {
+      error = erroropt.get_result();
+    } else {
+      if (parse_distance(erroropt, &error, kMetersPerMile) == 0) {
+        gbFatal("No value specified with error option.\n");
+      }
     }
   }
   break;
