@@ -35,7 +35,7 @@ namespace gpsbabel
 class CodecDevice : public QIODevice
 {
 public:
-  CodecDevice(const QString& fname, const char* module, const char* codec_name);
+  CodecDevice(const QString& fname, const char* codec_name);
   ~CodecDevice();
   bool open(QIODevice::OpenMode mode) override;
   bool isSequential() const override;
@@ -47,7 +47,6 @@ private:
 
 private:
   QString fname_;
-  const char* module_;
   const char* codec_name_;
   gpsbabel::File* file_{nullptr};
   QTextCodec* codec_{nullptr};
