@@ -19,21 +19,13 @@
 #ifndef SRC_CORE_TEXTSTREAM_INCLUDED_H_
 #define SRC_CORE_TEXTSTREAM_INCLUDED_H_
 
-#include <QtGlobal>                // for QT_VERSION, QT_VERSION_CHECK
 
 #include <QIODevice>               // for QIODevice
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 #include <QIODeviceBase>           // for QIODeviceBase::OpenMode
-#endif
 #include <QString>                 // for QString
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include <QTextCodec>              // for QTextCodec
-#endif
 #include <QTextStream>             // for QTextStream
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 #include "src/core/codecdevice.h"  // for CodecDevice
-#endif
 #include "src/core/file.h"         // for File
 
 
@@ -43,16 +35,12 @@ namespace gpsbabel
 class TextStream : public QTextStream
 {
 public:
-  void open(const QString& fname, QIODevice::OpenMode mode, const char* module, const char* codec = "UTF-8");
+  void open(const QString& fname, QIODevice::OpenMode mode, const char* codec = "UTF-8");
   void close();
 
 private:
   gpsbabel::File* file_{nullptr};
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-  QTextCodec* codec_{nullptr};
-#else
   gpsbabel::CodecDevice* device_{nullptr};
-#endif
 };
 
 } // namespace gpsbabel
