@@ -18,8 +18,8 @@ function validate() {
   )
 }
 
-QT_VERSION=${1:-5.12.10}
-COMPILER=${2:-msvc2017_64}
+QT_VERSION=${1:-6.5.3}
+COMPILER=${2:-msvc2019_64}
 METHOD=${3:-default}
 
 if [ "${COMPILER}" = "msvc2017_64" ]; then
@@ -28,6 +28,10 @@ elif [ "${COMPILER}" = "msvc2017" ]; then
   PACKAGE_SUFFIX=win32_msvc2017
 elif [ "${COMPILER}" = "msvc2019_64" ]; then
   PACKAGE_SUFFIX=win64_msvc2019_64
+elif [ "${COMPILER}" = "msvc2019" ]; then
+  PACKAGE_SUFFIX=win32_msvc2019
+elif [ "${COMPILER}" = "msvc2022_64" ]; then
+  PACKAGE_SUFFIX=win64_msvc2022_64
 else
   echo "ERROR: unrecognized Qt compiler ${COMPILER}." >&2
   exit 1
@@ -47,20 +51,8 @@ else
     "${CI_BUILD_DIR}/tools/ci_install_qt.sh" windows "${QT_VERSION}" "${PACKAGE_SUFFIX}" "${CACHEDIR}/Qt"
     echo "export PATH=${QTDIR}/bin:\$PATH" > "${CACHEDIR}/qt.env"
   else
-    QT_VERSION_SHORT=${QT_VERSION//./}
-    QT_VERSION_MAJMIN=${QT_VERSION%.*}
-    curl -s -L -o "qt-opensource-windows-x86-${QT_VERSION}.exe" "https://download.qt.io/official_releases/qt/${QT_VERSION_MAJMIN}/${QT_VERSION}/qt-opensource-windows-x86-${QT_VERSION}.exe"
-    ls -l ./*.exe
-    netsh advfirewall firewall add rule name=dummyupqt dir=out action=block program="$(cygpath -w "${PWD}/qt-opensource-windows-x86-${QT_VERSION}.exe")"
-    "${PWD}/qt-opensource-windows-x86-${QT_VERSION}.exe" --verbose --script "${CI_BUILD_DIR}/tools/qtci/qt-install.qs" QTCI_OUTPUT="${CACHEDIR}/Qt" QTCI_PACKAGES="qt.qt5.${QT_VERSION_SHORT}.${PACKAGE_SUFFIX},qt.qt5.${QT_VERSION_SHORT}.qtwebengine"
-    netsh advfirewall firewall delete rule name=dummyupqt
-    rm "qt-opensource-windows-x86-${QT_VERSION}.exe"
-    ls "${CACHEDIR}/Qt"
-    rm -fr "${CACHEDIR}/Qt/Docs"
-    rm -fr "${CACHEDIR}/Qt/Examples"
-    rm -fr "${CACHEDIR}/Qt/Tools"
-    rm -f "${CACHEDIR}/Qt/MaintenanceTool.*"
-    echo "export PATH=${QTDIR}/bin:\$PATH" > "${CACHEDIR}/qt.env"
+    echo "ERROR: unknown installation method ${METHOD}." >&2
+    exit 1
   fi
 fi
 validate
