@@ -40,11 +40,10 @@
 #include "format.h"               // for Format
 #include "garmin_fs.h"            // for garmin_fs_t
 #include "mkshort.h"              // for MakeShort
+#include "option.h"               // for OptionString, OptionBool
 #include "src/core/datetime.h"    // for DateTime
 #include "src/core/textstream.h"  // for TextStream
 
-#if CSVFMTS_ENABLED
-
 /*
  * Class describing an xcsv format.
  */
@@ -350,7 +349,7 @@ private:
   /* Member Functions */
 
   static QDate yyyymmdd_to_time(const QString& s);
-  QDateTime xcsv_adjust_time(const QDate date, const QTime time, bool is_localtime) const;
+  QDateTime xcsv_adjust_time(QDate date, QTime time, bool is_localtime) const;
   static void sscanftime(const char* s, const char* format, QDate& date, QTime& time);
   static QString writetime(const char* format, time_t t, bool gmt);
   static QString writetime(const char* format, const gpsbabel::DateTime& t, bool gmt);
@@ -366,22 +365,21 @@ private:
   XcsvFile* xcsv_file{nullptr};
   const XcsvStyle* xcsv_style{nullptr};
   double pathdist = 0;
-  double oldlon = 999;
-  double oldlat = 999;
+  std::optional<PositionDeg> old_position;
 
   int waypt_out_count = 0;
   const route_head* csv_track = nullptr;
   const route_head* csv_route = nullptr;
 
-  char* styleopt = nullptr;
-  char* snlenopt = nullptr;
-  char* snwhiteopt = nullptr;
-  char* snupperopt = nullptr;
-  char* snuniqueopt = nullptr;
-  char* prefer_shortnames = nullptr;
-  char* xcsv_urlbase = nullptr;
-  char* opt_datum = nullptr;
-  char* opt_utc = nullptr;
+  OptionString styleopt;
+  OptionInt snlenopt;
+  OptionBool snwhiteopt;
+  OptionBool snupperopt;
+  OptionBool snuniqueopt;
+  OptionBool prefer_shortnames;
+  OptionString xcsv_urlbase;
+  OptionString opt_datum;
+  OptionInt opt_utc;
   int utc_offset{};
 
   QString intstylefile;
@@ -428,5 +426,4 @@ private:
 
 };
 
-#endif // CSVFMTS_ENABLED
 #endif // XCSV_H_INCLUDED_
